@@ -15,7 +15,7 @@
 
 #include <Rcpp.h>
 
-// To suppress Found ‘__assert_fail’, possibly from ‘assert’ (C).
+// To suppress Found '__assert_fail', possibly from 'assert' (C).
 #define BOOST_DISABLE_ASSERTS
 
 // Rcpp has its own stream object which cooperates more nicely with R's i/o
@@ -36,10 +36,14 @@
 // This define makes the R RNG have precedent over the C++11-based
 // RNG provided by Armadillo.
 #if !defined(ARMA_RNG_ALT)
-  #define ARMA_RNG_ALT         RcppArmadillo/Alt_R_RNG.h
+  #define ARMA_RNG_ALT         RcppArmadillo/rng/Alt_R_RNG.h
 #endif
 
 // To suppress warnings related to core/util/arma_util.hpp.
 #define MLPACK_CORE_UTIL_ARMA_CONFIG_HPP
 
+// Undefine macro due to macro collision.
+#undef Realloc
+#undef Free
+
 #endif
