@@ -25,29 +25,30 @@ namespace cli {
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::disable_if<util::IsStdVector<T>>::type* = 0,
-    const typename boost::disable_if<data::HasSerialize<T>>::type* = 0,
-    const typename boost::disable_if<std::is_same<T, std::string>>::type* = 0,
-    const typename boost::disable_if<std::is_same<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>::type* = 0);
+    util::ParamData& data,
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<!util::IsStdVector<T>::value>::type* = 0,
+    const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
+    const typename std::enable_if<!std::is_same<T,
+        std::string>::value>::type* = 0,
+    const typename std::enable_if<!std::is_same<T,
+        std::tuple<mlpack::data::DatasetInfo, arma::mat>>::value>::type* = 0);
 
 /**
  * Return the default value of a vector option.
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
-    const typename boost::enable_if<util::IsStdVector<T>>::type* = 0);
+    util::ParamData& data,
+    const typename std::enable_if<util::IsStdVector<T>::value>::type* = 0);
 
 /**
  * Return the default value of a string option.
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
-    const typename boost::enable_if<std::is_same<T, std::string>>::type* = 0);
+    util::ParamData& data,
+    const typename std::enable_if<std::is_same<T, std::string>::value>::type* = 0);
 
 /**
  * Return the default value of a matrix option, a tuple option, a
@@ -56,8 +57,8 @@ std::string DefaultParamImpl(
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
-    const typename boost::enable_if_c<
+    util::ParamData& data,
+    const typename std::enable_if<
         arma::is_arma_type<T>::value ||
         std::is_same<T, std::tuple<mlpack::data::DatasetInfo,
                                    arma::mat>>::value>::type* /* junk */ = 0);
@@ -68,16 +69,16 @@ std::string DefaultParamImpl(
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::enable_if<data::HasSerialize<T>>::type* = 0);
+    util::ParamData& data,
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<data::HasSerialize<T>::value>::type* = 0);
 
 /**
  * Return the default value of an option.  This is the function that will be
  * placed into the CLI functionMap.
  */
 template<typename T>
-void DefaultParam(const util::ParamData& data,
+void DefaultParam(util::ParamData& data,
                   const void* /* input */,
                   void* output)
 {
