@@ -28,13 +28,13 @@ namespace cli {
 template<typename T>
 T& GetParam(
     util::ParamData& d,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::disable_if<data::HasSerialize<T>>::type* = 0,
-    const typename boost::disable_if<std::is_same<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>::type* = 0)
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
+    const typename std::enable_if<!std::is_same<T,
+        std::tuple<mlpack::data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
   // No mapping is needed, so just cast it directly.
-  return *boost::any_cast<T>(&d.value);
+  return *MLPACK_ANY_CAST<T>(&d.value);
 }
 
 /**
@@ -45,16 +45,18 @@ T& GetParam(
 template<typename T>
 T& GetParam(
     util::ParamData& d,
-    const typename boost::enable_if<arma::is_arma_type<T>>::type* = 0)
+    const typename std::enable_if<arma::is_arma_type<T>::value>::type* = 0)
 {
   // If the matrix is an input matrix, we have to load the matrix.  'value'
   // contains the filename.  It's possible we could load empty matrices many
   // times, but I am not bothered by that---it shouldn't be something that
   // happens.
   typedef std::tuple<T, typename ParameterType<T>::type> TupleType;
-  TupleType& tuple = *boost::any_cast<TupleType>(&d.value);
-  const std::string& value = std::get<1>(tuple);
+  TupleType& tuple = *MLPACK_ANY_CAST<TupleType>(&d.value);
+  const std::string& value = std::get<0>(std::get<1>(tuple));
   T& matrix = std::get<0>(tuple);
+  size_t& n_rows = std::get<1>(std::get<1>(tuple));
+  size_t& n_cols = std::get<2>(std::get<1>(tuple));
   if (d.input && !d.loaded)
   {
     // Call correct data::Load() function.
@@ -62,6 +64,8 @@ T& GetParam(
       data::Load(value, matrix, true);
     else
       data::Load(value, matrix, true, !d.noTranspose);
+    n_rows = matrix.n_rows;
+    n_cols = matrix.n_cols;
     d.loaded = true;
   }
 
@@ -76,18 +80,22 @@ T& GetParam(
 template<typename T>
 T& GetParam(
     util::ParamData& d,
-    const typename boost::enable_if<std::is_same<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>::type* = 0)
+    const typename std::enable_if<std::is_same<T,
+        std::tuple<mlpack::data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
   // If this is an input parameter, we need to load both the matrix and the
   // dataset info.
-  typedef std::tuple<T, std::string> TupleType;
-  TupleType* tuple = boost::any_cast<TupleType>(&d.value);
-  const std::string& value = std::get<1>(*tuple);
+  typedef std::tuple<T, std::tuple<std::string, size_t, size_t>> TupleType;
+  TupleType* tuple = MLPACK_ANY_CAST<TupleType>(&d.value);
+  const std::string& value = std::get<0>(std::get<1>(*tuple));
   T& t = std::get<0>(*tuple);
+  size_t& n_rows = std::get<1>(std::get<1>(*tuple));
+  size_t& n_cols = std::get<2>(std::get<1>(*tuple));
   if (d.input && !d.loaded)
   {
     data::Load(value, std::get<1>(t), std::get<0>(t), true, !d.noTranspose);
+    n_rows = std::get<1>(t).n_rows;
+    n_cols = std::get<1>(t).n_cols;
     d.loaded = true;
   }
 
@@ -102,13 +110,13 @@ T& GetParam(
 template<typename T>
 T*& GetParam(
     util::ParamData& d,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::enable_if<data::HasSerialize<T>>::type* = 0)
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<data::HasSerialize<T>::value>::type* = 0)
 {
   // If the model is an input model, we have to load it from file.  'value'
   // contains the filename.
   typedef std::tuple<T*, std::string> TupleType;
-  TupleType* tuple = boost::any_cast<TupleType>(&d.value);
+  TupleType* tuple = MLPACK_ANY_CAST<TupleType>(&d.value);
   const std::string& value = std::get<1>(*tuple);
   if (d.input && !d.loaded)
   {
