@@ -23,14 +23,14 @@ namespace cli {
 template<typename T>
 std::string GetPrintableParam(
     util::ParamData& data,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* /* junk */,
-    const typename boost::disable_if<util::IsStdVector<T>>::type* /* junk */,
-    const typename boost::disable_if<data::HasSerialize<T>>::type* /* junk */,
-    const typename boost::disable_if<std::is_same<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>::type* /* junk */)
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* /* junk */,
+    const typename std::enable_if<!util::IsStdVector<T>::value>::type* /* junk */,
+    const typename std::enable_if<!data::HasSerialize<T>::value>::type* /* junk */,
+    const typename std::enable_if<!std::is_same<T,
+        std::tuple<data::DatasetInfo, arma::mat>>::value>::type* /* junk */)
 {
   std::ostringstream oss;
-  oss << boost::any_cast<T>(data.value);
+  oss << MLPACK_ANY_CAST<T>(data.value);
   return oss.str();
 }
 
@@ -41,7 +41,7 @@ std::string GetPrintableParam(
     const typename std::enable_if<util::IsStdVector<T>::value>::type*
         /* junk */)
 {
-  const T& t = boost::any_cast<T>(data.value);
+  const T& t = MLPACK_ANY_CAST<T>(data.value);
 
   std::ostringstream oss;
   for (size_t i = 0; i < t.size(); ++i)
@@ -80,16 +80,18 @@ std::string GetPrintableParam(
 {
   // Extract the string from the tuple that's being held.
   typedef std::tuple<T, typename ParameterType<T>::type> TupleType;
-  const TupleType* tuple = boost::any_cast<TupleType>(&data.value);
+  const TupleType* tuple = MLPACK_ANY_CAST<TupleType>(&data.value);
 
   std::ostringstream oss;
-  oss << "'" << std::get<1>(*tuple) << "'";
+  oss << "'" << std::get<0>(std::get<1>(*tuple)) << "'";
 
-  if (std::get<1>(*tuple) != "")
+  if (std::get<0>(std::get<1>(*tuple)) != "")
   {
     // Make sure the matrix is loaded so that we can print its size.
-    T& mat = GetParam<T>(const_cast<util::ParamData&>(data));
-    std::string matDescription = GetMatrixSize(mat);
+    GetParam<T>(const_cast<util::ParamData&>(data));
+    std::string matDescription =
+        std::to_string(std::get<2>(std::get<1>(*tuple))) + "x" +
+        std::to_string(std::get<1>(std::get<1>(*tuple))) + " matrix";
 
     oss << " (" << matDescription << ")";
   }
@@ -101,12 +103,12 @@ std::string GetPrintableParam(
 template<typename T>
 std::string GetPrintableParam(
     util::ParamData& data,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* /* junk */,
-    const typename boost::enable_if<data::HasSerialize<T>>::type* /* junk */)
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* /* junk */,
+    const typename std::enable_if<data::HasSerialize<T>::value>::type* /* junk */)
 {
   // Extract the string from the tuple that's being held.
   typedef std::tuple<T*, typename ParameterType<T>::type> TupleType;
-  const TupleType* tuple = boost::any_cast<TupleType>(&data.value);
+  const TupleType* tuple = MLPACK_ANY_CAST<TupleType>(&data.value);
 
   std::ostringstream oss;
   oss << std::get<1>(*tuple);
