@@ -30,18 +30,18 @@ namespace cli {
 template<typename T>
 void InPlaceCopyInternal(
     util::ParamData& /* d */,
-    const util::ParamData& /* input */,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::disable_if<data::HasSerialize<T>>::type* = 0,
-    const typename boost::disable_if<std::is_same<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>::type* = 0)
+    util::ParamData& /* input */,
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
+    const typename std::enable_if<!std::is_same<T,
+        std::tuple<mlpack::data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
   // Nothing to do.
 }
 
 /**
  * Modify the filename for any type that needs to be loaded from disk to match
- * the filename of the input parameter.
+ * the filename of the input parameter, for a matrix/DatasetInfo parameter.
  *
  * @param d ParamData object we want to make into an in-place copy.
  * @param input ParamData object whose filename we should copy.
@@ -49,19 +49,42 @@ void InPlaceCopyInternal(
 template<typename T>
 void InPlaceCopyInternal(
     util::ParamData& d,
-    const util::ParamData& input,
+    util::ParamData& input,
     const typename std::enable_if<
         arma::is_arma_type<T>::value ||
         std::is_same<T,
-                     std::tuple<mlpack::data::DatasetInfo, arma::mat>>::value ||
-        data::HasSerialize<T>::value>::type* = 0)
+                     std::tuple<mlpack::data::DatasetInfo, arma::mat>>::value
+                 >::type* = 0)
 {
   // Make the output filename the same as the input filename.
   typedef std::tuple<T, typename ParameterType<T>::type> TupleType;
-  TupleType& tuple = *boost::any_cast<TupleType>(&d.value);
+  TupleType& tuple = *MLPACK_ANY_CAST<TupleType>(&d.value);
+  std::string& value = std::get<0>(std::get<1>(tuple));
+
+  const TupleType& inputTuple = *MLPACK_ANY_CAST<TupleType>(&input.value);
+  value = std::get<0>(std::get<1>(inputTuple));
+}
+
+/**
+ * Modify the filename for any type that needs to be loaded from disk to match
+ * the filename of the input parameter. For serializable objects.
+ *
+ * @param d ParamData object we want to make into an in-place copy.
+ * @param input ParamData object whose filename we should copy.
+ */
+template<typename T>
+void InPlaceCopyInternal(
+    util::ParamData& d,
+    util::ParamData& input,
+    const typename std::enable_if<
+        data::HasSerialize<T>::value>::type* = 0)
+{
+  // Make the output filename the same as the input filename.
+  typedef std::tuple<T*, typename ParameterType<T>::type> TupleType;
+  TupleType& tuple = *MLPACK_ANY_CAST<TupleType>(&d.value);
   std::string& value = std::get<1>(tuple);
 
-  const TupleType& inputTuple = *boost::any_cast<TupleType>(&input.value);
+  const TupleType& inputTuple = *MLPACK_ANY_CAST<TupleType>(&input.value);
   value = std::get<1>(inputTuple);
 }
 
@@ -74,13 +97,13 @@ void InPlaceCopyInternal(
  * @param * (output) Unused parameter.
  */
 template<typename T>
-void InPlaceCopy(const util::ParamData& d,
+void InPlaceCopy(util::ParamData& d,
                  const void* input,
                  void* /* output */)
 {
   // Cast to the correct type.
   InPlaceCopyInternal<typename std::remove_pointer<T>::type>(
-      const_cast<util::ParamData&>(d), *((const util::ParamData*) input));
+      const_cast<util::ParamData&>(d), *((util::ParamData*) input));
 }
 
 } // namespace cli
