@@ -2,7 +2,7 @@
  * @file bindings/cli/map_parameter_name.hpp
  * @author Ryan Curtin
  *
- * Map a parameter name to what it seen by boost::program_options using template
+ * Map a parameter name to what it seen by CLI11 using template
  * metaprogramming.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
@@ -21,29 +21,29 @@ namespace cli {
 
 /**
  * If needed, map the parameter name to the name that is used by
- * boost::program_options.  This overload simply returns the same name, so it is
+ * CLI11.  This overload simply returns the same name, so it is
  * used for primitive types.
  */
 template<typename T>
 std::string MapParameterName(
     const std::string& identifier,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::disable_if<data::HasSerialize<T>>::type* = 0,
-    const typename boost::disable_if<std::is_same<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>::type* = 0)
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
+    const typename std::enable_if<!std::is_same<T,
+        std::tuple<mlpack::data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
   return identifier;
 }
 
 /**
- * Map the parameter name to the name that is used by boost::program_options.
+ * Map the parameter name to the name that is used by CLI11.
  * This overload addresses matrices and models, where the parameter name has
  * "_file" appended to it (since a filename will be provided).
  */
 template<typename T>
 std::string MapParameterName(
     const std::string& identifier,
-    const typename boost::enable_if_c<
+    const typename std::enable_if<
         arma::is_arma_type<T>::value ||
         std::is_same<T, std::tuple<mlpack::data::DatasetInfo,
                                    arma::mat>>::value ||
@@ -53,14 +53,14 @@ std::string MapParameterName(
 }
 
 /**
- * Map the parameter name to the name seen by boost::program_options.
+ * Map the parameter name to the name seen by CLI.
  *
  * @param d Parameter data.
  * @param * (input) Unused parameter.
  * @param output Pointer to std::string that will hold the mapped name.
  */
 template<typename T>
-void MapParameterName(const util::ParamData& d,
+void MapParameterName(util::ParamData& d,
                       const void* /* input */,
                       void* output)
 {
