@@ -29,24 +29,24 @@ template<typename T>
 void PrintOutputProcessing(
     util::ParamData& d,
     const size_t indent,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::disable_if<data::HasSerialize<T>>::type* = 0,
-    const typename boost::disable_if<std::is_same<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>::type* = 0)
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
+    const typename std::enable_if<!std::is_same<T,
+        std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
   const std::string prefix(indent, ' ');
 
   /**
    * This gives us code like:
    *
-   *  \<paramName\> := GetParam\<Type\>("paramName")
+   *  \<paramName\> := GetParam\<Type\>(params, "paramName")
    *
    */
 
   std::string name = d.name;
   name = util::CamelCase(name, true);
   std::cout << prefix << name << " := getParam" << GetType<T>(d)
-            << "(\"" << d.name << "\")" << std::endl;
+            << "(params, \"" << d.name << "\")" << std::endl;
 }
 
 /**
@@ -56,7 +56,7 @@ template<typename T>
 void PrintOutputProcessing(
     util::ParamData& d,
     const size_t indent,
-    const typename boost::enable_if<arma::is_arma_type<T>>::type* = 0,
+    const typename std::enable_if<arma::is_arma_type<T>::value>::type* = 0,
     const typename std::enable_if<!std::is_same<T,
         std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
@@ -66,7 +66,8 @@ void PrintOutputProcessing(
    * This gives us code like:
    *
    *  var \<paramName\>Ptr mlpackArma
-   *  \<paramName\> := \<paramName\>_ptr.ArmaToGonum_\<Type\>("paramName")
+   *  \<paramName\> := \<paramName\>_ptr.ArmaToGonum_\<Type\>(params,
+   *      "paramName")
    *
    */
   std::string name = d.name;
@@ -74,7 +75,7 @@ void PrintOutputProcessing(
   std::cout << prefix << "var " << name << "Ptr mlpackArma" << std::endl;
   std::cout << prefix << name << " := " << name
             << "Ptr.armaToGonum" << GetType<T>(d)
-            << "(\""  << d.name << "\")" << std::endl;
+            << "(params, \""  << d.name << "\")" << std::endl;
 }
 /**
  * Print output processing for a matrix with info type.
@@ -83,8 +84,8 @@ template<typename T>
 void PrintOutputProcessing(
     util::ParamData& d,
     const size_t indent,
-    const typename boost::enable_if<std::is_same<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>::type* = 0)
+    const typename std::enable_if<std::is_same<T,
+        std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
   const std::string prefix(indent, ' ');
 
@@ -92,14 +93,15 @@ void PrintOutputProcessing(
    * This gives us code like:
    *
    *  var \<paramName\>_ptr mlpackArma
-   *  \<paramName\> := \<paramName\>Ptr.ArmaToGonumWithInfo\<Type\>("paramName")
+   *  \<paramName\> := \<paramName\>Ptr.ArmaToGonumWithInfo\<Type\>(params,
+   *      "paramName")
    *
    */
   std::string name = d.name;
   name = util::CamelCase(name, true);
   std::cout << prefix << "var " << name << "Ptr mlpackArma" << std::endl;
   std::cout << prefix << name << " := " << name << "Ptr.armaToGonumWith"
-            << "Info(\""  << d.name << "\")" << std::endl;
+            << "Info(params, \""  << d.name << "\")" << std::endl;
 }
 
 /**
@@ -109,8 +111,8 @@ template<typename T>
 void PrintOutputProcessing(
     util::ParamData& d,
     const size_t indent,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::enable_if<data::HasSerialize<T>>::type* = 0)
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<data::HasSerialize<T>::value>::type* = 0)
 {
   // Get the type names we need to use.
   std::string goStrippedType, strippedType, printedType, defaultsType;
@@ -122,14 +124,14 @@ void PrintOutputProcessing(
    * This gives us code like:
    *
    *  var modelOut \<Type\>
-   *  modelOut.get\<Type\>("paramName")
+   *  modelOut.get\<Type\>(params, "paramName")
    *
    */
   std::string name = d.name;
   name = util::CamelCase(name, true);
   std::cout << prefix << "var " << name << " " << goStrippedType << std::endl;
   std::cout << prefix << name << ".get" << strippedType
-            << "(\"" << d.name << "\")" << std::endl;
+            << "(params, \"" << d.name << "\")" << std::endl;
 }
 
 /**
