@@ -24,15 +24,15 @@ namespace markdown {
  */
 template<typename T>
 std::string GetPrintableParam(
-    const util::ParamData& data,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::disable_if<util::IsStdVector<T>>::type* = 0,
-    const typename boost::disable_if<data::HasSerialize<T>>::type* = 0,
-    const typename boost::disable_if<std::is_same<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>::type* = 0)
+    util::ParamData& data,
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<!util::IsStdVector<T>::value>::type* = 0,
+    const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
+    const typename std::enable_if<!std::is_same<T,
+        std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
   std::ostringstream oss;
-  oss << boost::any_cast<T>(data.value);
+  oss << MLPACK_ANY_CAST<T>(data.value);
   return oss.str();
 }
 
@@ -41,10 +41,10 @@ std::string GetPrintableParam(
  */
 template<typename T>
 std::string GetPrintableParam(
-    const util::ParamData& data,
-    const typename boost::enable_if<util::IsStdVector<T>>::type* = 0)
+    util::ParamData& data,
+    const typename std::enable_if<util::IsStdVector<T>::value>::type* = 0)
 {
-  const T& t = boost::any_cast<T>(data.value);
+  const T& t = MLPACK_ANY_CAST<T>(data.value);
 
   std::ostringstream oss;
   for (size_t i = 0; i < t.size(); ++i)
@@ -57,11 +57,11 @@ std::string GetPrintableParam(
  */
 template<typename T>
 std::string GetPrintableParam(
-    const util::ParamData& data,
-    const typename boost::enable_if<arma::is_arma_type<T>>::type* = 0)
+    util::ParamData& data,
+    const typename std::enable_if<arma::is_arma_type<T>::value>::type* = 0)
 {
   // Get the matrix.
-  const T& matrix = boost::any_cast<T>(data.value);
+  const T& matrix = MLPACK_ANY_CAST<T>(data.value);
 
   std::ostringstream oss;
   oss << matrix.n_rows << "x" << matrix.n_cols << " matrix";
@@ -73,12 +73,12 @@ std::string GetPrintableParam(
  */
 template<typename T>
 std::string GetPrintableParam(
-    const util::ParamData& data,
-    const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
-    const typename boost::enable_if<data::HasSerialize<T>>::type* = 0)
+    util::ParamData& data,
+    const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
+    const typename std::enable_if<data::HasSerialize<T>::value>::type* = 0)
 {
   std::ostringstream oss;
-  oss << data.cppType << " model at " << boost::any_cast<T*>(data.value);
+  oss << data.cppType << " model at " << MLPACK_ANY_CAST<T*>(data.value);
   return oss.str();
 }
 
@@ -87,12 +87,12 @@ std::string GetPrintableParam(
  */
 template<typename T>
 std::string GetPrintableParam(
-    const util::ParamData& data,
-    const typename boost::enable_if<std::is_same<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>::type* = 0)
+    util::ParamData& data,
+    const typename std::enable_if<std::is_same<T,
+        std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0)
 {
   // Get the matrix.
-  const T& tuple = boost::any_cast<T>(data.value);
+  const T& tuple = MLPACK_ANY_CAST<T>(data.value);
   const arma::mat& matrix = std::get<1>(tuple);
 
   std::ostringstream oss;
@@ -111,7 +111,7 @@ std::string GetPrintableParam(
  * @param output Output storage for the string.
  */
 template<typename T>
-void GetPrintableParam(const util::ParamData& data,
+void GetPrintableParam(util::ParamData& data,
                        const void* /* input */,
                        void* output)
 {
