@@ -15,16 +15,17 @@
 #include <mlpack/prereqs.hpp>
 
 /**
- * Given the current settings of CLI, print the header (which will be the
+ * Given the current settings of IO, print the header (which will be the
  * navigation tab) for the binding types that are registered for these options.
  *
  * Output is printed to stdout.
  */
 void PrintHeaders(const std::string& bindingName,
-                  const std::vector<std::string>& languages);
+                  const std::vector<std::string>& languages,
+                  const std::vector<bool>& addWrapperDocs);
 
 /**
- * Given the current settings of CLI, print Markdown documentation for the
+ * Given the current settings of IO, print Markdown documentation for the
  * binding types that are registered for these options.
  *
  * Output is printed to stdout.
@@ -33,6 +34,8 @@ void PrintHeaders(const std::string& bindingName,
  * @param languages The set of languages to print documentation for.
  */
 void PrintDocs(const std::string& bindingName,
-               const std::vector<std::string>& languages);
+               const std::vector<std::string>& languages,
+               const std::vector<std::string>& validMethods,
+               const std::vector<bool>& addWrapperDocs);
 
 #endif
