@@ -19,6 +19,7 @@
 #include <mlpack/bindings/python/print_type_doc.hpp>
 #include <mlpack/bindings/julia/print_type_doc.hpp>
 #include <mlpack/bindings/go/print_type_doc.hpp>
+#include <mlpack/bindings/R/print_type_doc.hpp>
 
 namespace mlpack {
 namespace bindings {
@@ -29,7 +30,7 @@ namespace markdown {
  * depends on the current setting of BindingInfo::Language().
  */
 template<typename T>
-std::string PrintTypeDoc(const util::ParamData& data)
+std::string PrintTypeDoc(util::ParamData& data)
 {
   if (BindingInfo::Language() == "cli")
   {
@@ -47,6 +48,10 @@ std::string PrintTypeDoc(const util::ParamData& data)
   {
     return go::PrintTypeDoc<typename std::remove_pointer<T>::type>(data);
   }
+  else if (BindingInfo::Language() == "r")
+  {
+    return r::PrintTypeDoc<typename std::remove_pointer<T>::type>(data);
+  }
   else
   {
     throw std::invalid_argument("PrintTypeDoc(): unknown "
