@@ -23,11 +23,11 @@ namespace python {
  * special handling is necessary.
  */
 template<typename T>
-void GetParam(const util::ParamData& d,
+void GetParam(util::ParamData& d,
               const void* /* input */,
               void* output)
 {
-  *((T**) output) = const_cast<T*>(boost::any_cast<T>(&d.value));
+  *((T**) output) = const_cast<T*>(MLPACK_ANY_CAST<T>(&d.value));
 }
 
 } // namespace python
