@@ -33,17 +33,15 @@ namespace python {
  * @param * (output) Unused parameter.
  */
 template<typename T>
-void PrintDoc(const util::ParamData& d,
+void PrintDoc(util::ParamData& d,
               const void* input,
               void* /* output */)
 {
   const size_t indent = *((size_t*) input);
   std::ostringstream oss;
   oss << " - ";
-  if (d.name == "lambda") // Don't print Python keywords.
-    oss << d.name << "_ (";
-  else
-    oss << d.name << " (";
+  oss << GetValidName(d.name);
+  oss << " (";
   oss << GetPrintableType<typename std::remove_pointer<T>::type>(d) << "): "
       << d.desc;
 
