@@ -9,17 +9,10 @@
 // Written by Ryan Curtin
 // Written by Matthew Amidon
 
-/**
- * Add a batch constructor for SpMat, if the version is older than 3.810.0, and
- * also a serialize() function for Armadillo.
- */
-template<typename Archive>
-void serialize(Archive& ar, const unsigned int version);
-
 /**
  * These will help us refer the proper vector / column types, only with
  * specifying the matrix type we want to use.
  */
 typedef SpCol<elem_type>   vec_type;
 typedef SpCol<elem_type>   col_type;
-typedef SpRow<elem_type>   row_type;
\ No newline at end of file
+typedef SpRow<elem_type>   row_type;
