@@ -13,7 +13,6 @@
 #define MLPACK_CORE_CV_K_FOLD_CV_IMPL_HPP
 
 namespace mlpack {
-namespace cv {
 
 template<typename MLAlgorithm,
          typename Metric,
@@ -246,17 +245,32 @@ double KFoldCV<MLAlgorithm,
 {
   arma::vec evaluations(k);
 
+  size_t numInvalidScores = 0;
   for (size_t i = 0; i < k; ++i)
   {
     MLAlgorithm&& model  = base.Train(GetTrainingSubset(xs, i),
         GetTrainingSubset(ys, i), args...);
     evaluations(i) = Metric::Evaluate(model, GetValidationSubset(xs, i),
         GetValidationSubset(ys, i));
+    if (std::isnan(evaluations(i)) || std::isinf(evaluations(i)))
+    {
+      ++numInvalidScores;
+      Log::Warn << "KFoldCV::TrainAndEvaluate(): fold " << i << " returned "
+          << "a score of " << evaluations(i) << "; ignoring when computing "
+          << "the average score." << std::endl;
+    }
     if (i == k - 1)
       modelPtr.reset(new MLAlgorithm(std::move(model)));
   }
 
-  return arma::mean(evaluations);
+  if (numInvalidScores == k)
+  {
+    Log::Warn << "KFoldCV::TrainAndEvaluate(): all folds returned invalid "
+        << "scores!  Returning 0.0 as overall score." << std::endl;
+    return 0.0;
+  }
+
+  return arma::mean(evaluations.elem(arma::find_finite(evaluations)));
 }
 
 template<typename MLAlgorithm,
@@ -305,7 +319,7 @@ void KFoldCV<MLAlgorithm,
   PredictionsType ysOrig = ys.cols(0, (k - 1) * binSize + lastBinSize - 1);
 
   // Now shuffle the data.
-  math::ShuffleData(xsOrig, ysOrig, xsOrig, ysOrig);
+  ShuffleData(xsOrig, ysOrig, xsOrig, ysOrig);
 
   InitKFoldCVMat(xsOrig, xs);
   InitKFoldCVMat(ysOrig, ys);
@@ -331,9 +345,9 @@ void KFoldCV<MLAlgorithm,
 
   // Now shuffle the data.
   if (weights.n_elem > 0)
-    math::ShuffleData(xsOrig, ysOrig, weightsOrig, xsOrig, ysOrig, weightsOrig);
+    ShuffleData(xsOrig, ysOrig, weightsOrig, xsOrig, ysOrig, weightsOrig);
   else
-    math::ShuffleData(xsOrig, ysOrig, xsOrig, ysOrig);
+    ShuffleData(xsOrig, ysOrig, xsOrig, ysOrig);
 
   InitKFoldCVMat(xsOrig, xs);
   InitKFoldCVMat(ysOrig, ys);
@@ -441,7 +455,6 @@ arma::Row<ElementType> KFoldCV<MLAlgorithm,
       subsetSize, false, true);
 }
 
-} // namespace cv
 } // namespace mlpack
 
 #endif
