@@ -19,7 +19,6 @@
 #include <mlpack/core/math/random.hpp>
 
 namespace mlpack {
-namespace distribution /** Probability distributions. */ {
 
 /**
  * A discrete distribution where the only observations are discrete
@@ -31,10 +30,6 @@ namespace distribution /** Probability distributions. */ {
  * observation is passed (i.e. observation > numObservations), a crash will
  * probably occur.
  *
- * This distribution only supports one-dimensional observations, so when
- * passing an arma::vec as an observation, it should only have one dimension
- * (vec.n_rows == 1).  Any additional dimensions will simply be ignored.
- *
  * @note
  * This class, like every other class in mlpack, uses arma::vec to represent
  * observations.  While a discrete distribution only has positive integers
@@ -238,9 +233,9 @@ class DiscreteDistribution
    * Serialize the distribution.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(probabilities);
+    ar(CEREAL_NVP(probabilities));
   }
 
  private:
@@ -249,7 +244,9 @@ class DiscreteDistribution
   std::vector<arma::vec> probabilities;
 };
 
-} // namespace distribution
 } // namespace mlpack
 
+// Include implementation.
+#include "discrete_distribution_impl.hpp"
+
 #endif
