@@ -15,7 +15,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace kernel {
 
 /**
  * Hyperbolic tangent kernel.  For any two vectors @f$ x @f$, @f$ y @f$ and a
@@ -74,10 +73,10 @@ class HyperbolicTangentKernel
 
   //! Serialize the kernel.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(scale);
-    ar & BOOST_SERIALIZATION_NVP(offset);
+    ar(CEREAL_NVP(scale));
+    ar(CEREAL_NVP(offset));
   }
 
  private:
@@ -85,7 +84,6 @@ class HyperbolicTangentKernel
   double offset;
 };
 
-} // namespace kernel
 } // namespace mlpack
 
 #endif
