@@ -10,11 +10,9 @@
 #ifndef MLPACK_CORE_KERNELS_SPHERICAL_KERNEL_HPP
 #define MLPACK_CORE_KERNELS_SPHERICAL_KERNEL_HPP
 
-#include <boost/math/special_functions/gamma.hpp>
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace kernel {
 
 /**
  * The spherical kernel, which is 1 when the distance between the two argument
@@ -43,8 +41,7 @@ class SphericalKernel
   template<typename VecTypeA, typename VecTypeB>
   double Evaluate(const VecTypeA& a, const VecTypeB& b) const
   {
-    return
-        (metric::SquaredEuclideanDistance::Evaluate(a, b) <= bandwidthSquared) ?
+    return (SquaredEuclideanDistance::Evaluate(a, b) <= bandwidthSquared) ?
         1.0 : 0.0;
   }
   /**
@@ -56,12 +53,12 @@ class SphericalKernel
    * @tparam VecTypeB Type of second vector.
    * @param a First vector.
    * @param b Second vector.
-   * @return the convolution integral value.
+   * @return The convolution integral value.
    */
   template<typename VecTypeA, typename VecTypeB>
   double ConvolutionIntegral(const VecTypeA& a, const VecTypeB& b) const
   {
-    double distance = sqrt(metric::SquaredEuclideanDistance::Evaluate(a, b));
+    double distance = sqrt(SquaredEuclideanDistance::Evaluate(a, b));
     if (distance >= 2.0 * bandwidth)
     {
       return 0.0;
@@ -72,17 +69,14 @@ class SphericalKernel
     {
       case 1:
         return 1.0 / volumeSquared * (2.0 * bandwidth - distance);
-        break;
       case 2:
         return 1.0 / volumeSquared *
           (2.0 * bandwidth * bandwidth * acos(distance/(2.0 * bandwidth)) -
           distance / 4.0 * sqrt(4.0*bandwidth*bandwidth-distance*distance));
-        break;
       default:
         Log::Fatal << "The spherical kernel does not support convolution\
           integrals above dimension two, yet..." << std::endl;
         return -1.0;
-        break;
     }
   }
   double Normalizer(size_t dimension) const
@@ -107,10 +101,10 @@ class SphericalKernel
 
   //! Serialize the object.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(bandwidth);
-    ar & BOOST_SERIALIZATION_NVP(bandwidthSquared);
+    ar(CEREAL_NVP(bandwidth));
+    ar(CEREAL_NVP(bandwidthSquared));
   }
 
  private:
@@ -129,7 +123,6 @@ class KernelTraits<SphericalKernel>
   static const bool UsesSquaredDistance = false;
 };
 
-} // namespace kernel
 } // namespace mlpack
 
 #endif
