@@ -16,7 +16,6 @@
 #include "lmetric.hpp"
 
 namespace mlpack {
-namespace metric {
 
 // Unspecialized implementation.  This should almost never be used...
 template<int Power, bool TakeRoot>
@@ -26,7 +25,7 @@ typename VecTypeA::elem_type LMetric<Power, TakeRoot>::Evaluate(
     const VecTypeB& b)
 {
   typename VecTypeA::elem_type sum = 0;
-  for (size_t i = 0; i < a.n_elem; i++)
+  for (size_t i = 0; i < a.n_elem; ++i)
     sum += std::pow(fabs(a[i] - b[i]), Power);
 
   if (!TakeRoot) // The compiler should optimize this correctly at compile-time.
@@ -81,7 +80,7 @@ typename VecTypeA::elem_type LMetric<3, true>::Evaluate(
     const VecTypeB& b)
 {
   typename VecTypeA::elem_type sum = 0;
-  for (size_t i = 0; i < a.n_elem; i++)
+  for (size_t i = 0; i < a.n_elem; ++i)
     sum += std::pow(fabs(a[i] - b[i]), 3.0);
 
   return std::pow(arma::accu(arma::pow(arma::abs(a - b), 3.0)), 1.0 / 3.0);
@@ -106,7 +105,6 @@ typename VecTypeA::elem_type LMetric<INT_MAX, false>::Evaluate(
   return arma::as_scalar(arma::max(arma::abs(a - b)));
 }
 
-} // namespace metric
 } // namespace mlpack
 
 #endif
