@@ -19,7 +19,6 @@
 #include <mlpack/core/tree/perform_split.hpp>
 
 namespace mlpack {
-namespace tree /** Trees and tree-building procedures. */ {
 
 /**
  * A binary space partitioning tree node is split into its left and right child.
@@ -74,7 +73,7 @@ class MidpointSplit
                              const size_t count,
                              const SplitInfo& splitInfo)
   {
-    return split::PerformSplit<MatType, MidpointSplit>(data, begin, count,
+    return mlpack::PerformSplit<MatType, MidpointSplit>(data, begin, count,
         splitInfo);
   }
 
@@ -99,7 +98,7 @@ class MidpointSplit
                              const SplitInfo& splitInfo,
                              std::vector<size_t>& oldFromNew)
   {
-    return split::PerformSplit<MatType, MidpointSplit>(data, begin, count,
+    return mlpack::PerformSplit<MatType, MidpointSplit>(data, begin, count,
         splitInfo, oldFromNew);
   }
 
@@ -117,7 +116,6 @@ class MidpointSplit
   }
 };
 
-} // namespace tree
 } // namespace mlpack
 
 // Include implementation.
