@@ -16,7 +16,6 @@
 #include <queue>
 
 namespace mlpack {
-namespace tree {
 
 template<
     typename MetricType,
@@ -86,23 +85,25 @@ class CoverTree<MetricType, StatisticType, MatType, RootPointPolicy>::
   /**
    * Helper function for traversal of the two trees.
    */
-  void Traverse(CoverTree& queryNode,
-                std::map<int, std::vector<DualCoverTreeMapEntry> >&
-                    referenceMap);
+  void Traverse(
+      CoverTree& queryNode,
+      std::map<int, std::vector<DualCoverTreeMapEntry>,
+          std::greater<int>>& referenceMap);
 
   //! Prepare map for recursion.
-  void PruneMap(CoverTree& queryNode,
-                std::map<int, std::vector<DualCoverTreeMapEntry> >&
-                    referenceMap,
-                std::map<int, std::vector<DualCoverTreeMapEntry> >&
-                    childMap);
+  void PruneMap(
+      CoverTree& queryNode,
+      std::map<int, std::vector<DualCoverTreeMapEntry>,
+          std::greater<int>>& referenceMap,
+      std::map<int, std::vector<DualCoverTreeMapEntry>,
+          std::greater<int>>& childMap);
 
-  void ReferenceRecursion(CoverTree& queryNode,
-                          std::map<int, std::vector<DualCoverTreeMapEntry> >&
-                              referenceMap);
+  void ReferenceRecursion(
+      CoverTree& queryNode,
+    std::map<int, std::vector<DualCoverTreeMapEntry>,
+        std::greater<int>>& referenceMap);
 };
 
-} // namespace tree
 } // namespace mlpack
 
 // Include implementation.
