@@ -18,7 +18,6 @@
 #include "hrectbound.hpp"
 
 namespace mlpack {
-namespace bound {
 
 /**
  * Empty constructor.
@@ -37,7 +36,7 @@ inline HRectBound<MetricType, ElemType>::HRectBound() :
 template<typename MetricType, typename ElemType>
 inline HRectBound<MetricType, ElemType>::HRectBound(const size_t dimension) :
     dim(dimension),
-    bounds(new math::RangeType<ElemType>[dim]),
+    bounds(new RangeType<ElemType>[dim]),
     minWidth(0)
 { /* Nothing to do. */ }
 
@@ -48,11 +47,11 @@ template<typename MetricType, typename ElemType>
 inline HRectBound<MetricType, ElemType>::HRectBound(
     const HRectBound<MetricType, ElemType>& other) :
     dim(other.Dim()),
-    bounds(new math::RangeType<ElemType>[dim]),
+    bounds(new RangeType<ElemType>[dim]),
     minWidth(other.MinWidth())
 {
   // Copy other bounds over.
-  for (size_t i = 0; i < dim; i++)
+  for (size_t i = 0; i < dim; ++i)
     bounds[i] = other[i];
 }
 
@@ -65,6 +64,9 @@ inline HRectBound<
     ElemType>& HRectBound<MetricType,
     ElemType>::operator=(const HRectBound<MetricType, ElemType>& other)
 {
+  if (this == &other)
+    return *this;
+
   if (dim != other.Dim())
   {
     // Reallocation is necessary.
@@ -72,11 +74,11 @@ inline HRectBound<
       delete[] bounds;
 
     dim = other.Dim();
-    bounds = new math::RangeType<ElemType>[dim];
+    bounds = new RangeType<ElemType>[dim];
   }
 
   // Now copy each of the bound values.
-  for (size_t i = 0; i < dim; i++)
+  for (size_t i = 0; i < dim; ++i)
     bounds[i] = other[i];
 
   minWidth = other.MinWidth();
@@ -100,6 +102,26 @@ inline HRectBound<MetricType, ElemType>::HRectBound(
   other.minWidth = 0.0;
 }
 
+/**
+ * Move assignment operator.
+ */
+template<typename MetricType, typename ElemType>
+inline HRectBound<MetricType, ElemType>&
+HRectBound<MetricType, ElemType>::operator=(
+    HRectBound<MetricType, ElemType>&& other)
+{
+  if (this != &other)
+  {
+    bounds = other.bounds;
+    minWidth = other.minWidth;
+    dim = other.dim;
+    other.dim = 0;
+    other.bounds = nullptr;
+    other.minWidth = 0.0;
+  }
+  return *this;
+}
+
 /**
  * Destructor: clean up memory.
  */
@@ -116,8 +138,8 @@ inline HRectBound<MetricType, ElemType>::~HRectBound()
 template<typename MetricType, typename ElemType>
 inline void HRectBound<MetricType, ElemType>::Clear()
 {
-  for (size_t i = 0; i < dim; i++)
-    bounds[i] = math::RangeType<ElemType>();
+  for (size_t i = 0; i < dim; ++i)
+    bounds[i] = RangeType<ElemType>();
   minWidth = 0;
 }
 
@@ -134,7 +156,7 @@ inline void HRectBound<MetricType, ElemType>::Center(
   if (!(center.n_elem == dim))
     center.set_size(dim);
 
-  for (size_t i = 0; i < dim; i++)
+  for (size_t i = 0; i < dim; ++i)
     center(i) = bounds[i].Mid();
 }
 
@@ -227,8 +249,8 @@ ElemType HRectBound<MetricType, ElemType>::MinDistance(const HRectBound& other)
   Log::Assert(dim == other.dim);
 
   ElemType sum = 0;
-  const math::RangeType<ElemType>* mbound = bounds;
-  const math::RangeType<ElemType>* obound = other.bounds;
+  const RangeType<ElemType>* mbound = bounds;
+  const RangeType<ElemType>* obound = other.bounds;
 
   ElemType lower, higher;
   for (size_t d = 0; d < dim; d++)
@@ -364,7 +386,7 @@ inline ElemType HRectBound<MetricType, ElemType>::MaxDistance(
  * Calculates minimum and maximum bound-to-bound squared distance.
  */
 template<typename MetricType, typename ElemType>
-inline math::RangeType<ElemType>
+inline RangeType<ElemType>
 HRectBound<MetricType, ElemType>::RangeDistance(
     const HRectBound& other) const
 {
@@ -411,19 +433,19 @@ HRectBound<MetricType, ElemType>::RangeDistance(
   if (MetricType::TakeRoot)
   {
     if (MetricType::Power == 1)
-      return math::RangeType<ElemType>(loSum, hiSum);
+      return RangeType<ElemType>(loSum, hiSum);
     else if (MetricType::Power == 2)
-      return math::RangeType<ElemType>((ElemType) std::sqrt(loSum),
+      return RangeType<ElemType>((ElemType) std::sqrt(loSum),
                                        (ElemType) std::sqrt(hiSum));
     else
     {
-      return math::RangeType<ElemType>(
+      return RangeType<ElemType>(
           (ElemType) pow((double) loSum, 1.0 / (double) MetricType::Power),
           (ElemType) pow((double) hiSum, 1.0 / (double) MetricType::Power));
     }
   }
   else
-    return math::RangeType<ElemType>(loSum, hiSum);
+    return RangeType<ElemType>(loSum, hiSum);
 }
 
 /**
@@ -431,7 +453,7 @@ HRectBound<MetricType, ElemType>::RangeDistance(
  */
 template<typename MetricType, typename ElemType>
 template<typename VecType>
-inline math::RangeType<ElemType>
+inline RangeType<ElemType>
 HRectBound<MetricType, ElemType>::RangeDistance(
     const VecType& point,
     typename std::enable_if_t<IsVector<VecType>::value>* /* junk */) const
@@ -487,19 +509,19 @@ HRectBound<MetricType, ElemType>::RangeDistance(
   if (MetricType::TakeRoot)
   {
     if (MetricType::Power == 1)
-      return math::RangeType<ElemType>(loSum, hiSum);
+      return RangeType<ElemType>(loSum, hiSum);
     else if (MetricType::Power == 2)
-      return math::RangeType<ElemType>((ElemType) std::sqrt(loSum),
+      return RangeType<ElemType>((ElemType) std::sqrt(loSum),
                                        (ElemType) std::sqrt(hiSum));
     else
     {
-      return math::RangeType<ElemType>(
+      return RangeType<ElemType>(
           (ElemType) pow((double) loSum, 1.0 / (double) MetricType::Power),
           (ElemType) pow((double) hiSum, 1.0 / (double) MetricType::Power));
     }
   }
   else
-    return math::RangeType<ElemType>(loSum, hiSum);
+    return RangeType<ElemType>(loSum, hiSum);
 }
 
 /**
@@ -516,9 +538,9 @@ HRectBound<MetricType, ElemType>::operator|=(const MatType& data)
   arma::Col<ElemType> maxs(max(data, 1));
 
   minWidth = std::numeric_limits<ElemType>::max();
-  for (size_t i = 0; i < dim; i++)
+  for (size_t i = 0; i < dim; ++i)
   {
-    bounds[i] |= math::RangeType<ElemType>(mins[i], maxs[i]);
+    bounds[i] |= RangeType<ElemType>(mins[i], maxs[i]);
     const ElemType width = bounds[i].Width();
     if (width < minWidth)
       minWidth = width;
@@ -537,7 +559,7 @@ HRectBound<MetricType, ElemType>::operator|=(const HRectBound& other)
   assert(other.dim == dim);
 
   minWidth = std::numeric_limits<ElemType>::max();
-  for (size_t i = 0; i < dim; i++)
+  for (size_t i = 0; i < dim; ++i)
   {
     bounds[i] |= other.bounds[i];
     const ElemType width = bounds[i].Width();
@@ -556,7 +578,7 @@ template<typename VecType>
 inline bool HRectBound<MetricType, ElemType>::Contains(
     const VecType& point) const
 {
-  for (size_t i = 0; i < point.n_elem; i++)
+  for (size_t i = 0; i < point.n_elem; ++i)
   {
     if (!bounds[i].Contains(point(i)))
       return false;
@@ -572,10 +594,10 @@ template<typename MetricType, typename ElemType>
 inline bool HRectBound<MetricType, ElemType>::Contains(
     const HRectBound& bound) const
 {
-  for (size_t i = 0; i < dim; i++)
+  for (size_t i = 0; i < dim; ++i)
   {
-    const math::RangeType<ElemType>& r_a = bounds[i];
-    const math::RangeType<ElemType>& r_b = bound.bounds[i];
+    const RangeType<ElemType>& r_a = bounds[i];
+    const RangeType<ElemType>& r_b = bound.bounds[i];
 
     // If a does not overlap b at all.
     if (r_a.Hi() <= r_b.Lo() || r_a.Lo() >= r_b.Hi())
@@ -594,7 +616,7 @@ HRectBound<MetricType, ElemType>::operator&(const HRectBound& bound) const
 {
   HRectBound<MetricType, ElemType> result(dim);
 
-  for (size_t k = 0; k < dim; k++)
+  for (size_t k = 0; k < dim; ++k)
   {
     result[k].Lo() = std::max(bounds[k].Lo(), bound.bounds[k].Lo());
     result[k].Hi() = std::min(bounds[k].Hi(), bound.bounds[k].Hi());
@@ -609,7 +631,7 @@ template<typename MetricType, typename ElemType>
 inline HRectBound<MetricType, ElemType>&
 HRectBound<MetricType, ElemType>::operator&=(const HRectBound& bound)
 {
-  for (size_t k = 0; k < dim; k++)
+  for (size_t k = 0; k < dim; ++k)
   {
     bounds[k].Lo() = std::max(bounds[k].Lo(), bound.bounds[k].Lo());
     bounds[k].Hi() = std::min(bounds[k].Hi(), bound.bounds[k].Hi());
@@ -626,7 +648,7 @@ inline ElemType HRectBound<MetricType, ElemType>::Overlap(
 {
   ElemType volume = 1.0;
 
-  for (size_t k = 0; k < dim; k++)
+  for (size_t k = 0; k < dim; ++k)
   {
     ElemType lo = std::max(bounds[k].Lo(), bound.bounds[k].Lo());
     ElemType hi = std::min(bounds[k].Hi(), bound.bounds[k].Hi());
@@ -661,26 +683,14 @@ template<typename MetricType, typename ElemType>
 template<typename Archive>
 void HRectBound<MetricType, ElemType>::serialize(
     Archive& ar,
-    const unsigned int /* version */)
+    const uint32_t /* version */)
 {
-  ar & BOOST_SERIALIZATION_NVP(dim);
-
-  // Allocate memory for the bounds, if necessary.
-  if (Archive::is_loading::value)
-  {
-    if (bounds)
-      delete[] bounds;
-    bounds = new math::RangeType<ElemType>[dim];
-  }
-
   // We can't serialize a raw array directly, so wrap it.
-  auto boundsArray = boost::serialization::make_array(bounds, dim);
-  ar & BOOST_SERIALIZATION_NVP(boundsArray);
-  ar & BOOST_SERIALIZATION_NVP(minWidth);
-  ar & BOOST_SERIALIZATION_NVP(metric);
+  ar(CEREAL_POINTER_ARRAY(bounds, dim));
+  ar(CEREAL_NVP(minWidth));
+  ar(CEREAL_NVP(metric));
 }
 
-} // namespace bound
 } // namespace mlpack
 
 #endif // MLPACK_CORE_TREE_HRECTBOUND_IMPL_HPP
