@@ -15,7 +15,6 @@
 #define MLPACK_CORE_TREE_RECTANGLE_TREE_HR_TREE_AUXILIARY_INFO_HPP
 
 namespace mlpack {
-namespace tree {
 
 template<typename TreeType,
          template<typename> class HilbertValueType>
@@ -139,10 +138,9 @@ class HilbertRTreeAuxiliaryInformation
    * Serialize the information.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 };
 
-} // namespace tree
 } // namespace mlpack
 
 #include "hilbert_r_tree_auxiliary_information_impl.hpp"
