@@ -17,7 +17,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * This class is used to initialize weight matrix with constant values.
@@ -41,7 +40,23 @@ class ConstInitialization
   template<typename eT>
   void Initialize(arma::Mat<eT>& W, const size_t rows, const size_t cols)
   {
-    W.set_size(rows, cols);
+    if (W.is_empty())
+      W.set_size(rows, cols);
+
+    W.fill(initVal);
+  }
+
+  /**
+   * Initialize the elements of the specified weight matrix.
+   *
+   * @param W Weight matrix to initialize.
+   */
+  template<typename eT>
+  void Initialize(arma::Mat<eT>& W)
+  {
+    if (W.is_empty())
+      Log::Fatal << "Cannot initialize an empty matrix." << std::endl;
+
     W.fill(initVal);
   }
 
@@ -59,21 +74,42 @@ class ConstInitialization
                   const size_t cols,
                   const size_t slices)
   {
-    W.set_size(rows, cols, slices);
+    if (W.is_empty())
+      W.set_size(rows, cols, slices);
+
+    W.fill(initVal);
+  }
+
+  /**
+   * Initialize the elements of the specified weight (3rd order tensor).
+   *
+   * @param W Weight matrix to initialize.
+   */
+  template<typename eT>
+  void Initialize(arma::Cube<eT>& W)
+  {
+    if (W.is_empty())
+      Log::Fatal << "Cannot initialize an empty cube." << std::endl;
+
     W.fill(initVal);
   }
 
   //! Get the initialization value.
   double const& InitValue() const { return initVal; }
   //! Modify the initialization value.
-  double& initValue() { return initVal; }
+  double& InitValue() { return initVal; }
+
+  template<typename Archive>
+  void serialize(Archive& ar, const uint32_t /* version */)
+  {
+    ar(CEREAL_NVP(initVal));
+  }
 
  private:
   //! Value to be initialized with
   double initVal;
 }; // class ConstInitialization
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
