@@ -20,7 +20,6 @@
 #include <mlpack/core/math/random.hpp>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * This class is used to initialize weight matrix with the He
@@ -136,9 +135,14 @@ class HeInitialization
     for (size_t i = 0; i < W.n_slices; ++i)
       Initialize(W.slice(i));
   }
+
+  template<typename Archive>
+  void serialize(Archive& /* ar */, const uint32_t /* version */)
+  {
+    // Nothing to do.
+  }
 }; // class HeInitialization
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
