@@ -37,7 +37,6 @@
 #include <iostream>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * This class is used to initialize the weight matrix with the method proposed
@@ -90,6 +89,21 @@ class KathirvalavakumarSubavathiInitialization
     randomInit.Initialize(W, rows, cols);
   }
 
+  /**
+   * Initialize the elements of the specified weight matrix with the
+   * Kathirvalavakumar-Subavathi method.
+   *
+   * @param W Weight matrix to initialize.
+   */
+  template<typename eT>
+  void Initialize(arma::Mat<eT>& W)
+  {
+    arma::Row<eT> b = s * arma::sqrt(3 / (W.n_rows * dataSum));
+    const double theta = b.min();
+    RandomInitialization randomInit(-theta, theta);
+    randomInit.Initialize(W);
+  }
+
   /**
    * Initialize the elements of the specified weight 3rd order tensor with the
    * Kathirvalavakumar-Subavathi method.
@@ -105,12 +119,39 @@ class KathirvalavakumarSubavathiInitialization
                   const size_t cols,
                   const size_t slices)
   {
-    W = arma::Cube<eT>(rows, cols, slices);
+    if (W.is_empty())
+      W.set_size(rows, cols, slices);
 
-    for (size_t i = 0; i < slices; i++)
+    for (size_t i = 0; i < slices; ++i)
       Initialize(W.slice(i), rows, cols);
   }
 
+  /**
+   * Initialize the elements of the specified weight 3rd order tensor with the
+   * Kathirvalavakumar-Subavathi method.
+   *
+   * @param W Weight matrix to initialize.
+   */
+  template<typename eT>
+  void Initialize(arma::Cube<eT>& W)
+  {
+    if (W.is_empty())
+      Log::Fatal << "Cannot initialize an empty cube." << std::endl;
+
+    for (size_t i = 0; i < W.n_slices; ++i)
+      Initialize(W.slice(i));
+  }
+ 
+  /**
+   * Serialize the initialization.
+   */
+  template<typename Archive>
+  void serialize(Archive& ar, const uint32_t /* version */)
+  {
+    ar(CEREAL_NVP(dataSum));
+    ar(CEREAL_NVP(s));
+  }
+
  private:
   //! Parameter that defines the sum of elements in each column.
   arma::rowvec dataSum;
@@ -130,7 +171,6 @@ class InitTraits<KathirvalavakumarSubavathiInitialization>
 };
 
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
