@@ -19,7 +19,6 @@
 #include <mlpack/core/math/random.hpp>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * This class is used to initialize weight matrix with the Lecun Normalization
@@ -65,7 +64,8 @@ class LecunNormalInitialization
    * @param rows Number of rows.
    * @param cols Number of columns.
    */
-  void Initialize(arma::mat& W,
+  template <typename eT>
+  void Initialize(arma::Mat<eT>& W,
                   const size_t rows,
                   const size_t cols)
   {
@@ -75,9 +75,29 @@ class LecunNormalInitialization
     const double variance = 1.0 / ((double) rows);
 
     if (W.is_empty())
-    {
       W.set_size(rows, cols);
-    }
+
+    // Multipling a random variable X with variance V(X) by some factor c,
+    // then the variance V(cX) = (c ^ 2) * V(X).
+    W.imbue( [&]() { return sqrt(variance) * arma::randn(); } );
+  }
+
+  /**
+   * Initialize the elements of the weight matrix with the Lecun
+   * Normal initialization rule.
+   *
+   * @param W Weight matrix to initialize.
+   */
+  template <typename eT>
+  void Initialize(arma::Mat<eT>& W)
+  {
+    // He initialization rule says to initialize weights with random
+    // values taken from a gaussian distribution with mean = 0 and
+    // standard deviation = sqrt(1 / rows), i.e. variance = (1 / rows).
+    const double variance = 1.0 / (double) W.n_rows;
+
+    if (W.is_empty())
+      Log::Fatal << "Cannot initialize an empty matrix." << std::endl;
 
     // Multipling a random variable X with variance V(X) by some factor c,
     // then the variance V(cX) = (c ^ 2) * V(X).
@@ -93,7 +113,8 @@ class LecunNormalInitialization
    * @param cols Number of columns.
    * @param slices Number of slices.
    */
-  void Initialize(arma::cube & W,
+  template <typename eT>
+  void Initialize(arma::Cube<eT> & W,
                   const size_t rows,
                   const size_t cols,
                   const size_t slices)
@@ -101,12 +122,33 @@ class LecunNormalInitialization
     if (W.is_empty())
       W.set_size(rows, cols, slices);
 
-    for (size_t i = 0; i < slices; i++)
+    for (size_t i = 0; i < slices; ++i)
       Initialize(W.slice(i), rows, cols);
   }
+
+  /**
+   * Initialize the elements of the specified weight 3rd order tensor
+   * with Lecun Normal initialization rule.
+   *
+   * @param W Weight matrix to initialize.
+   */
+  template <typename eT>
+  void Initialize(arma::Cube<eT> & W)
+  {
+    if (W.is_empty())
+      Log::Fatal << "Cannot initialize an empty cube." << std::endl;
+
+    for (size_t i = 0; i < W.n_slices; ++i)
+      Initialize(W.slice(i));
+  }
+
+  /**
+   * Serialize the initialization.  (Nothing to serialize for this one.)
+   */
+  template<typename Archive>
+  void serialize(Archive& /* ar */, const uint32_t /* version */) { }
 }; // class LecunNormalInitialization
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
