@@ -33,7 +33,6 @@
 #include "random_init.hpp"
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * This class is used to initialize the weight matrix with the oivs method. The
@@ -47,15 +46,13 @@ namespace ann /** Artificial Neural Network. */ {
  * w_i &=& \hat{w} \cdot \sqrt{a_i + 1}
  * @f}
  *
- * Where f is the transfer function epsilon, k custom parameters, n the number of
- * neurons in the outgoing layer and gamma a parameter that defines the random
- * interval.
+ * Where f is the transfer function epsilon, k custom parameters, n the number
+ * of neurons in the outgoing layer and gamma a parameter that defines the
+ * random interval.
  *
  * @tparam ActivationFunction The activation function used for the oivs method.
  */
-template<
-    class ActivationFunction = LogisticFunction
->
+template<class ActivationFunction = LogisticFunction>
 class OivsInitialization
 {
  public:
@@ -155,7 +152,6 @@ class OivsInitialization
 }; // class OivsInitialization
 
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
