@@ -1,7 +1,7 @@
 /**
- * @file layer_norm.hpp
+ * @file methods/ann/layer/layer_norm.hpp
  * @author Shikhar Jaiswal
- *
+ * @author Adam Kropp
  * Definition of the Layer Normalization class.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
@@ -15,7 +15,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * Declaration of the Layer Normalization class. The layer transforms
@@ -53,33 +52,24 @@ namespace ann /** Artificial Neural Network. */ {
  * }
  * @endcode
  *
- * @tparam InputDataType Type of the input data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
- * @tparam OutputDataType Type of the output data (arma::colvec, arma::mat,
+ * @tparam MatType Type of the input data (arma::colvec, arma::mat,
  *         arma::sp_mat or arma::cube).
  */
 template <
-  typename InputDataType = arma::mat,
-  typename OutputDataType = arma::mat
+  typename MatType = arma::mat
 >
-class LayerNorm
+class LayerNormType : public Layer<MatType>
 {
  public:
-  //! Create the LayerNorm object.
-  LayerNorm();
-
   /**
    * Create the LayerNorm object for a specified number of input units.
    *
-   * @param size The number of input units.
    * @param eps The epsilon added to variance to ensure numerical stability.
    */
-  LayerNorm(const size_t size, const double eps = 1e-8);
+  LayerNormType(const double eps = 1e-8);
 
-  /**
-   * Reset the layer parameters.
-   */
-  void Reset();
+  //! Clone the LayerNormType object. This handles polymorphism correctly.
+  LayerNormType* Clone() const override { return new LayerNormType(*this); }
 
   /**
    * Forward pass of Layer Normalization. Transforms the input data
@@ -89,20 +79,20 @@ class LayerNorm
    * @param input Input data for the layer.
    * @param output Resulting output activations.
    */
-  template<typename eT>
-  void Forward(const arma::Mat<eT>& input, arma::Mat<eT>& output);
+  void Forward(const MatType& input, MatType& output) override;
 
   /**
    * Backward pass through the layer.
    *
-   * @param input The input activations.
+   * @param input The input data (x) given to the forward pass.
+   * @param output The propagated data (f(x)) resulting from Forward()
    * @param gy The backpropagated error.
    * @param g The calculated gradient.
    */
-  template<typename eT>
-  void Backward(const arma::Mat<eT>& input,
-                const arma::Mat<eT>& gy,
-                arma::Mat<eT>& g);
+  void Backward(const MatType& /* input */,
+                const MatType& /* output */,
+                const MatType& gy,
+                MatType& g) override;
 
   /**
    * Calculate the gradient using the output delta and the input activations.
@@ -111,85 +101,83 @@ class LayerNorm
    * @param error The calculated error.
    * @param gradient The calculated gradient.
    */
-  template<typename eT>
-  void Gradient(const arma::Mat<eT>& input,
-                const arma::Mat<eT>& error,
-                arma::Mat<eT>& gradient);
+  void Gradient(const MatType& input,
+                const MatType& error,
+                MatType& gradient) override;
 
   //! Get the parameters.
-  OutputDataType const& Parameters() const { return weights; }
+  MatType const& Parameters() const override { return weights; }
   //! Modify the parameters.
-  OutputDataType& Parameters() { return weights; }
-
-  //! Get the output parameter.
-  OutputDataType const& OutputParameter() const { return outputParameter; }
-  //! Modify the output parameter.
-  OutputDataType& OutputParameter() { return outputParameter; }
-
-  //! Get the delta.
-  OutputDataType const& Delta() const { return delta; }
-  //! Modify the delta.
-  OutputDataType& Delta() { return delta; }
-
-  //! Get the gradient.
-  OutputDataType const& Gradient() const { return gradient; }
-  //! Modify the gradient.
-  OutputDataType& Gradient() { return gradient; }
+  MatType& Parameters() override { return weights; }
 
   //! Get the mean across single training data.
-  OutputDataType Mean() { return mean; }
+  MatType Mean() { return mean; }
 
   //! Get the variance across single training data.
-  OutputDataType Variance() { return variance; }
+  MatType Variance() { return variance; }
+
+  //! Get the number of input units.
+  size_t InSize() const { return size; }
+
+  //! Get the value of epsilon.
+  double Epsilon() const { return eps; }
+
+  size_t WeightSize() const override { return 2 * size; }
+
+  void ComputeOutputDimensions() override
+  {
+    // The default implementation is to assume that the output size is the same
+    // as the input.
+    this->outputDimensions = this->inputDimensions;
+    size = this->inputDimensions[0];
+    for (size_t i = 1; i < this->inputDimensions.size(); i++)
+      size *= this->inputDimensions[i];
+  }
+
+  void SetWeights(typename MatType::elem_type* /* weightsPtr */) override;
+
+  void CustomInitialize(
+      MatType& /* W */,
+      const size_t /* elements */) override;
 
   /**
    * Serialize the layer.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
-  //! Locally-stored number of input units.
-  size_t size;
-
   //! Locally-stored epsilon value.
   double eps;
 
-  //! Variable to keep track of whether we are in loading or saving mode.
-  bool loading;
+  // Cached size for the normalization.
+  size_t size;
 
   //! Locally-stored scale parameter.
-  OutputDataType gamma;
+  MatType gamma;
 
   //! Locally-stored shift parameter.
-  OutputDataType beta;
+  MatType beta;
 
   //! Locally-stored parameters.
-  OutputDataType weights;
+  MatType weights;
 
   //! Locally-stored mean object.
-  OutputDataType mean;
+  MatType mean;
 
   //! Locally-stored variance object.
-  OutputDataType variance;
-
-  //! Locally-stored gradient object.
-  OutputDataType gradient;
-
-  //! Locally-stored delta object.
-  OutputDataType delta;
-
-  //! Locally-stored output parameter object.
-  OutputDataType outputParameter;
+  MatType variance;
 
   //! Locally-stored normalized input.
-  OutputDataType normalized;
+  MatType normalized;
 
   //! Locally-stored zero mean input.
-  OutputDataType inputMean;
-}; // class LayerNorm
+  MatType inputMean;
+}; // class LayerNormType
+
+// Standard LayerNorm type
+typedef LayerNormType<arma::mat> LayerNorm;
 
-} // namespace ann
 } // namespace mlpack
 
 // Include the implementation.
