@@ -16,8 +16,9 @@
 
 #include <mlpack/prereqs.hpp>
 
+#include "layer.hpp"
+
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * The LeakyReLU activation function, defined by
@@ -32,16 +33,11 @@ namespace ann /** Artificial Neural Network. */ {
  * \right.
  * @f}
  *
- * @tparam InputDataType Type of the input data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
- * @tparam OutputDataType Type of the output data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
+ * @tparam MatType Matrix representation to accept as input and use for
+ *    computation.
  */
-template <
-    typename InputDataType = arma::mat,
-    typename OutputDataType = arma::mat
->
-class LeakyReLU
+template<typename MatType = arma::mat>
+class LeakyReLUType : public Layer<MatType>
 {
  public:
   /**
@@ -49,9 +45,24 @@ class LeakyReLU
    * The non zero gradient can be adjusted by specifying the parameter
    * alpha in the range 0 to 1. Default (alpha = 0.03)
    *
-   * @param alpha Non zero gradient
+   * @param alpha Non zero gradient.
    */
-  LeakyReLU(const double alpha = 0.03);
+  LeakyReLUType(const typename MatType::elem_type alpha = 0.03);
+
+  //! Clone the LeakyReLUType object. This handles polymorphism correctly.
+  LeakyReLUType* Clone() const { return new LeakyReLUType(*this); }
+
+  // Virtual destructor.
+  virtual ~LeakyReLUType() { }
+
+  //! Copy the given LeakyReLUType.
+  LeakyReLUType(const LeakyReLUType& other);
+  //! Take ownership of the given LeakyReLUType.
+  LeakyReLUType(LeakyReLUType&& other);
+  //! Copy the given LeakyReLUType.
+  LeakyReLUType& operator=(const LeakyReLUType& other);
+  //! Take ownership of the given LeakyReLUType.
+  LeakyReLUType& operator=(LeakyReLUType&& other);
 
   /**
    * Ordinary feed forward pass of a neural network, evaluating the function
@@ -60,54 +71,43 @@ class LeakyReLU
    * @param input Input data used for evaluating the specified function.
    * @param output Resulting output activation.
    */
-  template<typename InputType, typename OutputType>
-  void Forward(const InputType& input, OutputType& output);
+  void Forward(const MatType& input, MatType& output);
 
   /**
    * Ordinary feed backward pass of a neural network, calculating the function
    * f(x) by propagating x backwards through f. Using the results from the feed
    * forward pass.
    *
-   * @param input The propagated input activation.
+   * @param input The input data (x) given to the forward pass.
+   * @param output The propagated data (f(x)) resulting from Forward()
    * @param gy The backpropagated error.
    * @param g The calculated gradient.
    */
-  template<typename DataType>
-  void Backward(const DataType& input, const DataType& gy, DataType& g);
-
-  //! Get the output parameter.
-  OutputDataType const& OutputParameter() const { return outputParameter; }
-  //! Modify the output parameter.
-  OutputDataType& OutputParameter() { return outputParameter; }
-
-  //! Get the delta.
-  OutputDataType const& Delta() const { return delta; }
-  //! Modify the delta.
-  OutputDataType& Delta() { return delta; }
+  void Backward(const MatType& input,
+                const MatType& /* output */,
+                const MatType& gy,
+                MatType& g);
 
   //! Get the non zero gradient.
-  double const& Alpha() const { return alpha; }
+  typename MatType::elem_type const& Alpha() const { return alpha; }
   //! Modify the non zero gradient.
-  double& Alpha() { return alpha; }
+  typename MatType::elem_type& Alpha() { return alpha; }
 
-  /**
-   * Serialize the layer.
-   */
+  //! Serialize the layer.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
-  //! Locally-stored delta object.
-  OutputDataType delta;
-
-  //! Locally-stored output parameter object.
-  OutputDataType outputParameter;
-
   //! Leakyness Parameter in the range 0 <alpha< 1
-  double alpha;
-}; // class LeakyReLU
+  typename MatType::elem_type alpha;
+}; // class LeakyReLUType
+
+// Convenience typedefs.
+
+// Standard LeakyReLU layer.
+typedef LeakyReLUType<arma::mat> LeakyReLU;
+
 
-} // namespace ann
 } // namespace mlpack
 
 // Include implementation.
