@@ -1,5 +1,5 @@
 /**
- * @file parametric_relu.hpp
+ * @file methods/ann/layer/parametric_relu.hpp
  * @author Prasanna Patil
  *
  * Definition of PReLU layer first introduced in the,
@@ -12,13 +12,14 @@
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef MLPACK_METHODS_ANN_LAYER_PReLU_HPP
-#define MLPACK_METHODS_ANN_LAYER_PReLU_HPP
+#ifndef MLPACK_METHODS_ANN_LAYER_PRELU_HPP
+#define MLPACK_METHODS_ANN_LAYER_PRELU_HPP
 
 #include <mlpack/prereqs.hpp>
 
+#include "layer.hpp"
+
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * The PReLU activation function, defined by (where alpha is trainable)
@@ -33,16 +34,12 @@ namespace ann /** Artificial Neural Network. */ {
  * \right.
  * @f}
  *
- * @tparam InputDataType Type of the input data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
- * @tparam OutputDataType Type of the output data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
+ * @tparam MatType Matrix representation to accept as input and allows the
+ *         computation and weight type to differ from the input type
+ *         (Default: arma::mat).
  */
-template <
-    typename InputDataType = arma::mat,
-    typename OutputDataType = arma::mat
->
-class PReLU
+template<typename MatType = arma::mat>
+class PReLUType : public Layer<MatType>
 {
  public:
   /**
@@ -51,14 +48,37 @@ class PReLU
    * alpha in the range 0 to 1. Default (alpha = 0.03). This parameter
    * is trainable.
    *
-   * @param alpha Non zero gradient
+   * @param userAlpha Non zero gradient
    */
-  PReLU(const double userAlpha = 0.03);
+  PReLUType(const double userAlpha = 0.03);
 
-  /*
-   * Reset the layer parameter.
+  //! Clone the PReLUType object. This handles polymorphism correctly.
+  PReLUType* Clone() const { return new PReLUType(*this); }
+
+  // Virtual destructor.
+  virtual ~PReLUType() { }
+
+  //! Copy the given PReLUType.
+  PReLUType(const PReLUType& other);
+  //! Take ownership of the given PReLUType.
+  PReLUType(PReLUType&& other);
+  //! Copy the given PReLUType.
+  PReLUType& operator=(const PReLUType& other);
+  //! Take ownership of the given PReLUType.
+  PReLUType& operator=(PReLUType&& other);
+
+  //! Reset the layer parameter.
+  void SetWeights(typename MatType::elem_type* weightsPtr);
+
+  /**
+   * Initialize the weight matrix of the layer.
+   *
+   * @param W Weight matrix to initialize.
+   * @param elements Number of elements.
    */
-  void Reset();
+  void CustomInitialize(
+      MatType& W,
+      const size_t elements);
 
   /**
    * Ordinary feed forward pass of a neural network, evaluating the function
@@ -67,20 +87,22 @@ class PReLU
    * @param input Input data used for evaluating the specified function.
    * @param output Resulting output activation.
    */
-  template<typename InputType, typename OutputType>
-  void Forward(const InputType& input, OutputType& output);
+  void Forward(const MatType& input, MatType& output);
 
   /**
    * Ordinary feed backward pass of a neural network, calculating the function
    * f(x) by propagating x backwards through f. Using the results from the feed
    * forward pass.
    *
-   * @param input The propagated input activation.
+   * @param input The input data (x) given to the forward pass.
+   * @param output The propagated data (f(x)) resulting from Forward()
    * @param gy The backpropagated error.
    * @param g The calculated gradient.
    */
-  template<typename DataType>
-  void Backward(const DataType& input, const DataType& gy, DataType& g);
+  void Backward(const MatType& input,
+                const MatType& /* output */,
+                const MatType& gy,
+                MatType& g);
 
   /**
    * Calculate the gradient using the output delta and the input activation.
@@ -89,60 +111,42 @@ class PReLU
    * @param error The calculated error.
    * @param gradient The calculated gradient.
    */
-  template<typename eT>
-  void Gradient(const arma::Mat<eT>& input,
-                const arma::Mat<eT>& error,
-                arma::Mat<eT>& gradient);
+  void Gradient(const MatType& input,
+                const MatType& error,
+                MatType& gradient);
 
   //! Get the parameters.
-  OutputDataType const& Parameters() const { return alpha; }
+  MatType const& Parameters() const { return alpha; }
   //! Modify the parameters.
-  OutputDataType& Parameters() { return alpha; }
-
-  //! Get the output parameter.
-  OutputDataType const& OutputParameter() const { return outputParameter; }
-  //! Modify the output parameter.
-  OutputDataType& OutputParameter() { return outputParameter; }
-
-  //! Get the delta.
-  OutputDataType const& Delta() const { return delta; }
-  //! Modify the delta.
-  OutputDataType& Delta() { return delta; }
-
-  //! Get the gradient.
-  OutputDataType const& Gradient() const { return gradient; }
-  //! Modify the gradient.
-  OutputDataType& Gradient() { return gradient; }
+  MatType& Parameters() { return alpha; }
 
   //! Get the non zero gradient.
   double const& Alpha() const { return alpha(0); }
   //! Modify the non zero gradient.
   double& Alpha() { return alpha(0); }
 
+  //! Get size of weights.
+  size_t WeightSize() const { return 1; }
+
   /**
    * Serialize the layer.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
-  //! Locally-stored delta object.
-  OutputDataType delta;
-
-  //! Locally-stored output parameter object.
-  OutputDataType outputParameter;
-
   //! Leakyness Parameter object.
-  OutputDataType alpha;
-
-  //! Locally-stored gradient object.
-  OutputDataType gradient;
+  MatType alpha;
 
   //! Leakyness Parameter given by user in the range 0 < alpha < 1.
   double userAlpha;
 }; // class PReLU
 
-} // namespace ann
+// Convenience typedefs.
+
+// Standard PReLU layer.
+typedef PReLUType<arma::mat> PReLU;
+
 } // namespace mlpack
 
 // Include implementation.
