@@ -98,17 +98,17 @@ void PReLUType<MatType>::Forward(
     const MatType& input, MatType& output)
 {
   output = input;
-  if (this->training)
-  {
-    #pragma omp for
-    for (size_t i = 0; i < input.n_elem; ++i)
-      output(i) *= (input(i) >= 0) ? 1 : alpha(0);
-  }
+  #pragma omp for
+  for (size_t i = 0; i < input.n_elem; ++i)
+    output(i) *= (input(i) >= 0) ? 1 : alpha(0);
 }
 
 template<typename MatType>
 void PReLUType<MatType>::Backward(
-    const MatType& input, const MatType& gy, MatType& g)
+    const MatType& input,
+    const MatType& /* output */,
+    const MatType& gy,
+    MatType& g)
 {
   MatType derivative;
   derivative.set_size(arma::size(input));
