@@ -1,5 +1,5 @@
 /**
- * @file dice_loss.hpp
+ * @file methods/ann/loss_functions/dice_loss.hpp
  * @author N Rajiv Vaidyanathan
  *
  * Definition of the dice loss function.
@@ -15,7 +15,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * The dice loss performance function measures the network's
@@ -24,6 +23,7 @@ namespace ann /** Artificial Neural Network. */ {
  *
  * For more information see the following.
  *
+ * @code
  * @article{Milletari2016,
  *   author    = {Fausto Milletari and Nassir Navab and Seyed{-}Ahmad Ahmadi},
  *   title     = {V-Net: Fully Convolutional Neural Networks for
@@ -35,52 +35,43 @@ namespace ann /** Artificial Neural Network. */ {
  *   archivePrefix = {arXiv},
  *   eprint    = {1606.04797},
  * }
+ * @endcode
  *
- * @tparam InputDataType Type of the input data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
- * @tparam OutputDataType Type of the output data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
+ * @tparam MatType Matrix representation to accept as input and use for
+ *    computation.
  */
-template <
-    typename InputDataType = arma::mat,
-    typename OutputDataType = arma::mat
->
-class DiceLoss
+template<typename MatType = arma::mat>
+class DiceLossType
 {
  public:
   /**
-   * Create the DiceLoss object.
+   * Create the DiceLossType object.
    *
    * @param smooth The Laplace smoothing parameter.
    */
-  DiceLoss(const double smooth = 1);
+  DiceLossType(const double smooth = 1);
 
   /**
    * Computes the dice loss function.
    *
-   * @param input Input data used for evaluating the specified function.
+   * @param prediction Predictions used for evaluating the specified loss
+   *     function.
    * @param target The target vector.
    */
-  template<typename InputType, typename TargetType>
-  typename InputType::elem_type Forward(const InputType& input,
-                                        const TargetType& target);
+  typename MatType::elem_type Forward(const MatType& prediction,
+                                      const MatType& target);
 
   /**
    * Ordinary feed backward pass of a neural network.
    *
-   * @param input The propagated input activation.
+   * @param prediction Predictions used for evaluating the specified loss
+   *     function.
    * @param target The target vector.
-   * @param output The calculated error.
+   * @param loss The calculated error.
    */
-  template<typename InputType, typename TargetType, typename OutputType>
-  void Backward(const InputType& input,
-                const TargetType& target,
-                OutputType& output);
-
-  //! Get the output parameter.
-  OutputDataType& OutputParameter() const { return outputParameter; }
-  //! Modify the output parameter.
-  OutputDataType& OutputParameter() { return outputParameter; }
+  void Backward(const MatType& prediction,
+                const MatType& target,
+                MatType& loss);
 
   //! Get the smooth.
   double Smooth() const { return smooth; }
@@ -91,17 +82,16 @@ class DiceLoss
    * Serialize the layer.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
-  //! Locally-stored output parameter object.
-  OutputDataType outputParameter;
-
   //! The parameter to avoid overfitting.
   double smooth;
-}; // class DiceLoss
+}; // class DiceLossType
+
+// Default typedef for typical `arma::mat` usage.
+typedef DiceLossType<arma::mat> DiceLoss;
 
-} // namespace ann
 } // namespace mlpack
 
 // Include implementation.
