@@ -16,7 +16,6 @@
 #include "lregularizer.hpp"
 
 namespace mlpack {
-namespace ann {
 
 template<int Power>
 LRegularizer<Power>::LRegularizer(double factor) :
@@ -38,7 +37,7 @@ template<>
 template<typename MatType>
 void LRegularizer<1>::Evaluate(const MatType& weight, MatType& gradient)
 {
-  gradient += arma::vectorise(factor * weight / arma::abs(weight));
+  gradient += arma::vectorise(factor * arma::sign(weight));
 }
 
 // L2-Regularizer specializations.
@@ -52,12 +51,11 @@ void LRegularizer<2>::Evaluate(const MatType& weight, MatType& gradient)
 template<int Power>
 template<typename Archive>
 void LRegularizer<Power>::serialize(
-    Archive& ar, const unsigned int /* version */)
+    Archive& ar, const uint32_t /* version */)
 {
-  ar & BOOST_SERIALIZATION_NVP(factor);
+  ar(CEREAL_NVP(factor));
 }
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
