@@ -15,7 +15,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace cf {
 
 /**
  * Implementation of regression-based interpolation method. Predicting a user's
@@ -126,11 +125,11 @@ class RegressionInterpolation
       return;
     }
 
-    for (size_t i = 0; i < neighborNum; i++)
+    for (size_t i = 0; i < neighborNum; ++i)
     {
       // Calculate coefficient.
       arma::vec iPrediction;
-      for (size_t j = i; j < neighborNum; j++)
+      for (size_t j = i; j < neighborNum; ++j)
       {
         if (a(neighbors(i), neighbors(j)) != 0)
         {
@@ -182,7 +181,6 @@ class RegressionInterpolation
   arma::sp_mat b;
 };
 
-} // namespace cf
 } // namespace mlpack
 
 #endif
