@@ -17,7 +17,6 @@
 #include "svd_wrapper.hpp"
 
 namespace mlpack {
-namespace cf {
 
 template<class Factorizer>
 double SVDWrapper<Factorizer>::Apply(const arma::mat& V,
@@ -32,7 +31,7 @@ double SVDWrapper<Factorizer>::Apply(const arma::mat& V,
   // construct sigma matrix
   sigma.zeros(V.n_rows, V.n_cols);
 
-  for (size_t i = 0; i < sigma.n_rows && i < sigma.n_cols; i++)
+  for (size_t i = 0; i < sigma.n_rows && i < sigma.n_cols; ++i)
     sigma(i, i) = E(i, 0);
 
   arma::mat V_rec = W * sigma * arma::trans(H);
@@ -54,7 +53,7 @@ double SVDWrapper<DummyClass>::Apply(const arma::mat& V,
   // construct sigma matrix
   sigma.zeros(V.n_rows, V.n_cols);
 
-  for (size_t i = 0; i < sigma.n_rows && i < sigma.n_cols; i++)
+  for (size_t i = 0; i < sigma.n_rows && i < sigma.n_cols; ++i)
     sigma(i, i) = E(i, 0);
 
   arma::mat V_rec = W * sigma * arma::trans(H);
@@ -145,7 +144,6 @@ double SVDWrapper<DummyClass>::Apply(const arma::mat& V,
   return arma::norm(V - V_rec, "fro") / arma::norm(V, "fro");
 }
 
-} // namespace cf
 } // namespace mlpack
 
 #endif
