@@ -1,5 +1,5 @@
 /**
- * @file decision_tree.hpp
+ * @file methods/decision_tree/decision_tree.hpp
  * @author Ryan Curtin
  *
  * A generic decision tree learner.  Its behavior can be controlled via template
@@ -13,16 +13,23 @@
 #ifndef MLPACK_METHODS_DECISION_TREE_DECISION_TREE_HPP
 #define MLPACK_METHODS_DECISION_TREE_DECISION_TREE_HPP
 
-#include <mlpack/prereqs.hpp>
+#include <mlpack/core.hpp>
+
 #include "gini_gain.hpp"
 #include "information_gain.hpp"
+#include "mad_gain.hpp"
+#include "mse_gain.hpp"
+
 #include "best_binary_numeric_split.hpp"
+#include "random_binary_numeric_split.hpp"
+
 #include "all_categorical_split.hpp"
+
 #include "all_dimension_select.hpp"
-#include <type_traits>
+#include "random_dimension_select.hpp"
+#include "multiple_random_dimension_select.hpp"
 
 namespace mlpack {
-namespace tree {
 
 /**
  * This class implements a generic decision tree learner.  Its behavior can be
@@ -35,13 +42,10 @@ template<typename FitnessFunction = GiniGain,
          template<typename> class NumericSplitType = BestBinaryNumericSplit,
          template<typename> class CategoricalSplitType = AllCategoricalSplit,
          typename DimensionSelectionType = AllDimensionSelect,
-         typename ElemType = double,
          bool NoRecursion = false>
 class DecisionTree :
-    public NumericSplitType<FitnessFunction>::template
-        AuxiliarySplitInfo<ElemType>,
-    public CategoricalSplitType<FitnessFunction>::template
-        AuxiliarySplitInfo<ElemType>
+    public NumericSplitType<FitnessFunction>::AuxiliarySplitInfo,
+    public CategoricalSplitType<FitnessFunction>::AuxiliarySplitInfo
 {
  public:
   //! Allow access to the numeric split type.
@@ -139,10 +143,11 @@ class DecisionTree :
           typename std::remove_reference<WeightsType>::type>::value>* = 0);
 
   /**
-   * Take ownership of another decision tree and train on the given data and 
-   * labels with weights, where the data can be both numeric and categorical.
-   * Setting minimumLeafSize and minimumGainSplit too small may cause the
-   * tree to overfit, but setting them too large may cause it to underfit.
+   * Using the hyperparameters of another decision tree, train on the given data
+   * and labels with weights, where the data can be both numeric and
+   * categorical.  Setting minimumLeafSize and minimumGainSplit too small may
+   * cause the tree to overfit, but setting them too large may cause it to
+   * underfit.
    *
    * Use std::move if data, labels or weights are no longer needed to avoid
    * copies.
@@ -200,10 +205,10 @@ class DecisionTree :
           typename std::remove_reference<WeightsType>::type>::value>* = 0);
 
   /**
-   * Take ownership of another decision tree and train on the given data and labels
-   * with weights, assuming that the data is all of the numeric type. Setting 
-   * minimumLeafSize and minimumGainSplit too small may cause the tree to 
-   * overfit, but setting them too large may cause it to underfit.
+   * Take ownership of another decision tree and train on the given data and
+   * labels with weights, assuming that the data is all of the numeric type.
+   * Setting minimumLeafSize and minimumGainSplit too small may cause the tree
+   * to overfit, but setting them too large may cause it to underfit.
    *
    * Use std::move if data, labels or weights are no longer needed to avoid
    * copies.
@@ -287,7 +292,6 @@ class DecisionTree :
    * @param datasetInfo Type information for each dimension.
    * @param labels Labels for each training point.
    * @param numClasses Number of classes in the dataset.
-   * @param weights Weights of all the labels
    * @param minimumLeafSize Minimum number of points in each leaf node.
    * @param minimumGainSplit Minimum gain for the node to split.
    * @param maximumDepth Maximum depth for the tree.
@@ -316,7 +320,6 @@ class DecisionTree :
    * @param data Dataset to train on.
    * @param labels Labels for each training point.
    * @param numClasses Number of classes in the dataset.
-   * @param weights Weights of all the labels
    * @param minimumLeafSize Minimum number of points in each leaf node.
    * @param minimumGainSplit Minimum gain for the node to split.
    * @param maximumDepth Maximum depth for the tree.
@@ -453,7 +456,7 @@ class DecisionTree :
    * Serialize the tree.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
   //! Get the number of children.
   size_t NumChildren() const { return children.size(); }
@@ -467,6 +470,11 @@ class DecisionTree :
   //! trained tree).
   size_t SplitDimension() const { return splitDimension; }
 
+  //! Get the class probabilities, if this is a leaf node in the trained tree.
+  //! Note that if this is not a leaf, then this may contain arbitrary
+  //! information used by the split in the tree!
+  const arma::vec& ClassProbabilities() const { return classProbabilities; }
+
   /**
    * Given a point and that this node is not a leaf, calculate the index of the
    * child node this point would go towards.  This method is primarily used by
@@ -487,9 +495,15 @@ class DecisionTree :
   std::vector<DecisionTree*> children;
   //! The dimension this node splits on.
   size_t splitDimension;
-  //! The type of the dimension that we have split on (if we are not a leaf).
-  //! If we are a leaf, then this is the index of the majority class.
-  size_t dimensionTypeOrMajorityClass;
+
+  union
+  {
+    //! Stores the type of dimension on which the split is done for internal
+    //! nodes of the tree.
+    size_t dimensionType;
+    //! Stores the majority class for leaf nodes of the tree.
+    size_t majorityClass;
+  };
   /**
    * This vector may hold different things.  If the node has no children, then
    * it is guaranteed to hold the probabilities of each class.  If the node has
@@ -502,9 +516,9 @@ class DecisionTree :
   //! Note that this class will also hold the members of the NumericSplit and
   //! CategoricalSplit AuxiliarySplitInfo classes, since it inherits from them.
   //! We'll define some convenience typedefs here.
-  typedef typename NumericSplit::template AuxiliarySplitInfo<ElemType>
+  typedef typename NumericSplit::AuxiliarySplitInfo
       NumericAuxiliarySplitInfo;
-  typedef typename CategoricalSplit::template AuxiliarySplitInfo<ElemType>
+  typedef typename CategoricalSplit::AuxiliarySplitInfo
       CategoricalAuxiliarySplitInfo;
 
   /**
@@ -580,13 +594,11 @@ class DecisionTree :
 template<typename FitnessFunction = GiniGain,
          template<typename> class NumericSplitType = BestBinaryNumericSplit,
          template<typename> class CategoricalSplitType = AllCategoricalSplit,
-         typename DimensionSelectType = AllDimensionSelect,
-         typename ElemType = double>
+         typename DimensionSelectType = AllDimensionSelect>
 using DecisionStump = DecisionTree<FitnessFunction,
                                    NumericSplitType,
                                    CategoricalSplitType,
                                    DimensionSelectType,
-                                   ElemType,
                                    false>;
 
 /**
@@ -597,12 +609,13 @@ typedef DecisionTree<InformationGain,
                      BestBinaryNumericSplit,
                      AllCategoricalSplit,
                      AllDimensionSelect,
-                     double,
                      true> ID3DecisionStump;
-} // namespace tree
 } // namespace mlpack
 
 // Include implementation.
 #include "decision_tree_impl.hpp"
 
+// Also include the DecisionTreeRegressor.
+#include "decision_tree_regressor.hpp"
+
 #endif
