@@ -10,16 +10,21 @@
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef MLPACK_METHODS_MOG_MOG_EM_HPP
-#define MLPACK_METHODS_MOG_MOG_EM_HPP
+#ifndef MLPACK_METHODS_GMM_GMM_HPP
+#define MLPACK_METHODS_GMM_GMM_HPP
 
-#include <mlpack/prereqs.hpp>
+#include <mlpack/core.hpp>
+
+// Include all constraint types a user may want to use.
+#include "diagonal_constraint.hpp"
+#include "eigenvalue_ratio_constraint.hpp"
+#include "no_constraint.hpp"
+#include "positive_definite_constraint.hpp"
 
 // This is the default fitting method class.
 #include "em_fit.hpp"
 
 namespace mlpack {
-namespace gmm /** Gaussian Mixture Models. */ {
 
 /**
  * A Gaussian Mixture Model (GMM). This class uses maximum likelihood loss
@@ -34,12 +39,12 @@ namespace gmm /** Gaussian Mixture Models. */ {
  *
  * @code
  * void Estimate(const arma::mat& observations,
- *               std::vector<distribution::GaussianDistribution>& dists,
+ *               std::vector<GaussianDistribution>& dists,
  *               arma::vec& weights);
  *
  * void Estimate(const arma::mat& observations,
  *               const arma::vec& probabilities,
- *               std::vector<distribution::GaussianDistribution>& dists,
+ *               std::vector<GaussianDistribution>& dists,
  *               arma::vec& weights);
  * @endcode
  *
@@ -84,7 +89,7 @@ class GMM
   size_t dimensionality;
 
   //! Vector of Gaussians
-  std::vector<distribution::GaussianDistribution> dists;
+  std::vector<GaussianDistribution> dists;
 
   //! Vector of a priori weights for each Gaussian.
   arma::vec weights;
@@ -119,7 +124,7 @@ class GMM
    * @param dists Distributions of the model.
    * @param weights Weights of the model.
    */
-  GMM(const std::vector<distribution::GaussianDistribution> & dists,
+  GMM(const std::vector<GaussianDistribution> & dists,
       const arma::vec& weights) :
       gaussians(dists.size()),
       dimensionality((!dists.empty()) ? dists[0].Mean().n_elem : 0),
@@ -142,14 +147,13 @@ class GMM
    *
    * @param i Index of component.
    */
-  const distribution::GaussianDistribution& Component(size_t i) const {
-      return dists[i]; }
+  const GaussianDistribution& Component(size_t i) const { return dists[i]; }
   /**
    * Return a reference to a component distribution.
    *
    * @param i Index of component.
    */
-  distribution::GaussianDistribution& Component(size_t i) { return dists[i]; }
+  GaussianDistribution& Component(size_t i) { return dists[i]; }
 
   //! Return a const reference to the a priori weights of each Gaussian.
   const arma::vec& Weights() const { return weights; }
@@ -160,18 +164,34 @@ class GMM
    * Return the probability that the given observation came from this
    * distribution.
    *
-   * @param observation Observation to evaluate the probability of.
+   * @param observation Observation vector to evaluate the probability of.
    */
   double Probability(const arma::vec& observation) const;
 
+  /**
+   * Return the probability of the given observation matrix.
+   *
+   * @param observation Observation matrix.
+   * @param probs Vector to store probability value of observation x.
+   */
+  void Probability(const arma::mat& observation, arma::vec& probs) const;
+
   /**
    * Return the log probability that the given observation came from this
    * distribution.
    *
-   * @param observation Observation to evaluate the probability of.
+   * @param observation Observation vector to evaluate the probability of.
    */
   double LogProbability(const arma::vec& observation) const;
 
+  /**
+   * Return the log-probability of the given observation (x) matrix.
+   *
+   * @param observation Observation matrix.
+   * @param logProbs Vector to store log-probability value of observation.
+   */
+  void LogProbability(const arma::mat& observation, arma::vec& logProbs) const;
+
   /**
    * Return the probability that the given observation came from the given
    * Gaussian component in this distribution.
@@ -283,7 +303,7 @@ class GMM
    * Serialize the GMM.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
   /**
@@ -297,14 +317,16 @@ class GMM
    */
   double LogLikelihood(
       const arma::mat& dataPoints,
-      const std::vector<distribution::GaussianDistribution>& distsL,
+      const std::vector<GaussianDistribution>& distsL,
       const arma::vec& weights) const;
 };
 
-} // namespace gmm
 } // namespace mlpack
 
 // Include implementation.
 #include "gmm_impl.hpp"
 
+// Also include the DiagonalGMM class.
+#include "diagonal_gmm.hpp"
+
 #endif
