@@ -16,7 +16,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace tree {
 
 template<typename ObservationType = double>
 class BinaryNumericSplitInfo
@@ -34,16 +33,15 @@ class BinaryNumericSplitInfo
 
   //! Serialize the split (save/load the split points).
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(splitPoint);
+    ar(CEREAL_NVP(splitPoint));
   }
 
  private:
   ObservationType splitPoint;
 };
 
-} // namespace tree
 } // namespace mlpack
 
 #endif
