@@ -13,14 +13,20 @@
 #ifndef MLPACK_METHODS_HOEFFDING_TREES_HOEFFDING_TREE_HPP
 #define MLPACK_METHODS_HOEFFDING_TREES_HOEFFDING_TREE_HPP
 
-#include <mlpack/prereqs.hpp>
-#include <mlpack/core/data/dataset_mapper.hpp>
+#include <mlpack/core.hpp>
+
+#include "categorical_split_info.hpp"
+#include "numeric_split_info.hpp"
+
 #include "gini_impurity.hpp"
+#include "information_gain.hpp"
+
 #include "hoeffding_numeric_split.hpp"
+#include "binary_numeric_split.hpp"
+
 #include "hoeffding_categorical_split.hpp"
 
 namespace mlpack {
-namespace tree {
 
 /**
  * The HoeffdingTree object represents all of the necessary information for a
@@ -43,10 +49,10 @@ namespace tree {
  * The class is modular, and takes three template parameters.  The first,
  * FitnessFunction, is the fitness function that should be used to determine
  * whether a split is beneficial; examples might be GiniImpurity or
- * InformationGain.  The NumericSplitType determines how numeric attributes are
- * handled, and the CategoricalSplitType determines how categorical attributes
- * are handled.  As far as the actual splitting goes, the meat of the splitting
- * procedure will be contained in those two classes.
+ * HoeffdingInformationGain.  The NumericSplitType determines how numeric
+ * attributes are handled, and the CategoricalSplitType determines how
+ * categorical attributes are handled.  As far as the actual splitting goes,
+ * the meat of the splitting procedure will be contained in those two classes.
  *
  * @tparam FitnessFunction Fitness function to use.
  * @tparam NumericSplitType Technique for splitting numeric features.
@@ -155,6 +161,27 @@ class HoeffdingTree
    */
   HoeffdingTree(const HoeffdingTree& other);
 
+  /**
+   * Move another tree.
+   *
+   * @param other Tree to move.
+   */
+  HoeffdingTree(HoeffdingTree&& other);
+
+  /**
+   * Copy assignment operator.
+   *
+   * @param other Tree to copy.
+   */
+  HoeffdingTree& operator=(const HoeffdingTree& other);
+
+  /**
+   * Move assignment operator.
+   *
+   * @param other Tree to move.
+   */
+  HoeffdingTree& operator=(HoeffdingTree&& other);
+
   /**
    * Clean up memory.
    */
@@ -162,29 +189,53 @@ class HoeffdingTree
 
   /**
    * Train on a set of points, either in streaming mode or in batch mode, with
-   * the given labels.
+   * the given labels.  If `resetTree` is set to `true`, then reset the state of
+   * the tree to an empty tree before training.
+   *
+   * Note that the tree will be automatically reset if the dimensionality of
+   * `data` does not match the dimensionality that the tree was currently
+   * trained with.  The tree will also be reset if `numClasses` is passed.
    *
    * @param data Data points to train on.
    * @param labels Labels of data points.
    * @param batchTraining If true, perform training in batch.
+   * @param resetTree If true, reset the tree to an empty tree before training.
+   * @param numClasses The number of classes in `labels`.  Passing this will
+   *      reset the tree.  If not given and `resetTree` is `true`, then the
+   *      number of classes will be computed from `labels`.
    */
   template<typename MatType>
   void Train(const MatType& data,
              const arma::Row<size_t>& labels,
-             const bool batchTraining = true);
+             const bool batchTraining = true,
+             const bool resetTree = false,
+             const size_t numClasses = 0);
 
   /**
    * Train on a set of points, either in streaming mode or in batch mode, with
-   * the given labels and the given DatasetInfo.  This will reset the tree.
+   * the given labels and the given `DatasetInfo`.  This will reset the tree.
+   * This only needs to be called when the `DatasetInfo` has changed---if you
+   * are training incrementally but have already passed the DatasetInfo once,
+   * use the overload of `Train()` that does not take a `DatasetInfo` and make
+   * sure `resetTree` is set to `false`.
+   *
+   * @param data Data points to train on.
+   * @param info DatasetInfo object with information about each dimension.
+   * @param labels Labels of data points.
+   * @param batchTraining If true, perform training in batch.
+   * @param numClasses Number of classes in `labels`.  If not specified, it is
+   *      computed from `labels`.
    */
   template<typename MatType>
   void Train(const MatType& data,
              const data::DatasetInfo& info,
              const arma::Row<size_t>& labels,
-             const bool batchTraining = true);
+             const bool batchTraining = true,
+             const size_t numClasses = 0);
 
   /**
-   * Train on a single point in streaming mode, with the given label.
+   * Train on a single point in streaming mode, with the given label.  The tree
+   * will not be reset before training.
    *
    * @param point Point to train on.
    * @param label Label of point to train on.
@@ -311,7 +362,7 @@ class HoeffdingTree
 
   //! Serialize the split.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
   // We need to keep some information for before we have split.
@@ -358,9 +409,26 @@ class HoeffdingTree
   typename NumericSplitType<FitnessFunction>::SplitInfo numericSplit;
   //! If the split has occurred, these are the children.
   std::vector<HoeffdingTree*> children;
+
+  /**
+   * Perform training (typically after a reset, but not necessarily).  This
+   * assumes datasetInfo and dimensionMappings are set correctly.
+   */
+  template<typename MatType>
+  void TrainInternal(const MatType& data,
+                     const arma::Row<size_t>& labels,
+                     const bool batchTraining);
+
+  /**
+   * Reset the tree.  This assumes datasetInfo is set correctly.
+   */
+  void ResetTree(
+      const CategoricalSplitType<FitnessFunction>& categoricalSplitIn =
+          CategoricalSplitType<FitnessFunction>(0, 0),
+      const NumericSplitType<FitnessFunction>& numericSplitIn =
+          NumericSplitType<FitnessFunction>(0));
 };
 
-} // namespace tree
 } // namespace mlpack
 
 #include "hoeffding_tree_impl.hpp"
