@@ -15,9 +15,9 @@
 #include "hoeffding_tree.hpp"
 #include "binary_numeric_split.hpp"
 #include "information_gain.hpp"
+#include <queue>
 
 namespace mlpack {
-namespace tree {
 
 /**
  * This class is a serializable Hoeffding tree model that can hold four
@@ -166,10 +166,10 @@ class HoeffdingTreeModel
    * Serialize the model.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
     // Clear memory if needed.
-    if (Archive::is_loading::value)
+    if (cereal::is_loading<Archive>())
     {
       delete giniHoeffdingTree;
       delete giniBinaryTree;
@@ -182,18 +182,18 @@ class HoeffdingTreeModel
       infoBinaryTree = NULL;
     }
 
-    ar & BOOST_SERIALIZATION_NVP(type);
+    ar(CEREAL_NVP(type));
 
     // Fake dataset info may be needed to create fake trees.
     data::DatasetInfo info;
     if (type == GINI_HOEFFDING)
-      ar & BOOST_SERIALIZATION_NVP(giniHoeffdingTree);
+      ar(CEREAL_POINTER(giniHoeffdingTree));
     else if (type == GINI_BINARY)
-      ar & BOOST_SERIALIZATION_NVP(giniBinaryTree);
+      ar(CEREAL_POINTER(giniBinaryTree));
     else if (type == INFO_HOEFFDING)
-      ar & BOOST_SERIALIZATION_NVP(infoHoeffdingTree);
+      ar(CEREAL_POINTER(infoHoeffdingTree));
     else if (type == INFO_BINARY)
-      ar & BOOST_SERIALIZATION_NVP(infoBinaryTree);
+      ar(CEREAL_POINTER(infoBinaryTree));
   }
 
  private:
@@ -217,7 +217,9 @@ class HoeffdingTreeModel
   InfoBinaryTreeType* infoBinaryTree;
 };
 
-} // namespace tree
 } // namespace mlpack
 
+// Include implementation.
+#include "hoeffding_tree_model_impl.hpp"
+
 #endif
