@@ -14,9 +14,8 @@
 #define MLPACK_METHODS_HOEFFDING_TREES_INFORMATION_GAIN_HPP
 
 namespace mlpack {
-namespace tree {
 
-class InformationGain
+class HoeffdingInformationGain
 {
  public:
   /**
@@ -90,7 +89,6 @@ class InformationGain
   }
 };
 
-} // namespace tree
 } // namespace mlpack
 
 #endif
