@@ -17,10 +17,9 @@
 #include "kde_rules.hpp"
 
 // Used for Monte Carlo estimation.
-#include <boost/math/distributions/normal.hpp>
+#include <mlpack/core/math/quantile.hpp>
 
 namespace mlpack {
-namespace kde {
 
 template<typename MetricType, typename KernelType, typename TreeType>
 KDERules<MetricType, KernelType, TreeType>::KDERules(
@@ -66,7 +65,7 @@ KDERules<MetricType, KernelType, TreeType>::KDERules(
 
 //! The base case.
 template<typename MetricType, typename KernelType, typename TreeType>
-inline force_inline
+inline mlpack_force_inline
 double KDERules<MetricType, KernelType, TreeType>::BaseCase(
     const size_t queryIndex,
     const size_t referenceIndex)
@@ -114,7 +113,7 @@ Score(const size_t queryIndex, TreeType& referenceNode)
   else
     depthAlpha = -1;
 
-  if (tree::TreeTraits<TreeType>::FirstPointIsCentroid &&
+  if (TreeTraits<TreeType>::FirstPointIsCentroid &&
       lastQueryIndex == queryIndex &&
       traversalInfo.LastReferenceNode() != NULL &&
       lastReferenceIndex == referenceNode.Point(0))
@@ -129,12 +128,12 @@ Score(const size_t queryIndex, TreeType& referenceNode)
   else
   {
     // All Calculations are new.
-    const math::Range r = referenceNode.RangeDistance(queryPoint);
+    const Range r = referenceNode.RangeDistance(queryPoint);
     minDistance = r.Lo();
     maxDistance = r.Hi();
 
     // Check if we are a self-child.
-    if (tree::TreeTraits<TreeType>::HasSelfChildren &&
+    if (TreeTraits<TreeType>::HasSelfChildren &&
         referenceNode.Parent() != NULL &&
         referenceNode.Parent()->Point(0) == referenceNode.Point(0))
     {
@@ -191,9 +190,7 @@ Score(const size_t queryIndex, TreeType& referenceNode)
     // Monte Carlo probabilistic estimation.
     // Calculate z using accumulated alpha if possible.
     const double alpha = depthAlpha + accumMCAlpha(queryIndex);
-    const boost::math::normal normalDist;
-    const double z =
-        std::abs(boost::math::quantile(normalDist, alpha / 2));
+    const double z = std::abs(Quantile(alpha / 2.0));
 
     // Auxiliary variables.
     arma::vec sample;
@@ -222,9 +219,9 @@ Score(const size_t queryIndex, TreeType& referenceNode)
         // Sample and evaluate random points from the reference node.
         size_t randomPoint;
         if (alreadyDidRefPoint0)
-          randomPoint = math::RandInt(1, refNumDesc);
+          randomPoint = RandInt(1, refNumDesc);
         else
-          randomPoint = math::RandInt(0, refNumDesc);
+          randomPoint = RandInt(0, refNumDesc);
 
         sample(oldSize + i) =
             EvaluateKernel(queryIndex, referenceNode.Descendant(randomPoint));
@@ -294,7 +291,7 @@ Score(const size_t queryIndex, TreeType& referenceNode)
 }
 
 template<typename MetricType, typename KernelType, typename TreeType>
-inline force_inline double KDERules<MetricType, KernelType, TreeType>::
+inline mlpack_force_inline double KDERules<MetricType, KernelType, TreeType>::
 Rescore(const size_t /* queryIndex */,
         TreeType& /* referenceNode */,
         const double oldScore) const
@@ -308,7 +305,7 @@ template<typename MetricType, typename KernelType, typename TreeType>
 inline double KDERules<MetricType, KernelType, TreeType>::
 Score(TreeType& queryNode, TreeType& referenceNode)
 {
-  kde::KDEStat& queryStat = queryNode.Stat();
+  KDEStat& queryStat = queryNode.Stat();
   const size_t refNumDesc = referenceNode.NumDescendants();
   double score, minDistance, maxDistance, depthAlpha;
   // Calculations are not duplicated.
@@ -327,7 +324,7 @@ Score(TreeType& queryNode, TreeType& referenceNode)
                                referenceNode.IsLeaf() &&
                                queryNode.IsLeaf();
 
-  if (tree::TreeTraits<TreeType>::FirstPointIsCentroid &&
+  if (TreeTraits<TreeType>::FirstPointIsCentroid &&
       (traversalInfo.LastQueryNode() != NULL) &&
       (traversalInfo.LastReferenceNode() != NULL) &&
       (traversalInfo.LastQueryNode()->Point(0) == queryNode.Point(0)) &&
@@ -348,7 +345,7 @@ Score(TreeType& queryNode, TreeType& referenceNode)
   else
   {
     // All calculations are new.
-    const math::Range r = queryNode.RangeDistance(referenceNode);
+    const Range r = queryNode.RangeDistance(referenceNode);
     minDistance = r.Lo();
     maxDistance = r.Hi();
   }
@@ -400,9 +397,7 @@ Score(TreeType& queryNode, TreeType& referenceNode)
     // Monte Carlo probabilistic estimation.
     // Calculate z using accumulated alpha if possible.
     const double alpha = depthAlpha + queryStat.AccumAlpha();
-    const boost::math::normal normalDist;
-    const double z =
-        std::abs(boost::math::quantile(normalDist, alpha / 2));
+    const double z = std::abs(Quantile(alpha / 2));
 
     // Auxiliary variables.
     arma::vec sample;
@@ -439,9 +434,9 @@ Score(TreeType& queryNode, TreeType& referenceNode)
           // Sample and evaluate random points from the reference node.
           size_t randomPoint;
           if (alreadyDidRefPoint0)
-            randomPoint = math::RandInt(1, refNumDesc);
+            randomPoint = RandInt(1, refNumDesc);
           else
-            randomPoint = math::RandInt(0, refNumDesc);
+            randomPoint = RandInt(0, refNumDesc);
 
           sample(oldSize + i) =
               EvaluateKernel(queryIndex, referenceNode.Descendant(randomPoint));
@@ -519,7 +514,7 @@ Score(TreeType& queryNode, TreeType& referenceNode)
 
 //! Dual-tree rescore.
 template<typename MetricType, typename KernelType, typename TreeType>
-inline force_inline double KDERules<MetricType, KernelType, TreeType>::
+inline mlpack_force_inline double KDERules<MetricType, KernelType, TreeType>::
 Rescore(TreeType& /*queryNode*/,
         TreeType& /*referenceNode*/,
         const double oldScore) const
@@ -529,7 +524,7 @@ Rescore(TreeType& /*queryNode*/,
 }
 
 template<typename MetricType, typename KernelType, typename TreeType>
-inline force_inline double KDERules<MetricType, KernelType, TreeType>::
+inline mlpack_force_inline double KDERules<MetricType, KernelType, TreeType>::
 EvaluateKernel(const size_t queryIndex,
                const size_t referenceIndex) const
 {
@@ -538,14 +533,14 @@ EvaluateKernel(const size_t queryIndex,
 }
 
 template<typename MetricType, typename KernelType, typename TreeType>
-inline force_inline double KDERules<MetricType, KernelType, TreeType>::
+inline mlpack_force_inline double KDERules<MetricType, KernelType, TreeType>::
 EvaluateKernel(const arma::vec& query, const arma::vec& reference) const
 {
   return kernel.Evaluate(metric.Evaluate(query, reference));
 }
 
 template<typename MetricType, typename KernelType, typename TreeType>
-inline force_inline double KDERules<MetricType, KernelType, TreeType>::
+inline mlpack_force_inline double KDERules<MetricType, KernelType, TreeType>::
 CalculateAlpha(TreeType* node)
 {
   KDEStat& stat = node->Stat();
@@ -575,7 +570,7 @@ CalculateAlpha(TreeType* node)
 
 //! Clean rules base case.
 template<typename TreeType>
-inline force_inline
+inline mlpack_force_inline
 double KDECleanRules<TreeType>::BaseCase(const size_t /* queryIndex */,
                                          const size_t /* refIndex */)
 {
@@ -584,7 +579,7 @@ double KDECleanRules<TreeType>::BaseCase(const size_t /* queryIndex */,
 
 //! Clean rules single-tree score.
 template<typename TreeType>
-inline force_inline
+inline mlpack_force_inline
 double KDECleanRules<TreeType>::Score(const size_t /* queryIndex */,
                                       TreeType& referenceNode)
 {
@@ -595,7 +590,7 @@ double KDECleanRules<TreeType>::Score(const size_t /* queryIndex */,
 
 //! Clean rules double-tree score.
 template<typename TreeType>
-inline force_inline
+inline mlpack_force_inline
 double KDECleanRules<TreeType>::Score(TreeType& queryNode,
                                       TreeType& referenceNode)
 {
@@ -608,7 +603,6 @@ double KDECleanRules<TreeType>::Score(TreeType& queryNode,
   return 0;
 }
 
-} // namespace kde
 } // namespace mlpack
 
 #endif
