@@ -9,43 +9,34 @@
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core.hpp>
+
+#undef BINDING_NAME
+#define BINDING_NAME kernel_pca
+
 #include <mlpack/core/util/mlpack_main.hpp>
-#include <mlpack/core/math/random.hpp>
-#include <mlpack/core/kernels/kernel_traits.hpp>
-#include <mlpack/core/kernels/linear_kernel.hpp>
-#include <mlpack/core/kernels/polynomial_kernel.hpp>
-#include <mlpack/core/kernels/cosine_distance.hpp>
-#include <mlpack/core/kernels/gaussian_kernel.hpp>
-#include <mlpack/core/kernels/epanechnikov_kernel.hpp>
-#include <mlpack/core/kernels/hyperbolic_tangent_kernel.hpp>
-#include <mlpack/core/kernels/laplacian_kernel.hpp>
-#include <mlpack/core/kernels/pspectrum_string_kernel.hpp>
-#include <mlpack/core/kernels/spherical_kernel.hpp>
-#include <mlpack/core/kernels/triangular_kernel.hpp>
 #include <mlpack/methods/hoeffding_trees/hoeffding_tree.hpp>
-#include <mlpack/methods/nystroem_method/ordered_selection.hpp>
-#include <mlpack/methods/nystroem_method/random_selection.hpp>
-#include <mlpack/methods/nystroem_method/kmeans_selection.hpp>
 #include <mlpack/methods/nystroem_method/nystroem_method.hpp>
 #include <mlpack/methods/kernel_pca/kernel_rules/nystroem_method.hpp>
 
 #include "kernel_pca.hpp"
 
 using namespace mlpack;
-using namespace mlpack::kpca;
-using namespace mlpack::kernel;
 using namespace mlpack::util;
 using namespace std;
 using namespace arma;
 
-PROGRAM_INFO("Kernel Principal Components Analysis",
-    // Short description.
+// Program Name.
+BINDING_USER_NAME("Kernel Principal Components Analysis");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of Kernel Principal Components Analysis (KPCA).  This "
     "can be used to perform nonlinear dimensionality reduction or preprocessing"
-    " on a given dataset.",
-    // Long description.
+    " on a given dataset.");
+
+// Long description.
+BINDING_LONG_DESC(
     "This program performs Kernel Principal Components Analysis (KPCA) on the "
     "specified dataset with the specified kernel.  This will transform the "
     "data onto the kernel principal components, and optionally reduce the "
@@ -55,13 +46,6 @@ PROGRAM_INFO("Kernel Principal Components Analysis",
     "For the case where a linear kernel is used, this reduces to regular "
     "PCA."
     "\n\n"
-    "For example, the following command will perform KPCA on the dataset " +
-    PRINT_DATASET("input") + " using the Gaussian kernel, and saving the "
-    "transformed data to " + PRINT_DATASET("transformed") + ": "
-    "\n\n" +
-    PRINT_CALL("kernel_pca", "input", "input", "kernel", "gaussian", "output",
-        "transformed") +
-    "\n\n"
     "The kernels that are supported are listed below:"
     "\n\n"
     " * 'linear': the standard linear dot product (same as normal PCA):\n"
@@ -98,13 +82,24 @@ PROGRAM_INFO("Kernel Principal Components Analysis",
     "the kernel matrix; to specify the sampling scheme, the " +
     PRINT_PARAM_STRING("sampling") + " parameter is used.  The "
     "sampling scheme for the Nystroem method can be chosen from the "
-    "following list: 'kmeans', 'random', 'ordered'.",
-    SEE_ALSO("Kernel principal component analysis on Wikipedia",
-        "https://en.wikipedia.org/wiki/Kernel_principal_component_analysis"),
-    SEE_ALSO("Kernel Principal Component Analysis (pdf)",
-        "http://pca.narod.ru/scholkopf_kernel.pdf"),
-    SEE_ALSO("mlpack::kpca::KernelPCA class documentation",
-        "@doxygen/classmlpack_1_1kpca_1_1KernelPCA.html"));
+    "following list: 'kmeans', 'random', 'ordered'.");
+
+// Example.
+BINDING_EXAMPLE(
+    "For example, the following command will perform KPCA on the dataset " +
+    PRINT_DATASET("input") + " using the Gaussian kernel, and saving the "
+    "transformed data to " + PRINT_DATASET("transformed") + ": "
+    "\n\n" +
+    PRINT_CALL("kernel_pca", "input", "input", "kernel", "gaussian", "output",
+        "transformed"));
+
+// See also...
+BINDING_SEE_ALSO("Kernel principal component analysis on Wikipedia",
+    "https://en.wikipedia.org/wiki/Kernel_principal_component_analysis");
+BINDING_SEE_ALSO("Kernel Principal Component Analysis (pdf)",
+    "http://pca.narod.ru/scholkopf_kernel.pdf");
+BINDING_SEE_ALSO("KernelPCA class documentation",
+    "@src/mlpack/methods/kernel_pca/kernel_pca.hpp");
 
 PARAM_MATRIX_IN_REQ("input", "Input dataset to perform KPCA on.", "i");
 PARAM_MATRIX_OUT("output", "Matrix to save modified dataset to.", "o");
@@ -175,18 +170,19 @@ void RunKPCA(arma::mat& dataset,
   }
 }
 
-static void mlpackMain()
+void BINDING_FUNCTION(util::Params& params, util::Timers& /* timers */)
 {
-  RequireAtLeastOnePassed({ "output" }, false, "no output will be saved");
+  RequireAtLeastOnePassed(params, { "output" }, false,
+      "no output will be saved");
 
   // Load input dataset.
-  mat dataset = std::move(CLI::GetParam<arma::mat>("input"));
+  mat dataset = std::move(params.Get<arma::mat>("input"));
 
   // Get the new dimensionality, if it is necessary.
   size_t newDim = dataset.n_rows;
-  if (CLI::GetParam<int>("new_dimensionality") != 0)
+  if (params.Get<int>("new_dimensionality") != 0)
   {
-    newDim = CLI::GetParam<int>("new_dimensionality");
+    newDim = params.Get<int>("new_dimensionality");
 
     if (newDim > dataset.n_rows)
     {
@@ -197,14 +193,14 @@ static void mlpackMain()
   }
 
   // Get the kernel type and make sure it is valid.
-  RequireParamInSet<string>("kernel", { "linear", "gaussian", "polynomial",
-      "hyptan", "laplacian", "epanechnikov", "cosine" }, true,
+  RequireParamInSet<string>(params, "kernel", { "linear", "gaussian",
+      "polynomial", "hyptan", "laplacian", "epanechnikov", "cosine" }, true,
       "unknown kernel type");
-  const string kernelType = CLI::GetParam<string>("kernel");
+  const string kernelType = params.Get<string>("kernel");
 
-  const bool centerTransformedData = CLI::HasParam("center");
-  const bool nystroem = CLI::HasParam("nystroem_method");
-  const string sampling = CLI::GetParam<string>("sampling");
+  const bool centerTransformedData = params.Has("center");
+  const bool nystroem = params.Has("nystroem_method");
+  const string sampling = params.Get<string>("sampling");
 
   if (kernelType == "linear")
   {
@@ -214,7 +210,7 @@ static void mlpackMain()
   }
   else if (kernelType == "gaussian")
   {
-    const double bandwidth = CLI::GetParam<double>("bandwidth");
+    const double bandwidth = params.Get<double>("bandwidth");
 
     GaussianKernel kernel(bandwidth);
     RunKPCA<GaussianKernel>(dataset, centerTransformedData, nystroem, newDim,
@@ -222,8 +218,8 @@ static void mlpackMain()
   }
   else if (kernelType == "polynomial")
   {
-    const double degree = CLI::GetParam<double>("degree");
-    const double offset = CLI::GetParam<double>("offset");
+    const double degree = params.Get<double>("degree");
+    const double offset = params.Get<double>("offset");
 
     PolynomialKernel kernel(degree, offset);
     RunKPCA<PolynomialKernel>(dataset, centerTransformedData, nystroem,
@@ -231,8 +227,8 @@ static void mlpackMain()
   }
   else if (kernelType == "hyptan")
   {
-    const double scale = CLI::GetParam<double>("kernel_scale");
-    const double offset = CLI::GetParam<double>("offset");
+    const double scale = params.Get<double>("kernel_scale");
+    const double offset = params.Get<double>("offset");
 
     HyperbolicTangentKernel kernel(scale, offset);
     RunKPCA<HyperbolicTangentKernel>(dataset, centerTransformedData, nystroem,
@@ -240,7 +236,7 @@ static void mlpackMain()
   }
   else if (kernelType == "laplacian")
   {
-    const double bandwidth = CLI::GetParam<double>("bandwidth");
+    const double bandwidth = params.Get<double>("bandwidth");
 
     LaplacianKernel kernel(bandwidth);
     RunKPCA<LaplacianKernel>(dataset, centerTransformedData, nystroem, newDim,
@@ -248,7 +244,7 @@ static void mlpackMain()
   }
   else if (kernelType == "epanechnikov")
   {
-    const double bandwidth = CLI::GetParam<double>("bandwidth");
+    const double bandwidth = params.Get<double>("bandwidth");
 
     EpanechnikovKernel kernel(bandwidth);
     RunKPCA<EpanechnikovKernel>(dataset, centerTransformedData, nystroem,
@@ -262,6 +258,6 @@ static void mlpackMain()
   }
 
   // Save the output dataset.
-  if (CLI::HasParam("output"))
-    CLI::GetParam<arma::mat>("output") = std::move(dataset);
+  if (params.Has("output"))
+    params.Get<arma::mat>("output") = std::move(dataset);
 }
