@@ -17,7 +17,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace kmeans {
 
 /**
  * When an empty cluster is detected, this class takes the point furthest from
@@ -56,7 +55,7 @@ class MaxVarianceNewCluster
 
   //! Serialize the object.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int version);
+  void serialize(Archive& ar, const uint32_t version);
 
  private:
   //! Index of iteration for which variance is cached.
@@ -74,7 +73,6 @@ class MaxVarianceNewCluster
                     MetricType& metric);
 };
 
-} // namespace kmeans
 } // namespace mlpack
 
 // Include implementation.
