@@ -16,7 +16,6 @@
 #include "linear_svm.hpp"
 
 namespace mlpack {
-namespace svm {
 
 template <typename MatType>
 template <typename OptimizerType, typename... CallbackTypes>
@@ -105,9 +104,7 @@ double LinearSVM<MatType>::Train(
     parameters = svm.InitialPoint();
 
   // Train the model.
-  Timer::Start("linear_svm_optimization");
   const double out = optimizer.Optimize(svm, parameters, callbacks...);
-  Timer::Stop("linear_svm_optimization");
 
   Log::Info << "LinearSVM::LinearSVM(): final objective of "
             << "trained model is " << out << "." << std::endl;
@@ -134,9 +131,7 @@ double LinearSVM<MatType>::Train(
     parameters = svm.InitialPoint();
 
   // Train the model.
-  Timer::Start("linear_svm_optimization");
   const double out = optimizer.Optimize(svm, parameters);
-  Timer::Stop("linear_svm_optimization");
 
   Log::Info << "LinearSVM::LinearSVM(): final objective of "
             << "trained model is " << out << "." << std::endl;
@@ -173,13 +168,7 @@ void LinearSVM<MatType>::Classify(
     const MatType& data,
     arma::mat& scores) const
 {
-  if (data.n_rows != FeatureSize())
-  {
-    std::ostringstream oss;
-    oss << "LinearSVM::Classify(): dataset has " << data.n_rows
-        << " dimensions, but model has " << FeatureSize() << " dimensions!";
-    throw std::invalid_argument(oss.str());
-  }
+  util::CheckSameDimensionality(data, FeatureSize(), "LinearSVM::Classify()");
 
   if (fitIntercept)
   {
@@ -214,7 +203,7 @@ double LinearSVM<MatType>::ComputeAccuracy(
 
   // Increment count for every correctly predicted label.
   size_t count = 0;
-  for (size_t i = 0; i < labels.n_elem ; i++)
+  for (size_t i = 0; i < labels.n_elem ; ++i)
     if (testLabels(i) == labels(i))
       count++;
 
@@ -222,7 +211,6 @@ double LinearSVM<MatType>::ComputeAccuracy(
   return (double) count / labels.n_elem;
 }
 
-} // namespace svm
 } // namespace mlpack
 
 #endif // MLPACK_METHODS_LINEAR_SVM_LINEAR_SVM_IMPL_HPP
