@@ -1,5 +1,5 @@
 /**
- * @file lcc.hpp
+ * @file methods/local_coordinate_coding/lcc.hpp
  * @author Nishant Mehta
  *
  * Definition of the LocalCoordinateCoding class, which performs the Local
@@ -13,16 +13,15 @@
 #ifndef MLPACK_METHODS_LOCAL_COORDINATE_CODING_LCC_HPP
 #define MLPACK_METHODS_LOCAL_COORDINATE_CODING_LCC_HPP
 
-#include <mlpack/prereqs.hpp>
+#include <mlpack/core.hpp>
 #include <mlpack/methods/lars/lars.hpp>
 
 // Include three simple dictionary initializers from sparse coding.
-#include "../sparse_coding/nothing_initializer.hpp"
-#include "../sparse_coding/data_dependent_random_initializer.hpp"
-#include "../sparse_coding/random_initializer.hpp"
+#include <mlpack/methods/sparse_coding/nothing_initializer.hpp>
+#include <mlpack/methods/sparse_coding/data_dependent_random_initializer.hpp>
+#include <mlpack/methods/sparse_coding/random_initializer.hpp>
 
 namespace mlpack {
-namespace lcc {
 
 /**
  * An implementation of Local Coordinate Coding (LCC) that codes data which
@@ -89,8 +88,7 @@ class LocalCoordinateCoding
    * Initialize(const arma::mat& data, arma::mat& dictionary) function), or call
    * the constructor that does not take a data matrix, then call Dictionary() to
    * set the dictionary matrix to a matrix of your choosing, and then call
-   * Train() with sparse_coding::NothingInitializer (i.e.
-   * Train<sparse_coding::NothingInitializer>(data)).
+   * Train() with NothingInitializer (i.e.  Train<NothingInitializer>(data)).
    *
    * @param data Data matrix.
    * @param atoms Number of atoms in dictionary.
@@ -98,11 +96,9 @@ class LocalCoordinateCoding
    * @param maxIterations Maximum number of iterations for training (0 runs
    *      until convergence).
    * @param tolerance Tolerance for the objective function.
+   * @param initializer Intializer to use.
    */
-  template<
-      typename DictionaryInitializer =
-          sparse_coding::DataDependentRandomInitializer
-  >
+  template<typename DictionaryInitializer = DataDependentRandomInitializer>
   LocalCoordinateCoding(const arma::mat& data,
                         const size_t atoms,
                         const double lambda,
@@ -131,16 +127,11 @@ class LocalCoordinateCoding
   /**
    * Run local coordinate coding.
    *
-   * @param nIterations Maximum number of iterations to run algorithm.
-   * @param objTolerance Tolerance of objective function.  When the objective
-   *     function changes by a value lower than this tolerance, the optimization
-   *     terminates.
+   * @param data Data matrix.
+   * @param initializer Intializer to use.
    * @return The final objective value.
    */
-  template<
-      typename DictionaryInitializer =
-          sparse_coding::DataDependentRandomInitializer
-  >
+  template<typename DictionaryInitializer = DataDependentRandomInitializer>
   double Train(const arma::mat& data,
                const DictionaryInitializer& initializer =
                    DictionaryInitializer());
@@ -156,6 +147,8 @@ class LocalCoordinateCoding
   /**
    * Learn dictionary by solving linear system.
    *
+   * @param data Matrix containing points to encode.
+   * @param codes Output matrix to store codes in.
    * @param adjacencies Indices of entries (unrolled column by column) of
    *    the coding matrix Z that are non-zero (the adjacency matrix for the
    *    bipartite graph of points and atoms)
@@ -166,6 +159,12 @@ class LocalCoordinateCoding
 
   /**
    * Compute objective function given the list of adjacencies.
+   *
+   * @param data Matrix containing points to encode.
+   * @param codes Output matrix to store codes in.
+   * @param adjacencies Indices of entries (unrolled column by column) of
+   *    the coding matrix Z that are non-zero (the adjacency matrix for the
+   *    bipartite graph of points and atoms)
    */
   double Objective(const arma::mat& data,
                    const arma::mat& codes,
@@ -198,7 +197,7 @@ class LocalCoordinateCoding
 
   //! Serialize the model.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
   //! Number of atoms in dictionary.
@@ -216,7 +215,6 @@ class LocalCoordinateCoding
   double tolerance;
 };
 
-} // namespace lcc
 } // namespace mlpack
 
 // Include implementation.
