@@ -18,7 +18,6 @@
 #include <mlpack/core.hpp>
 
 namespace mlpack {
-namespace regression {
 
 template<typename MatType>
 LogisticRegressionFunction<MatType>::LogisticRegressionFunction(
@@ -26,13 +25,11 @@ LogisticRegressionFunction<MatType>::LogisticRegressionFunction(
     const arma::Row<size_t>& responses,
     const double lambda) :
     // We promise to be well-behaved... the elements won't be modified.
-    predictors(math::MakeAlias(const_cast<MatType&>(predictors), false)),
-    responses(math::MakeAlias(const_cast<arma::Row<size_t>&>(responses),
+    predictors(MakeAlias(const_cast<MatType&>(predictors), false)),
+    responses(MakeAlias(const_cast<arma::Row<size_t>&>(responses),
         false)),
     lambda(lambda)
 {
-  initialPoint = arma::rowvec(predictors.n_rows + 1, arma::fill::zeros);
-
   // Sanity check.
   if (responses.n_elem != predictors.n_cols)
   {
@@ -43,25 +40,6 @@ LogisticRegressionFunction<MatType>::LogisticRegressionFunction(
   }
 }
 
-template<typename MatType>
-LogisticRegressionFunction<MatType>::LogisticRegressionFunction(
-    const MatType& predictors,
-    const arma::Row<size_t>& responses,
-    const arma::vec& initialPoint,
-    const double lambda) :
-    initialPoint(initialPoint),
-    // We promise to be well-behaved... the elements won't be modified.
-    predictors(math::MakeAlias(const_cast<MatType&>(predictors), false)),
-    responses(math::MakeAlias(const_cast<arma::Row<size_t>&>(responses),
-        false)),
-    lambda(lambda)
-{
-  // To check if initialPoint is compatible with predictors.
-  if (initialPoint.n_rows != (predictors.n_rows + 1) ||
-      initialPoint.n_cols != 1)
-    this->initialPoint = arma::rowvec(predictors.n_rows + 1, arma::fill::zeros);
-}
-
 /**
  * Shuffle the datapoints.
  */
@@ -71,11 +49,11 @@ void LogisticRegressionFunction<MatType>::Shuffle()
   MatType newPredictors;
   arma::Row<size_t> newResponses;
 
-  math::ShuffleData(predictors, responses, newPredictors, newResponses);
+  ShuffleData(predictors, responses, newPredictors, newResponses);
 
   // If we are an alias, make sure we don't write to the original data.
-  math::ClearAlias(predictors);
-  math::ClearAlias(responses);
+  ClearAlias(predictors);
+  ClearAlias(responses);
 
   // Take ownership of the new data.
   predictors = std::move(newPredictors);
@@ -299,7 +277,6 @@ double LogisticRegressionFunction<MatType>::EvaluateWithGradient(
   return objectiveRegularization - result;
 }
 
-} // namespace regression
 } // namespace mlpack
 
 #endif
