@@ -18,7 +18,6 @@
 #include "logistic_regression.hpp"
 
 namespace mlpack {
-namespace regression {
 
 template<typename MatType>
 LogisticRegression<MatType>::LogisticRegression(
@@ -90,10 +89,8 @@ double LogisticRegression<MatType>::Train(
   if (parameters.n_elem != predictors.n_rows + 1)
     parameters = arma::rowvec(predictors.n_rows + 1, arma::fill::zeros);
 
-  Timer::Start("logistic_regression_optimization");
   const double out = optimizer.Optimize(errorFunction, parameters,
       callbacks...);
-  Timer::Stop("logistic_regression_optimization");
 
   Log::Info << "LogisticRegression::LogisticRegression(): final objective of "
       << "trained model is " << out << "." << std::endl;
@@ -172,15 +169,13 @@ double LogisticRegression<MatType>::ComputeAccuracy(
 
 template<typename MatType>
 template<typename Archive>
-void LogisticRegression<MatType>::serialize(
-    Archive& ar,
-    const unsigned int /* version */)
+void LogisticRegression<MatType>::serialize(Archive& ar,
+    const uint32_t /* version */)
 {
-  ar & BOOST_SERIALIZATION_NVP(parameters);
-  ar & BOOST_SERIALIZATION_NVP(lambda);
+  ar(CEREAL_NVP(parameters));
+  ar(CEREAL_NVP(lambda));
 }
 
-} // namespace regression
 } // namespace mlpack
 
 #endif // MLPACK_METHODS_LOGISTIC_REGRESSION_LOGISTIC_REGRESSION_IMPL_HPP
