@@ -12,25 +12,31 @@
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
-#include <mlpack/core/data/normalize_labels.hpp>
+#include <mlpack/core.hpp>
+
+#undef BINDING_NAME
+#define BINDING_NAME nbc
+
 #include <mlpack/core/util/mlpack_main.hpp>
 
 #include "naive_bayes_classifier.hpp"
 
 using namespace mlpack;
-using namespace mlpack::naive_bayes;
 using namespace mlpack::util;
 using namespace std;
 using namespace arma;
 
-PROGRAM_INFO("Parametric Naive Bayes Classifier",
-    // Short description.
+// Program Name.
+BINDING_USER_NAME("Parametric Naive Bayes Classifier");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of the Naive Bayes Classifier, used for classification. "
     "Given labeled data, an NBC model can be trained and saved, or, a "
-    "pre-trained model can be used for classification.",
-    // Long description.
+    "pre-trained model can be used for classification.");
+
+// Long description.
+BINDING_LONG_DESC(
     "This program trains the Naive Bayes classifier on the given labeled "
     "training set, or loads a model from the given model file, and then may use"
     " that trained model to classify the points in a given test set."
@@ -60,8 +66,10 @@ PROGRAM_INFO("Parametric Naive Bayes Classifier",
     "Note: the " + PRINT_PARAM_STRING("output") + " and " +
     PRINT_PARAM_STRING("output_probs") + " parameters are deprecated and will "
     "be removed in mlpack 4.0.0.  Use " + PRINT_PARAM_STRING("predictions") +
-    " and " + PRINT_PARAM_STRING("probabilities") + " instead."
-    "\n\n"
+    " and " + PRINT_PARAM_STRING("probabilities") + " instead.");
+
+// Example.
+BINDING_EXAMPLE(
     "For example, to train a Naive Bayes classifier on the dataset " +
     PRINT_DATASET("data") + " with labels " + PRINT_DATASET("labels") + " "
     "and save the model to " + PRINT_MODEL("nbc_model") + ", the following "
@@ -76,14 +84,15 @@ PROGRAM_INFO("Parametric Naive Bayes Classifier",
     "may be used:"
     "\n\n" +
     PRINT_CALL("nbc", "input_model", "nbc_model", "test", "test_set", "output",
-        "predictions"),
-    SEE_ALSO("@softmax_regression", "#softmax_regression"),
-    SEE_ALSO("@random_forest", "#random_forest"),
-    SEE_ALSO("Naive Bayes classifier on Wikipedia",
-        "https://en.wikipedia.org/wiki/Naive_Bayes_classifier"),
-    SEE_ALSO("mlpack::naive_bayes::NaiveBayesClassifier C++ class "
-        "documentation", "@doxygen/classmlpack_1_1naive__bayes_1_1"
-        "NaiveBayesClassifier.html"));
+        "predictions"));
+
+// See also...
+BINDING_SEE_ALSO("@softmax_regression", "#softmax_regression");
+BINDING_SEE_ALSO("@random_forest", "#random_forest");
+BINDING_SEE_ALSO("Naive Bayes classifier on Wikipedia",
+    "https://en.wikipedia.org/wiki/Naive_Bayes_classifier");
+BINDING_SEE_ALSO("NaiveBayesClassifier C++ class documentation",
+    "@src/mlpack/methods/naive_bayes/naive_bayes_classifier.cpp");
 
 // A struct for saving the model with mappings.
 struct NBCModel
@@ -95,10 +104,10 @@ struct NBCModel
 
   //! Serialize the model.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(nbc);
-    ar & BOOST_SERIALIZATION_NVP(mappings);
+    ar(CEREAL_NVP(nbc));
+    ar(CEREAL_NVP(mappings));
   }
 };
 
@@ -128,33 +137,33 @@ PARAM_MATRIX_OUT("output_probs", "The matrix in which the predicted probability"
 PARAM_MATRIX_OUT("probabilities", "The matrix in which the predicted"
     " probability of labels for the test set will be written.", "p");
 
-static void mlpackMain()
+void BINDING_FUNCTION(util::Params& params, util::Timers& timers)
 {
   // Check input parameters.
-  RequireOnlyOnePassed({ "training", "input_model" }, true);
-  ReportIgnoredParam({{ "training", false }}, "labels");
-  ReportIgnoredParam({{ "training", false }}, "incremental_variance");
-  RequireAtLeastOnePassed({ "output", "predictions", "output_model",
+  RequireOnlyOnePassed(params, { "training", "input_model" }, true);
+  ReportIgnoredParam(params, {{ "training", false }}, "labels");
+  ReportIgnoredParam(params, {{ "training", false }}, "incremental_variance");
+  RequireAtLeastOnePassed(params, { "output", "predictions", "output_model",
       "output_probs", "probabilities" }, false, "no output will be saved");
-  ReportIgnoredParam({{ "test", false }}, "output");
-  ReportIgnoredParam({{ "test", false }}, "predictions");
-  if (CLI::HasParam("input_model") && !CLI::HasParam("test"))
+  ReportIgnoredParam(params, {{ "test", false }}, "output");
+  ReportIgnoredParam(params, {{ "test", false }}, "predictions");
+  if (params.Has("input_model") && !params.Has("test"))
     Log::Warn << "No test set given; no task will be performed!" << std::endl;
 
   // Either we have to train a model, or load a model.
   NBCModel* model;
-  if (CLI::HasParam("training"))
+  if (params.Has("training"))
   {
     model = new NBCModel();
-    mat trainingData = std::move(CLI::GetParam<mat>("training"));
+    mat trainingData = std::move(params.Get<mat>("training"));
 
     Row<size_t> labels;
 
     // Did the user pass in labels?
-    if (CLI::HasParam("labels"))
+    if (params.Has("labels"))
     {
       // Load labels.
-      Row<size_t> rawLabels = std::move(CLI::GetParam<Row<size_t>>("labels"));
+      Row<size_t> rawLabels = std::move(params.Get<Row<size_t>>("labels"));
       data::NormalizeLabels(rawLabels, labels, model->mappings);
     }
     else
@@ -167,23 +176,23 @@ static void mlpackMain()
       // Remove the label row.
       trainingData.shed_row(trainingData.n_rows - 1);
     }
-    const bool incrementalVariance = CLI::HasParam("incremental_variance");
+    const bool incrementalVariance = params.Has("incremental_variance");
 
-    Timer::Start("nbc_training");
+    timers.Start("nbc_training");
     model->nbc = NaiveBayesClassifier<>(trainingData, labels,
         model->mappings.n_elem, incrementalVariance);
-    Timer::Stop("nbc_training");
+    timers.Stop("nbc_training");
   }
   else
   {
     // Load the model from file.
-    model = CLI::GetParam<NBCModel*>("input_model");
+    model = params.Get<NBCModel*>("input_model");
   }
 
   // Do we need to do testing?
-  if (CLI::HasParam("test"))
+  if (params.Has("test"))
   {
-    mat testingData = std::move(CLI::GetParam<mat>("test"));
+    mat testingData = std::move(params.Get<mat>("test"));
 
     if (testingData.n_rows != model->nbc.Means().n_rows)
     {
@@ -195,29 +204,29 @@ static void mlpackMain()
     // Time the running of the Naive Bayes Classifier.
     Row<size_t> predictions;
     mat probabilities;
-    Timer::Start("nbc_testing");
+    timers.Start("nbc_testing");
     model->nbc.Classify(testingData, predictions, probabilities);
-    Timer::Stop("nbc_testing");
+    timers.Stop("nbc_testing");
 
-    if (CLI::HasParam("output") || CLI::HasParam("predictions"))
+    if (params.Has("output") || params.Has("predictions"))
     {
       // Un-normalize labels to prepare output.
       Row<size_t> rawResults;
       data::RevertLabels(predictions, model->mappings, rawResults);
 
-      if (CLI::HasParam("predictions"))
-        CLI::GetParam<Row<size_t>>("predictions") = rawResults;
-      if (CLI::HasParam("output"))
-        CLI::GetParam<Row<size_t>>("output") = std::move(rawResults);
+      if (params.Has("predictions"))
+        params.Get<Row<size_t>>("predictions") = rawResults;
+      if (params.Has("output"))
+        params.Get<Row<size_t>>("output") = std::move(rawResults);
     }
-    if (CLI::HasParam("output_probs") || CLI::HasParam("probabilities"))
+    if (params.Has("output_probs") || params.Has("probabilities"))
     {
-      if (CLI::HasParam("probabilities"))
-        CLI::GetParam<mat>("probabilities") = probabilities;
-      if (CLI::HasParam("output_probs"))
-        CLI::GetParam<mat>("output_probs") = std::move(probabilities);
+      if (params.Has("probabilities"))
+        params.Get<mat>("probabilities") = probabilities;
+      if (params.Has("output_probs"))
+        params.Get<mat>("output_probs") = std::move(probabilities);
     }
   }
 
-  CLI::GetParam<NBCModel*>("output_model") = model;
+  params.Get<NBCModel*>("output_model") = model;
 }
