@@ -19,7 +19,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace pca {
 
 /**
  * Implementation of the exact SVD policy.
@@ -45,7 +44,7 @@ class ExactSVDPolicy
              arma::mat& eigvec,
              const size_t /* rank */)
   {
-    // This matrix will store the right singular values; we do not need them.
+    // This matrix will store the right singular vectors; we do not need them.
     arma::mat v;
 
     // Do singular value decomposition.  Use the economical singular value
@@ -71,7 +70,6 @@ class ExactSVDPolicy
   }
 };
 
-} // namespace pca
 } // namespace mlpack
 
 #endif
