@@ -18,7 +18,6 @@
 #include <mlpack/methods/quic_svd/quic_svd.hpp>
 
 namespace mlpack {
-namespace pca {
 
 /**
  * Implementation of the QUIC-SVD policy.
@@ -57,11 +56,11 @@ class QUICSVDPolicy
              arma::mat& eigvec,
              const size_t /* rank */)
   {
-    // This matrix will store the right singular values; we do not need them.
+    // This matrix will store the right singular vectors; we do not need them.
     arma::mat v, sigma;
 
     // Do singular value decomposition using the QUIC-SVD algorithm.
-    svd::QUIC_SVD quicsvd(centeredData, eigvec, v, sigma, epsilon, delta);
+    QUIC_SVD quicsvd(centeredData, eigvec, v, sigma, epsilon, delta);
 
     // Now we must square the singular values to get the eigenvalues.
     // In addition we must divide by the number of points, because the
@@ -90,7 +89,6 @@ class QUICSVDPolicy
   double delta;
 };
 
-} // namespace pca
 } // namespace mlpack
 
 #endif
