@@ -9,21 +9,22 @@
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/io.hpp>
+#include <mlpack/core.hpp>
+
+#undef BINDING_NAME
+#define BINDING_NAME preprocess_describe
+
 #include <mlpack/core/util/mlpack_main.hpp>
 
-#include <boost/format.hpp>
-#include <boost/lexical_cast.hpp>
+#include <iomanip>
 
 using namespace mlpack;
 using namespace mlpack::data;
 using namespace mlpack::util;
 using namespace std;
-using namespace boost;
 
 // Program Name.
-BINDING_NAME("Descriptive Statistics");
+BINDING_USER_NAME("Descriptive Statistics");
 
 // Short description.
 BINDING_SHORT_DESC(
@@ -170,36 +171,24 @@ double StandardError(const size_t size, const double& fStd)
   return fStd / sqrt(size);
 }
 
-static void mlpackMain()
+void BINDING_FUNCTION(util::Params& params, util::Timers& timers)
 {
-  const size_t dimension = static_cast<size_t>(IO::GetParam<int>("dimension"));
-  const size_t precision = static_cast<size_t>(IO::GetParam<int>("precision"));
-  const size_t width = static_cast<size_t>(IO::GetParam<int>("width"));
-  const bool population = IO::HasParam("population");
-  const bool rowMajor = IO::HasParam("row_major");
+  const size_t dimension = static_cast<size_t>(params.Get<int>("dimension"));
+  const size_t precision = static_cast<size_t>(params.Get<int>("precision"));
+  const size_t width = static_cast<size_t>(params.Get<int>("width"));
+  const bool population = params.Has("population");
+  const bool rowMajor = params.Has("row_major");
 
   // Load the data.
-  arma::mat& data = IO::GetParam<arma::mat>("input");
+  arma::mat& data = params.Get<arma::mat>("input");
 
-  // Generate boost format recipe.
-  const string widthPrecision("%-" + to_string(width) + "." +
-      to_string(precision));
-  const string widthOnly("%-" + to_string(width) + ".");
-  string stringFormat = "";
-  string numberFormat = "";
-
-  // We are going to print 11 different categories.
-  for (size_t i = 0; i < 11; ++i)
-  {
-    stringFormat += widthOnly + "s";
-    numberFormat += widthPrecision + "f";
-  }
-
-  Timer::Start("statistics");
+  timers.Start("statistics");
   // Print the headers.
-  Log::Info << boost::format(stringFormat)
-      % "dim" % "var" % "mean" % "std" % "median" % "min" % "max"
-      % "range" % "skew" % "kurt" % "SE" << endl;
+  Log::Info << setw(width) << "dim" << setw(width) << "var" << setw(width) << 
+      "mean" << setw(width) << "std" << setw(width) << setw(width) << setw(width) << 
+      "median" << setw(width) << "min" << setw(width) << "max" << setw(width) << 
+      "range" << setw(width) << "skew" << setw(width) << "kurt" << setw(width) << 
+      "SE" << endl;
 
   // Lambda function to print out the results.
   auto PrintStatResults = [&](size_t dim, bool rowMajor)
@@ -217,24 +206,22 @@ static void mlpackMain()
     const double fStd = arma::stddev(feature, population);
 
     // Print statistics of the given dimension.
-    Log::Info << boost::format(numberFormat)
-        % dim
-        % arma::var(feature, population)
-        % fMean
-        % fStd
-        % arma::median(feature)
-        % fMin
-        % fMax
-        % (fMax - fMin) // range
-        % Skewness(feature, fStd, fMean, population)
-        % Kurtosis(feature, fStd, fMean, population)
-        % StandardError(feature.n_elem, fStd)
-        << endl;
+    Log::Info << setprecision(precision) << setw(width) << dim << 
+        setw(width) << arma::var(feature, population) << 
+        setw(width) << fMean << 
+        setw(width) << fStd <<
+        setw(width) << arma::median(feature) << 
+        setw(width) << fMin << 
+        setw(width) << fMax << 
+        setw(width) << (fMax - fMin) <<
+        setw(width) << Skewness(feature, fStd, fMean, population) <<
+        setw(width) << Kurtosis(feature, fStd, fMean, population) <<
+        setw(width) << StandardError(feature.n_elem, fStd) << endl;
   };
 
   // If the user specified dimension, describe statistics of the given
   // dimension. If a dimension is not specified, describe all dimensions.
-  if (IO::HasParam("dimension"))
+  if (params.Has("dimension"))
   {
     PrintStatResults(dimension, rowMajor);
   }
@@ -246,5 +233,5 @@ static void mlpackMain()
       PrintStatResults(i, rowMajor);
     }
   }
-  Timer::Stop("statistics");
+  timers.Stop("statistics");
 }
