@@ -16,14 +16,32 @@
 #include "random_forest.hpp"
 
 namespace mlpack {
-namespace tree {
 
 template<
     typename FitnessFunction,
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
+>
+RandomForest<
+    FitnessFunction,
+    DimensionSelectionType,
+    NumericSplitType,
+    CategoricalSplitType,
+    UseBootstrap
+>::RandomForest() :
+    avgGain(0.0)
+{
+  // Nothing to do here.
+}
+
+template<
+    typename FitnessFunction,
+    typename DimensionSelectionType,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType,
+    bool UseBootstrap
 >
 template<typename MatType>
 RandomForest<
@@ -31,7 +49,7 @@ RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::RandomForest(const MatType& dataset,
                 const arma::Row<size_t>& labels,
                 const size_t numClasses,
@@ -39,13 +57,15 @@ RandomForest<
                 const size_t minimumLeafSize,
                 const double minimumGainSplit,
                 const size_t maximumDepth,
-                DimensionSelectionType dimensionSelector)
+                DimensionSelectionType dimensionSelector) :
+    avgGain(0.0)
 {
   // Pass off work to the Train() method.
   data::DatasetInfo info; // Ignored.
   arma::rowvec weights; // Fake weights, not used.
   Train<false, false>(dataset, info, labels, numClasses, weights, numTrees,
-      minimumLeafSize, minimumGainSplit, maximumDepth, dimensionSelector);
+      minimumLeafSize, minimumGainSplit, maximumDepth, dimensionSelector,
+      false);
 }
 
 template<
@@ -53,7 +73,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 RandomForest<
@@ -61,7 +81,7 @@ RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::RandomForest(const MatType& dataset,
                 const data::DatasetInfo& datasetInfo,
                 const arma::Row<size_t>& labels,
@@ -70,13 +90,14 @@ RandomForest<
                 const size_t minimumLeafSize,
                 const double minimumGainSplit,
                 const size_t maximumDepth,
-                DimensionSelectionType dimensionSelector)
+                DimensionSelectionType dimensionSelector):
+                    avgGain(0.0)
 {
   // Pass off work to the Train() method.
   arma::rowvec weights; // Fake weights, not used.
   Train<false, true>(dataset, datasetInfo, labels, numClasses, weights,
       numTrees, minimumLeafSize, minimumGainSplit, maximumDepth,
-      dimensionSelector);
+      dimensionSelector, false);
 }
 
 template<
@@ -84,7 +105,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 RandomForest<
@@ -92,7 +113,7 @@ RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::RandomForest(const MatType& dataset,
                 const arma::Row<size_t>& labels,
                 const size_t numClasses,
@@ -101,12 +122,14 @@ RandomForest<
                 const size_t minimumLeafSize,
                 const double minimumGainSplit,
                 const size_t maximumDepth,
-                DimensionSelectionType dimensionSelector)
+                DimensionSelectionType dimensionSelector) :
+    avgGain(0.0)
 {
   // Pass off work to the Train() method.
   data::DatasetInfo info; // Ignored by Train().
   Train<true, false>(dataset, info, labels, numClasses, weights, numTrees,
-      minimumLeafSize, minimumGainSplit, maximumDepth, dimensionSelector);
+      minimumLeafSize, minimumGainSplit, maximumDepth, dimensionSelector,
+      false);
 }
 
 template<
@@ -114,7 +137,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 RandomForest<
@@ -122,7 +145,7 @@ RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::RandomForest(const MatType& dataset,
                 const data::DatasetInfo& datasetInfo,
                 const arma::Row<size_t>& labels,
@@ -132,11 +155,13 @@ RandomForest<
                 const size_t minimumLeafSize,
                 const double minimumGainSplit,
                 const size_t maximumDepth,
-                DimensionSelectionType dimensionSelector)
+                DimensionSelectionType dimensionSelector) :
+    avgGain(0.0)
 {
   // Pass off work to the Train() method.
-  Train<true, true>(dataset, datasetInfo, labels, numClasses, weights, numTrees,
-      minimumLeafSize, minimumGainSplit, maximumDepth, dimensionSelector);
+  Train<true, true>(dataset, datasetInfo, labels, numClasses, weights,
+      numTrees, minimumLeafSize, minimumGainSplit, maximumDepth,
+      dimensionSelector, false);
 }
 
 template<
@@ -144,7 +169,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 double RandomForest<
@@ -152,7 +177,7 @@ double RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Train(const MatType& dataset,
          const arma::Row<size_t>& labels,
          const size_t numClasses,
@@ -160,14 +185,15 @@ double RandomForest<
          const size_t minimumLeafSize,
          const double minimumGainSplit,
          const size_t maximumDepth,
+         const bool warmStart,
          DimensionSelectionType dimensionSelector)
 {
   // Pass off to Train().
-  data::DatasetInfo info; // Ignored by Train().
+  data::DatasetInfo datasetInfo; // Ignored by Train().
   arma::rowvec weights; // Ignored by Train().
-  return Train<false, false>(dataset, info, labels, numClasses, weights,
+  return Train<false, false>(dataset, datasetInfo, labels, numClasses, weights,
       numTrees, minimumLeafSize, minimumGainSplit, maximumDepth,
-      dimensionSelector);
+      dimensionSelector, warmStart);
 }
 
 template<
@@ -175,7 +201,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 double RandomForest<
@@ -183,7 +209,7 @@ double RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Train(const MatType& dataset,
          const data::DatasetInfo& datasetInfo,
          const arma::Row<size_t>& labels,
@@ -192,13 +218,14 @@ double RandomForest<
          const size_t minimumLeafSize,
          const double minimumGainSplit,
          const size_t maximumDepth,
+         const bool warmStart,
          DimensionSelectionType dimensionSelector)
 {
   // Pass off to Train().
   arma::rowvec weights; // Ignored by Train().
   return Train<false, true>(dataset, datasetInfo, labels, numClasses, weights,
       numTrees, minimumLeafSize, minimumGainSplit, maximumDepth,
-      dimensionSelector);
+      dimensionSelector, warmStart);
 }
 
 template<
@@ -206,7 +233,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 double RandomForest<
@@ -214,7 +241,7 @@ double RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Train(const MatType& dataset,
          const arma::Row<size_t>& labels,
          const size_t numClasses,
@@ -223,13 +250,14 @@ double RandomForest<
          const size_t minimumLeafSize,
          const double minimumGainSplit,
          const size_t maximumDepth,
+         const bool warmStart,
          DimensionSelectionType dimensionSelector)
 {
   // Pass off to Train().
-  data::DatasetInfo info; // Ignored by Train().
-  return Train<false, false>(dataset, info, labels, numClasses, weights,
+  data::DatasetInfo datasetInfo; // Ignored by Train().
+  return Train<false, false>(dataset, datasetInfo, labels, numClasses, weights,
       numTrees, minimumLeafSize, minimumGainSplit, maximumDepth,
-      dimensionSelector);
+      dimensionSelector, warmStart);
 }
 
 template<
@@ -237,7 +265,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 double RandomForest<
@@ -245,7 +273,7 @@ double RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Train(const MatType& dataset,
          const data::DatasetInfo& datasetInfo,
          const arma::Row<size_t>& labels,
@@ -255,12 +283,13 @@ double RandomForest<
          const size_t minimumLeafSize,
          const double minimumGainSplit,
          const size_t maximumDepth,
+         const bool warmStart,
          DimensionSelectionType dimensionSelector)
 {
   // Pass off to Train().
   return Train<true, true>(dataset, datasetInfo, labels, numClasses, weights,
       numTrees, minimumLeafSize, minimumGainSplit, maximumDepth,
-      dimensionSelector);
+      dimensionSelector, warmStart);
 }
 
 template<
@@ -268,7 +297,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename VecType>
 size_t RandomForest<
@@ -276,7 +305,7 @@ size_t RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Classify(const VecType& point) const
 {
   // Pass off to another Classify() overload.
@@ -292,7 +321,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename VecType>
 void RandomForest<
@@ -300,7 +329,7 @@ void RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Classify(const VecType& point,
             size_t& prediction,
             arma::vec& probabilities) const
@@ -339,7 +368,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 void RandomForest<
@@ -347,7 +376,7 @@ void RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Classify(const MatType& data,
             arma::Row<size_t>& predictions) const
 {
@@ -363,7 +392,7 @@ void RandomForest<
   predictions.set_size(data.n_cols);
 
   #pragma omp parallel for
-  for (omp_size_t i = 0; i < data.n_cols; ++i)
+  for (size_t i = 0; i < data.n_cols; ++i)
   {
     predictions[i] = Classify(data.col(i));
   }
@@ -374,7 +403,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename MatType>
 void RandomForest<
@@ -382,7 +411,7 @@ void RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Classify(const MatType& data,
             arma::Row<size_t>& predictions,
             arma::mat& probabilities) const
@@ -400,7 +429,7 @@ void RandomForest<
   probabilities.set_size(trees[0].NumClasses(), data.n_cols);
   predictions.set_size(data.n_cols);
   #pragma omp parallel for
-  for (omp_size_t i = 0; i < data.n_cols; ++i)
+  for (size_t i = 0; i < data.n_cols; ++i)
   {
     arma::vec probs = probabilities.unsafe_col(i);
     Classify(data.col(i), predictions[i], probs);
@@ -412,7 +441,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<typename Archive>
 void RandomForest<
@@ -420,22 +449,23 @@ void RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
->::serialize(Archive& ar, const unsigned int /* version */)
+    UseBootstrap
+>::serialize(Archive& ar, const uint32_t /* version */)
 {
   size_t numTrees;
-  if (Archive::is_loading::value)
+  if (cereal::is_loading<Archive>())
     trees.clear();
   else
     numTrees = trees.size();
 
-  ar & BOOST_SERIALIZATION_NVP(numTrees);
+  ar(CEREAL_NVP(numTrees));
 
   // Allocate space if needed.
-  if (Archive::is_loading::value)
+  if (cereal::is_loading<Archive>())
     trees.resize(numTrees);
 
-  ar & BOOST_SERIALIZATION_NVP(trees);
+  ar(CEREAL_NVP(trees));
+  ar(CEREAL_NVP(avgGain));
 }
 
 template<
@@ -443,7 +473,7 @@ template<
     typename DimensionSelectionType,
     template<typename> class NumericSplitType,
     template<typename> class CategoricalSplitType,
-    typename ElemType
+    bool UseBootstrap
 >
 template<bool UseWeights, bool UseDatasetInfo, typename MatType>
 double RandomForest<
@@ -451,7 +481,7 @@ double RandomForest<
     DimensionSelectionType,
     NumericSplitType,
     CategoricalSplitType,
-    ElemType
+    UseBootstrap
 >::Train(const MatType& dataset,
          const data::DatasetInfo& datasetInfo,
          const arma::Row<size_t>& labels,
@@ -461,60 +491,101 @@ double RandomForest<
          const size_t minimumLeafSize,
          const double minimumGainSplit,
          const size_t maximumDepth,
-         DimensionSelectionType& dimensionSelector)
+         DimensionSelectionType& dimensionSelector,
+         const bool warmStart)
 {
-  // Train each tree individually.
-  trees.resize(numTrees); // This will fill the vector with untrained trees.
-  double avgGain = 0.0;
+  // Reset the forest if we are not doing a warm-start.
+  if (!warmStart)
+    trees.clear();
+  const size_t oldNumTrees = trees.size();
+  trees.resize(trees.size() + numTrees);
 
-  #pragma omp parallel for reduction( + : avgGain)
-  for (omp_size_t i = 0; i < numTrees; ++i)
+  // Convert avgGain to total gain.
+  double totalGain = avgGain * oldNumTrees;
+
+  // Train each tree individually.
+  #pragma omp parallel for reduction( + : totalGain)
+  for (size_t i = 0; i < numTrees; ++i)
   {
-    Timer::Start("bootstrap");
+    // NOTE: this is a hacky workaround for older versions of Armadillo that did
+    // not (by default) set a different seed for each RNG.  We simply manually
+    // set the RNG seed for each individual thread.  However, if users have
+    // specifically set the RNG seed for Armadillo, this could break their code.
+    // So we hide it behind an (undocumented except for here) ifndef so that
+    // this support can be disabled if desired...
+    #undef MLPACK_ARMA_VERSION
+    #define MLPACK_ARMA_VERSION (ARMA_VERSION_MAJOR * 100000 + \
+                                 ARMA_VERSION_MINOR *    100 + \
+                                 ARMA_VERSION_PATCH)
+    #if (MLPACK_ARMA_VERSION < 1200602) // 12.6.2
+      #ifndef MLPACK_DONT_OVERWRITE_ARMA_RNG_SEEDS
+      // Note that each thread has its own differently-seeded RNG, so this will
+      // result in a different seed for each thread's Armadillo RNG.
+      arma::arma_rng::set_seed(RandGen()());
+      #endif
+    #endif
+
     MatType bootstrapDataset;
     arma::Row<size_t> bootstrapLabels;
     arma::rowvec bootstrapWeights;
-    Bootstrap<UseWeights>(dataset, labels, weights, bootstrapDataset,
-        bootstrapLabels, bootstrapWeights);
-    Timer::Stop("bootstrap");
+    if (UseBootstrap)
+    {
+      Bootstrap<UseWeights>(dataset, labels, weights, bootstrapDataset,
+          bootstrapLabels, bootstrapWeights);
+    }
 
-    // Now build the decision tree.
-    Timer::Start("train_tree");
     if (UseWeights)
     {
       if (UseDatasetInfo)
       {
-        avgGain += trees[i].Train(bootstrapDataset, datasetInfo,
-            bootstrapLabels, numClasses, bootstrapWeights, minimumLeafSize,
-            minimumGainSplit, maximumDepth, dimensionSelector);
+        totalGain += UseBootstrap ?
+            trees[oldNumTrees + i].Train(bootstrapDataset, datasetInfo,
+                bootstrapLabels, numClasses, bootstrapWeights, minimumLeafSize,
+                minimumGainSplit, maximumDepth, dimensionSelector) :
+            trees[oldNumTrees + i].Train(dataset, datasetInfo, labels,
+                numClasses, weights, minimumLeafSize, minimumGainSplit,
+                maximumDepth, dimensionSelector);
       }
       else
       {
-        avgGain += trees[i].Train(bootstrapDataset, bootstrapLabels, numClasses,
-            bootstrapWeights, minimumLeafSize, minimumGainSplit, maximumDepth,
-            dimensionSelector);
+        totalGain += UseBootstrap ?
+            trees[oldNumTrees + i].Train(bootstrapDataset, bootstrapLabels,
+                numClasses, bootstrapWeights, minimumLeafSize,
+                minimumGainSplit, maximumDepth, dimensionSelector) :
+            trees[oldNumTrees + i].Train(dataset, labels, numClasses,
+                weights, minimumLeafSize, minimumGainSplit, maximumDepth,
+                dimensionSelector);
       }
     }
     else
     {
       if (UseDatasetInfo)
       {
-        avgGain += trees[i].Train(bootstrapDataset, datasetInfo,
-            bootstrapLabels, numClasses, minimumLeafSize, minimumGainSplit,
-            maximumDepth, dimensionSelector);
+        totalGain += UseBootstrap ?
+            trees[oldNumTrees + i].Train(bootstrapDataset, datasetInfo,
+                bootstrapLabels, numClasses, minimumLeafSize, minimumGainSplit,
+                maximumDepth, dimensionSelector) :
+            trees[oldNumTrees + i].Train(dataset, datasetInfo, labels,
+                numClasses, minimumLeafSize, minimumGainSplit, maximumDepth,
+                dimensionSelector);
       }
       else
       {
-        avgGain += trees[i].Train(bootstrapDataset, bootstrapLabels, numClasses,
-            minimumLeafSize, minimumGainSplit, maximumDepth, dimensionSelector);
+        totalGain += UseBootstrap ?
+            trees[oldNumTrees + i].Train(bootstrapDataset, bootstrapLabels,
+                numClasses, minimumLeafSize, minimumGainSplit, maximumDepth,
+                dimensionSelector) :
+            trees[oldNumTrees + i].Train(dataset, labels, numClasses,
+                minimumLeafSize, minimumGainSplit, maximumDepth,
+                dimensionSelector);
       }
     }
-    Timer::Stop("train_tree");
   }
-  return avgGain / numTrees;
+
+  avgGain = totalGain / trees.size();
+  return avgGain;
 }
 
-} // namespace tree
 } // namespace mlpack
 
 #endif
