@@ -19,28 +19,6 @@
 #include "range_search_rules.hpp"
 
 namespace mlpack {
-namespace range {
-
-template<typename TreeType, typename MatType>
-TreeType* BuildTree(
-    MatType&& dataset,
-    std::vector<size_t>& oldFromNew,
-    const typename std::enable_if<
-        tree::TreeTraits<TreeType>::RearrangesDataset>::type* = 0)
-{
-  return new TreeType(std::forward<MatType>(dataset), oldFromNew);
-}
-
-//! Call the tree constructor that does not do mapping.
-template<typename TreeType, typename MatType>
-TreeType* BuildTree(
-    MatType&& dataset,
-    const std::vector<size_t>& /* oldFromNew */,
-    const typename std::enable_if<
-        !tree::TreeTraits<TreeType>::RearrangesDataset>::type* = 0)
-{
-  return new TreeType(std::forward<MatType>(dataset));
-}
 
 template<typename MetricType,
          typename MatType,
@@ -169,25 +147,61 @@ template<typename MetricType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType>
 RangeSearch<MetricType, MatType, TreeType>&
-RangeSearch<MetricType, MatType, TreeType>::operator=(RangeSearch other)
+RangeSearch<MetricType, MatType, TreeType>::operator=(const RangeSearch& other)
 {
-  // Clean memory first.
-  if (treeOwner)
-    delete referenceTree;
-  if (naive)
-    delete referenceSet;
+  if (this != &other)
+  {
+    oldFromNewReferences = other.oldFromNewReferences;
+    referenceTree = other.referenceTree ? new Tree(*other.referenceTree) :
+        nullptr;
+    referenceSet = other.referenceTree ? &referenceTree->Dataset() :
+        new MatType(*other.referenceSet);
+    treeOwner = other.referenceTree;
+    naive = other.naive;
+    singleMode = other.singleMode;
+    metric = other.metric;
+    baseCases = other.baseCases;
+    scores = other.scores;
+  }
+  return *this;
+}
 
-  // Move the other model.
-  oldFromNewReferences = std::move(other.oldFromNewReferences);
-  referenceTree = other.referenceTree;
-  referenceSet = other.referenceSet;
-  treeOwner = other.treeOwner;
-  naive = other.naive;
-  singleMode = other.singleMode;
-  metric = std::move(other.metric);
-  baseCases = other.baseCases;
-  scores = other.scores;
+template<typename MetricType,
+         typename MatType,
+         template<typename TreeMetricType,
+                  typename TreeStatType,
+                  typename TreeMatType> class TreeType>
+RangeSearch<MetricType, MatType, TreeType>&
+RangeSearch<MetricType, MatType, TreeType>::operator=(RangeSearch&& other)
+{
+  if (this != &other)
+  {
+    // Clean memory first.
+    if (treeOwner)
+      delete referenceTree;
+    if (naive)
+      delete referenceSet;
 
+    // Move the other model.
+    oldFromNewReferences = std::move(other.oldFromNewReferences);
+    referenceTree = other.referenceTree;
+    referenceSet = other.referenceSet;
+    treeOwner = other.treeOwner;
+    naive = other.naive;
+    singleMode = other.singleMode;
+    metric = std::move(other.metric);
+    baseCases = other.baseCases;
+    scores = other.scores;
+
+    // Clear other object.
+    other.referenceTree = nullptr;
+    other.referenceSet = nullptr;
+    other.treeOwner = false;
+    other.naive = false;
+    other.singleMode = false;
+    other.baseCases = 0;
+    other.scores = 0;
+  }
   return *this;
 }
 
@@ -254,12 +268,15 @@ void RangeSearch<MetricType, MatType, TreeType>::Train(
     throw std::invalid_argument("cannot train on given reference tree when "
         "naive search (without trees) is desired");
 
+  // Can only train when passed argument `referenceTree` is not nullptr.
   if (treeOwner && referenceTree)
+  {
     delete this->referenceTree;
 
-  this->referenceTree = referenceTree;
-  this->referenceSet = &referenceTree->Dataset();
-  treeOwner = false;
+    this->referenceTree = referenceTree;
+    this->referenceSet = &referenceTree->Dataset();
+    treeOwner = false;
+  }
 }
 
 template<typename MetricType,
@@ -269,25 +286,17 @@ template<typename MetricType,
                   typename TreeMatType> class TreeType>
 void RangeSearch<MetricType, MatType, TreeType>::Search(
     const MatType& querySet,
-    const math::Range& range,
+    const Range& range,
     std::vector<std::vector<size_t>>& neighbors,
     std::vector<std::vector<double>>& distances)
 {
-  if (querySet.n_rows != referenceSet->n_rows)
-  {
-    std::ostringstream oss;
-    oss << "RangeSearch::Search(): dimensionalities of query set ("
-        << querySet.n_rows << ") and reference set (" << referenceSet->n_rows
-        << ") do not match!";
-    throw std::invalid_argument(oss.str());
-  }
+  util::CheckSameDimensionality(querySet, *referenceSet,
+      "RangeSearch::Search()", "query set");
 
   // If there are no points, there is no search to be done.
   if (referenceSet->n_cols == 0)
     return;
 
-  Timer::Start("range_search/computing_neighbors");
-
   // This will hold mappings for query points, if necessary.
   std::vector<size_t> oldFromNewQueries;
 
@@ -299,7 +308,7 @@ void RangeSearch<MetricType, MatType, TreeType>::Search(
   std::vector<std::vector<double>>* distancePtr = &distances;
 
   // Mapping is only necessary if the tree rearranges points.
-  if (tree::TreeTraits<Tree>::RearrangesDataset)
+  if (TreeTraits<Tree>::RearrangesDataset)
   {
     // Query indices only need to be mapped if we are building the query tree
     // ourselves.
@@ -357,11 +366,7 @@ void RangeSearch<MetricType, MatType, TreeType>::Search(
   else // Dual-tree recursion.
   {
     // Build the query tree.
-    Timer::Stop("range_search/computing_neighbors");
-    Timer::Start("range_search/tree_building");
     Tree* queryTree = BuildTree<Tree>(querySet, oldFromNewQueries);
-    Timer::Stop("range_search/tree_building");
-    Timer::Start("range_search/computing_neighbors");
 
     // Create the traverser.
     RuleType rules(*referenceSet, queryTree->Dataset(), range, *neighborPtr,
@@ -377,10 +382,8 @@ void RangeSearch<MetricType, MatType, TreeType>::Search(
     delete queryTree;
   }
 
-  Timer::Stop("range_search/computing_neighbors");
-
   // Map points back to original indices, if necessary.
-  if (tree::TreeTraits<Tree>::RearrangesDataset)
+  if (TreeTraits<Tree>::RearrangesDataset)
   {
     if (!singleMode && !naive && treeOwner)
     {
@@ -453,7 +456,7 @@ template<typename MetricType,
                   typename TreeMatType> class TreeType>
 void RangeSearch<MetricType, MatType, TreeType>::Search(
     Tree* queryTree,
-    const math::Range& range,
+    const Range& range,
     std::vector<std::vector<size_t>>& neighbors,
     std::vector<std::vector<double>>& distances)
 {
@@ -461,8 +464,6 @@ void RangeSearch<MetricType, MatType, TreeType>::Search(
   if (referenceSet->n_cols == 0)
     return;
 
-  Timer::Start("range_search/computing_neighbors");
-
   // Get a reference to the query set.
   const MatType& querySet = queryTree->Dataset();
 
@@ -474,7 +475,7 @@ void RangeSearch<MetricType, MatType, TreeType>::Search(
   // We won't need to map query indices, but will we need to map distances?
   std::vector<std::vector<size_t>>* neighborPtr = &neighbors;
 
-  if (treeOwner && tree::TreeTraits<Tree>::RearrangesDataset)
+  if (treeOwner && TreeTraits<Tree>::RearrangesDataset)
     neighborPtr = new std::vector<std::vector<size_t>>;
 
   // Resize each vector.
@@ -493,13 +494,11 @@ void RangeSearch<MetricType, MatType, TreeType>::Search(
 
   traverser.Traverse(*queryTree, *referenceTree);
 
-  Timer::Stop("range_search/computing_neighbors");
-
   baseCases = rules.BaseCases();
   scores = rules.Scores();
 
   // Do we need to map indices?
-  if (treeOwner && tree::TreeTraits<Tree>::RearrangesDataset)
+  if (treeOwner && TreeTraits<Tree>::RearrangesDataset)
   {
     // We must map reference indices only.
     neighbors.clear();
@@ -523,7 +522,7 @@ template<typename MetricType,
                   typename TreeStatType,
                   typename TreeMatType> class TreeType>
 void RangeSearch<MetricType, MatType, TreeType>::Search(
-    const math::Range& range,
+    const Range& range,
     std::vector<std::vector<size_t>>& neighbors,
     std::vector<std::vector<double>>& distances)
 {
@@ -531,13 +530,11 @@ void RangeSearch<MetricType, MatType, TreeType>::Search(
   if (referenceSet->n_cols == 0)
     return;
 
-  Timer::Start("range_search/computing_neighbors");
-
   // Here, we will use the query set as the reference set.
   std::vector<std::vector<size_t>>* neighborPtr = &neighbors;
   std::vector<std::vector<double>>* distancePtr = &distances;
 
-  if (tree::TreeTraits<Tree>::RearrangesDataset && treeOwner)
+  if (TreeTraits<Tree>::RearrangesDataset && treeOwner)
   {
     // We will always need to rearrange in this case.
     distancePtr = new std::vector<std::vector<double>>;
@@ -588,10 +585,8 @@ void RangeSearch<MetricType, MatType, TreeType>::Search(
     scores = rules.Scores();
   }
 
-  Timer::Stop("range_search/computing_neighbors");
-
   // Do we need to map the reference indices?
-  if (treeOwner && tree::TreeTraits<Tree>::RearrangesDataset)
+  if (treeOwner && TreeTraits<Tree>::RearrangesDataset)
   {
     neighbors.clear();
     neighbors.resize(referenceSet->n_cols);
@@ -625,15 +620,14 @@ template<typename MetricType,
                   typename TreeMatType> class TreeType>
 template<typename Archive>
 void RangeSearch<MetricType, MatType, TreeType>::serialize(
-    Archive& ar,
-    const unsigned int /* version */)
+    Archive& ar, const uint32_t /* version */)
 {
   // Serialize preferences for search.
-  ar & BOOST_SERIALIZATION_NVP(naive);
-  ar & BOOST_SERIALIZATION_NVP(singleMode);
+  ar(CEREAL_NVP(naive));
+  ar(CEREAL_NVP(singleMode));
 
   // Reset base cases and scores if we are loading.
-  if (Archive::is_loading::value)
+  if (cereal::is_loading<Archive>())
   {
     baseCases = 0;
     scores = 0;
@@ -643,17 +637,17 @@ void RangeSearch<MetricType, MatType, TreeType>::serialize(
   // serialize the tree.
   if (naive)
   {
-    if (Archive::is_loading::value)
+    if (cereal::is_loading<Archive>())
     {
       if (referenceSet)
         delete referenceSet;
     }
 
-    ar & BOOST_SERIALIZATION_NVP(referenceSet);
-    ar & BOOST_SERIALIZATION_NVP(metric);
+    ar(CEREAL_POINTER(const_cast<MatType*&>(referenceSet)));
+    ar(CEREAL_NVP(metric));
 
     // If we are loading, set the tree to NULL and clean up memory if necessary.
-    if (Archive::is_loading::value)
+    if (cereal::is_loading<Archive>())
     {
       if (treeOwner && referenceTree)
         delete referenceTree;
@@ -666,7 +660,7 @@ void RangeSearch<MetricType, MatType, TreeType>::serialize(
   else
   {
     // Delete the current reference tree, if necessary and if we are loading.
-    if (Archive::is_loading::value)
+    if (cereal::is_loading<Archive>())
     {
       if (treeOwner && referenceTree)
         delete referenceTree;
@@ -675,12 +669,12 @@ void RangeSearch<MetricType, MatType, TreeType>::serialize(
       treeOwner = true;
     }
 
-    ar & BOOST_SERIALIZATION_NVP(referenceTree);
-    ar & BOOST_SERIALIZATION_NVP(oldFromNewReferences);
+    ar(CEREAL_POINTER(referenceTree));
+    ar(CEREAL_NVP(oldFromNewReferences));
 
     // If we are loading, set the dataset accordingly and clean up memory if
     // necessary.
-    if (Archive::is_loading::value)
+    if (cereal::is_loading<Archive>())
     {
       referenceSet = &referenceTree->Dataset();
       metric = referenceTree->Metric(); // Get the metric from the tree.
@@ -688,7 +682,6 @@ void RangeSearch<MetricType, MatType, TreeType>::serialize(
   }
 }
 
-} // namespace range
 } // namespace mlpack
 
 #endif
