@@ -16,7 +16,6 @@
 #include "ra_search_rules.hpp"
 
 namespace mlpack {
-namespace neighbor {
 
 template<typename SortPolicy, typename MetricType, typename TreeType>
 RASearchRules<SortPolicy, MetricType, TreeType>::
@@ -58,9 +57,7 @@ RASearchRules(const arma::mat& referenceSet,
         << t << " points; because k = " << k << ", this is exact search!"
         << std::endl;
 
-  Timer::Start("computing_number_of_samples_reqd");
   numSamplesReqd = RAUtil::MinimumSamplesReqd(n, k, tau, alpha);
-  Timer::Stop("computing_number_of_samples_reqd");
 
   // Initialize some statistics to be collected during the search.
   numSamplesMade = arma::zeros<arma::Col<size_t> >(querySet.n_cols);
@@ -90,7 +87,7 @@ RASearchRules(const arma::mat& referenceSet,
     arma::uvec distinctSamples;
     for (size_t i = 0; i < querySet.n_cols; ++i)
     {
-      math::ObtainDistinctSamples(0, n, numSamplesReqd, distinctSamples);
+      ObtainDistinctSamples(0, n, numSamplesReqd, distinctSamples);
       for (size_t j = 0; j < distinctSamples.n_elem; ++j)
         BaseCase(i, (size_t) distinctSamples[j]);
     }
@@ -118,7 +115,7 @@ void RASearchRules<SortPolicy, MetricType, TreeType>::GetResults(
 };
 
 template<typename SortPolicy, typename MetricType, typename TreeType>
-inline force_inline
+inline mlpack_force_inline
 double RASearchRules<SortPolicy, MetricType, TreeType>::BaseCase(
     const size_t queryIndex,
     const size_t referenceIndex)
@@ -204,7 +201,7 @@ inline double RASearchRules<SortPolicy, MetricType, TreeType>::Score(
           // Then samplesReqd <= singleSampleLimit.
           // Hence, approximate the node by sampling enough number of points.
           arma::uvec distinctSamples;
-          math::ObtainDistinctSamples(0, referenceNode.NumDescendants(),
+          ObtainDistinctSamples(0, referenceNode.NumDescendants(),
               samplesReqd, distinctSamples);
           for (size_t i = 0; i < distinctSamples.n_elem; ++i)
             // The counting of the samples are done in the 'BaseCase' function
@@ -220,7 +217,7 @@ inline double RASearchRules<SortPolicy, MetricType, TreeType>::Score(
           {
             // Approximate node by sampling enough number of points.
             arma::uvec distinctSamples;
-            math::ObtainDistinctSamples(0, referenceNode.NumDescendants(),
+            ObtainDistinctSamples(0, referenceNode.NumDescendants(),
                 samplesReqd, distinctSamples);
             for (size_t i = 0; i < distinctSamples.n_elem; ++i)
               // The counting of the samples are done in the 'BaseCase' function
@@ -308,7 +305,7 @@ Rescore(const size_t queryIndex,
         // Then, samplesReqd <= singleSampleLimit.  Hence, approximate the node
         // by sampling enough number of points.
         arma::uvec distinctSamples;
-        math::ObtainDistinctSamples(0, referenceNode.NumDescendants(),
+        ObtainDistinctSamples(0, referenceNode.NumDescendants(),
             samplesReqd, distinctSamples);
         for (size_t i = 0; i < distinctSamples.n_elem; ++i)
           // The counting of the samples are done in the 'BaseCase' function so
@@ -324,7 +321,7 @@ Rescore(const size_t queryIndex,
         {
           // Approximate node by sampling enough points.
           arma::uvec distinctSamples;
-          math::ObtainDistinctSamples(0, referenceNode.NumDescendants(),
+          ObtainDistinctSamples(0, referenceNode.NumDescendants(),
               samplesReqd, distinctSamples);
           for (size_t i = 0; i < distinctSamples.n_elem; ++i)
             // The counting of the samples are done in the 'BaseCase' function
@@ -511,7 +508,7 @@ inline double RASearchRules<SortPolicy, MetricType, TreeType>::Score(
           for (size_t i = 0; i < queryNode.NumDescendants(); ++i)
           {
             const size_t queryIndex = queryNode.Descendant(i);
-            math::ObtainDistinctSamples(0, referenceNode.NumDescendants(),
+            ObtainDistinctSamples(0, referenceNode.NumDescendants(),
                 samplesReqd, distinctSamples);
             for (size_t j = 0; j < distinctSamples.n_elem; ++j)
               // The counting of the samples are done in the 'BaseCase' function
@@ -541,7 +538,7 @@ inline double RASearchRules<SortPolicy, MetricType, TreeType>::Score(
             for (size_t i = 0; i < queryNode.NumDescendants(); ++i)
             {
               const size_t queryIndex = queryNode.Descendant(i);
-              math::ObtainDistinctSamples(0, referenceNode.NumDescendants(),
+              ObtainDistinctSamples(0, referenceNode.NumDescendants(),
                   samplesReqd, distinctSamples);
               for (size_t j = 0; j < distinctSamples.n_elem; ++j)
                 // The counting of the samples are done in the 'BaseCase'
@@ -716,7 +713,7 @@ Rescore(TreeType& queryNode,
         for (size_t i = 0; i < queryNode.NumDescendants(); ++i)
         {
           const size_t queryIndex = queryNode.Descendant(i);
-          math::ObtainDistinctSamples(0, referenceNode.NumDescendants(),
+          ObtainDistinctSamples(0, referenceNode.NumDescendants(),
               samplesReqd, distinctSamples);
           for (size_t j = 0; j < distinctSamples.n_elem; ++j)
             // The counting of the samples are done in the 'BaseCase'
@@ -745,7 +742,7 @@ Rescore(TreeType& queryNode,
           for (size_t i = 0; i < queryNode.NumDescendants(); ++i)
           {
             const size_t queryIndex = queryNode.Descendant(i);
-            math::ObtainDistinctSamples(0, referenceNode.NumDescendants(),
+            ObtainDistinctSamples(0, referenceNode.NumDescendants(),
                 samplesReqd, distinctSamples);
             for (size_t j = 0; j < distinctSamples.n_elem; ++j)
               // The counting of the samples are done in BaseCase() so no
@@ -822,7 +819,6 @@ InsertNeighbor(
   }
 }
 
-} // namespace neighbor
 } // namespace mlpack
 
 #endif // MLPACK_METHODS_RANN_RA_SEARCH_RULES_IMPL_HPP
