@@ -13,9 +13,9 @@
 #define MLPACK_METHODS_RL_REPLAY_RANDOM_REPLAY_HPP
 
 #include <mlpack/prereqs.hpp>
+#include <cassert>
 
 namespace mlpack {
-namespace rl {
 
 /**
  * Implementation of random experience replay.
@@ -49,11 +49,21 @@ class RandomReplay
   //! Convenient typedef for state.
   using StateType = typename EnvironmentType::State;
 
+  struct Transition
+  {
+    StateType state;
+    ActionType action;
+    double reward;
+    StateType nextState;
+    bool isEnd;
+  };
+
   RandomReplay():
       batchSize(0),
       capacity(0),
       position(0),
-      full(false)
+      full(false),
+      nSteps(0)
   { /* Nothing to do here. */ }
 
   /**
@@ -61,20 +71,23 @@ class RandomReplay
    *
    * @param batchSize Number of examples returned at each sample.
    * @param capacity Total memory size in terms of number of examples.
+   * @param nSteps Number of steps to look in the future.
    * @param dimension The dimension of an encoded state.
    */
   RandomReplay(const size_t batchSize,
                const size_t capacity,
+               const size_t nSteps = 1,
                const size_t dimension = StateType::dimension) :
       batchSize(batchSize),
       capacity(capacity),
       position(0),
+      full(false),
+      nSteps(nSteps),
       states(dimension, capacity),
       actions(capacity),
       rewards(capacity),
       nextStates(dimension, capacity),
-      isTerminal(capacity),
-      full(false)
+      isTerminal(capacity)
   { /* Nothing to do here. */ }
 
   /**
@@ -85,15 +98,36 @@ class RandomReplay
    * @param reward Given reward.
    * @param nextState Given next state.
    * @param isEnd Whether next state is terminal state.
+   * @param discount The discount parameter.
    */
-  void Store(const StateType& state,
+  void Store(StateType state,
              ActionType action,
              double reward,
-             const StateType& nextState,
-             bool isEnd)
+             StateType nextState,
+             bool isEnd,
+             const double& discount)
   {
+    nStepBuffer.push_back({state, action, reward, nextState, isEnd});
+
+    // Single step transition is not ready.
+    if (nStepBuffer.size() < nSteps)
+      return;
+
+    // To keep the queue size fixed to nSteps.
+    if (nStepBuffer.size() > nSteps)
+      nStepBuffer.pop_front();
+
+    // Before moving ahead, lets confirm if our fixed size buffer works.
+    assert(nStepBuffer.size() == nSteps);
+
+    // Make a n-step transition.
+    GetNStepInfo(reward, nextState, isEnd, discount);
+
+    state = nStepBuffer.front().state;
+    action = nStepBuffer.front().action;
+
     states.col(position) = state.Encode();
-    actions(position) = action;
+    actions[position] = action;
     rewards(position) = reward;
     nextStates.col(position) = nextState.Encode();
     isTerminal(position) = isEnd;
@@ -105,6 +139,36 @@ class RandomReplay
     }
   }
 
+  /**
+   * Get the reward, next state and terminal boolean for nth step.
+   *
+   * @param reward Given reward.
+   * @param nextState Given next state.
+   * @param isEnd Whether next state is terminal state.
+   * @param discount The discount parameter.
+   */
+  void GetNStepInfo(double& reward,
+                    StateType& nextState,
+                    bool& isEnd,
+                    const double& discount)
+  {
+    reward = nStepBuffer.back().reward;
+    nextState = nStepBuffer.back().nextState;
+    isEnd = nStepBuffer.back().isEnd;
+
+    // Should start from the second last transition in buffer.
+    for (int i = nStepBuffer.size() - 2; i >= 0; i--)
+    {
+      bool iE = nStepBuffer[i].isEnd;
+      reward = nStepBuffer[i].reward + discount * reward * (1 - iE);
+      if (iE)
+      {
+        nextState = nStepBuffer[i].nextState;
+        isEnd = iE;
+      }
+    }
+  }
+
   /**
    * Sample some experiences.
    *
@@ -116,20 +180,21 @@ class RandomReplay
    *        state.
    */
   void Sample(arma::mat& sampledStates,
-              arma::icolvec& sampledActions,
-              arma::colvec& sampledRewards,
+              std::vector<ActionType>& sampledActions,
+              arma::rowvec& sampledRewards,
               arma::mat& sampledNextStates,
-              arma::icolvec& isTerminal)
+              arma::irowvec& isTerminal)
   {
     size_t upperBound = full ? capacity : position;
     arma::uvec sampledIndices = arma::randi<arma::uvec>(
         batchSize, arma::distr_param(0, upperBound - 1));
 
     sampledStates = states.cols(sampledIndices);
-    sampledActions = actions.elem(sampledIndices);
-    sampledRewards = rewards.elem(sampledIndices);
+    for (size_t t = 0; t < sampledIndices.n_rows; t ++)
+      sampledActions.push_back(actions[sampledIndices[t]]);
+    sampledRewards = rewards.elem(sampledIndices).t();
     sampledNextStates = nextStates.cols(sampledIndices);
-    isTerminal = this->isTerminal.elem(sampledIndices);
+    isTerminal = this->isTerminal.elem(sampledIndices).t();
   }
 
   /**
@@ -151,13 +216,16 @@ class RandomReplay
    * @param * (gradients) The model's gradients
    */
   void Update(arma::mat /* target */,
-              arma::icolvec /* sampledActions */,
+              std::vector<ActionType> /* sampledActions */,
               arma::mat /* nextActionValues */,
               arma::mat& /* gradients */)
   {
     /* Do nothing for random replay. */
   }
 
+  //! Get the number of steps for n-step agent.
+  const size_t& NSteps() const { return nSteps; }
+
  private:
   //! Locally-stored number of examples of each sample.
   size_t batchSize;
@@ -168,26 +236,31 @@ class RandomReplay
   //! Indicate the position to store new transition.
   size_t position;
 
+  //! Locally-stored indicator that whether the memory is full or not
+  bool full;
+
+  //! Locally-stored number of steps to look into the future.
+  size_t nSteps;
+
+  //! Locally-stored buffer containing n consecutive steps.
+  std::deque<Transition> nStepBuffer;
+
   //! Locally-stored encoded previous states.
   arma::mat states;
 
   //! Locally-stored previous actions.
-  arma::icolvec actions;
+  std::vector<ActionType> actions;
 
   //! Locally-stored previous rewards.
-  arma::colvec rewards;
+  arma::rowvec rewards;
 
   //! Locally-stored encoded previous next states.
   arma::mat nextStates;
 
   //! Locally-stored termination information of previous experience.
-  arma::icolvec isTerminal;
-
-  //! Locally-stored indicator that whether the memory is full or not
-  bool full;
+  arma::irowvec isTerminal;
 };
 
-} // namespace rl
 } // namespace mlpack
 
 #endif
