@@ -13,10 +13,10 @@
 #ifndef MLPACK_METHODS_RL_WORKER_ONE_STEP_SARSA_WORKER_HPP
 #define MLPACK_METHODS_RL_WORKER_ONE_STEP_SARSA_WORKER_HPP
 
+#include <ensmallen.hpp>
 #include <mlpack/methods/reinforcement_learning/training_config.hpp>
 
 namespace mlpack {
-namespace rl {
 
 /**
  * One step Sarsa worker.
@@ -418,7 +418,6 @@ class OneStepSarsaWorker
   ActionType action;
 };
 
-} // namespace rl
 } // namespace mlpack
 
 #endif
