@@ -24,7 +24,9 @@
 #include "layer/convolution.cpp"
 #include "layer/concat.cpp"
 #include "layer/concatenate.cpp"
+#include "layer/c_relu.cpp"
 #include "layer/dropout.cpp"
+#include "layer/flexible_relu.cpp"
 #include "layer/grouped_convolution.cpp"
 #include "layer/hard_tanh.cpp"
 #include "layer/identity.cpp"
@@ -35,5 +37,9 @@
 #include "layer/mean_pooling.cpp"
 #include "layer/padding.cpp"
 #include "layer/parametric_relu.cpp"
+#include "layer/relu6.cpp"
 #include "layer/softmax.cpp"
 #include "layer/softmin.cpp"
+#include "layer/ftswish.cpp"
+#include "layer/layer_norm.cpp"
+#include "layer/multihead_attention.cpp"
