@@ -10,15 +10,11 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
-#include <mlpack/methods/linear_svm/linear_svm.hpp>
-#include <ensmallen.hpp>
+#include <mlpack/methods/linear_svm.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "catch.hpp"
 
 using namespace mlpack;
-using namespace mlpack::svm;
-using namespace mlpack::distribution;
 
 /**
  * Callback test function, based on the EndOptimization callback function.
@@ -40,12 +36,10 @@ class CallbackTestFunction
   bool calledEndOptimization;
 };
 
-BOOST_AUTO_TEST_SUITE(LinearSVMTest);
-
 /**
  * A simple test for LinearSVMFunction
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFunctionEvaluate)
+TEST_CASE("LinearSVMFunctionEvaluate", "[LinearSVMTest]")
 {
   // A very simple fake dataset
   arma::mat dataset = "2 0 0;"
@@ -63,30 +57,30 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionEvaluate)
   // These were hand-calculated using Python.
   arma::mat parameters = "1 1 1 1 1;"
                          "1 1 1 1 1";
-  BOOST_REQUIRE_CLOSE(svmf.Evaluate(parameters.t()), 1.0, 1e-5);
+  REQUIRE(svmf.Evaluate(parameters.t()) == Approx(1.0).epsilon(1e-7));
 
   parameters = "2 0 1 2 2;"
                "1 2 2 2 2";
-  BOOST_REQUIRE_CLOSE(svmf.Evaluate(parameters.t()), 2.0, 1e-5);
+  REQUIRE(svmf.Evaluate(parameters.t()) == Approx(2.0).epsilon(1e-7));
 
   parameters = "-0.1425 8.3228 0.1724 -0.3374 0.1548;"
                "0.1435 0.0009 -0.1736 0.3356 -0.1544";
-  BOOST_REQUIRE_CLOSE(svmf.Evaluate(parameters.t()), 0.0, 1e-5);
+  REQUIRE(svmf.Evaluate(parameters.t()) == Approx(0.0).epsilon(1e-7));
 
   parameters = "100 3 4 5 23;"
                "43 54 67 32 64";
-  BOOST_REQUIRE_CLOSE(svmf.Evaluate(parameters.t()), 85.33333333, 1e-5);
+  REQUIRE(svmf.Evaluate(parameters.t()) == Approx(85.33333333).epsilon(1e-7));
 
   parameters = "3 71 22 12 6;"
                "100 39 30 57 22";
-  BOOST_REQUIRE_CLOSE(svmf.Evaluate(parameters.t()), 11.0, 1e-5);
+  REQUIRE(svmf.Evaluate(parameters.t()) == Approx(11.0).epsilon(1e-7));
 }
 
 /**
  * A complicated test for the LinearSVMFunction for binary-class
  * classification.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFunctionRandomBinaryEvaluate)
+TEST_CASE("LinearSVMFunctionRandomBinaryEvaluate", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t trials = 10;
@@ -101,7 +95,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRandomBinaryEvaluate)
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   // Create a LinearSVMFunction, Regularization term ignored.
   LinearSVMFunction<arma::mat> svmf(data, labels, numClasses,
@@ -134,7 +128,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRandomBinaryEvaluate)
     hingeLoss /= points;
 
     // Compare with the value returned by the function.
-    BOOST_REQUIRE_CLOSE(svmf.Evaluate(parameters), hingeLoss, 1e-5);
+    REQUIRE(svmf.Evaluate(parameters) == Approx(hingeLoss).epsilon(1e-7));
   }
 }
 
@@ -142,7 +136,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRandomBinaryEvaluate)
  * A complicated test for the LinearSVMFunction for multi-class
  * classification.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFunctionRandomEvaluate)
+TEST_CASE("LinearSVMFunctionRandomEvaluate", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t trials = 10;
@@ -157,7 +151,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRandomEvaluate)
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   // Create a LinearSVMFunction, Regularization term ignored.
   LinearSVMFunction<arma::mat> svmf(data, labels, numClasses,
@@ -190,7 +184,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRandomEvaluate)
     hingeLoss /= points;
 
     // Compare with the value returned by the function.
-    BOOST_REQUIRE_CLOSE(svmf.Evaluate(parameters), hingeLoss, 1e-5);
+    REQUIRE(svmf.Evaluate(parameters) == Approx(hingeLoss).epsilon(1e-7));
   }
 }
 
@@ -198,7 +192,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRandomEvaluate)
  * Test regularization for the LinearSVMFunction Evaluate()
  * function.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationEvaluate)
+TEST_CASE("LinearSVMFunctionRegularizationEvaluate", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t trials = 10;
@@ -212,7 +206,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationEvaluate)
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   // 3 objects for comparing regularization costs.
   LinearSVMFunction<arma::mat> svmfNoReg(data, labels, numClasses, 0);
@@ -233,10 +227,10 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationEvaluate)
     const double smallRegTerm = 0.5 * wL2SquaredNorm;
     const double bigRegTerm = 10 * wL2SquaredNorm;
 
-    BOOST_REQUIRE_CLOSE(svmfNoReg.Evaluate(parameters) + smallRegTerm,
-                        svmfSmallReg.Evaluate(parameters), 1e-5);
-    BOOST_REQUIRE_CLOSE(svmfNoReg.Evaluate(parameters) + bigRegTerm,
-                        svmfBigReg.Evaluate(parameters), 1e-5);
+    REQUIRE(svmfNoReg.Evaluate(parameters) + smallRegTerm ==
+        Approx(svmfSmallReg.Evaluate(parameters)).epsilon(1e-7));
+    REQUIRE(svmfNoReg.Evaluate(parameters) + bigRegTerm ==
+        Approx(svmfBigReg.Evaluate(parameters)).epsilon(1e-7));
   }
 }
 
@@ -244,7 +238,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationEvaluate)
  * Test individual Evaluate() functions to be used for
  * optimization.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableEvaluate)
+TEST_CASE("LinearSVMFunctionSeparableEvaluate", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t trials = 10;
@@ -258,7 +252,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableEvaluate)
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   LinearSVMFunction<> svmf(data, labels, numClasses);
 
@@ -275,7 +269,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableEvaluate)
     hingeLoss /= points;
 
     // Compare with the value returned by the function.
-    BOOST_REQUIRE_CLOSE(svmf.Evaluate(parameters), hingeLoss, 1e-5);
+    REQUIRE(svmf.Evaluate(parameters) == Approx(hingeLoss).epsilon(1e-7));
   }
 }
 
@@ -284,7 +278,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableEvaluate)
  * Test regularization for the separable Evaluate() function
  * to be used Optimizers.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationSeparableEvaluate)
+TEST_CASE("LinearSVMFunctionRegularizationSeparableEvaluate", "[LinearSVMTest]")
 {
   const size_t points = 100;
   const size_t trials = 3;
@@ -298,7 +292,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationSeparableEvaluate)
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   LinearSVMFunction<> svmfNoReg(data, labels, numClasses, 0.0);
   LinearSVMFunction<> svmfSmallReg(data, labels, numClasses, 0.5);
@@ -306,9 +300,9 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationSeparableEvaluate)
 
 
   // Check that the number of functions is correct.
-  BOOST_REQUIRE_EQUAL(svmfNoReg.NumFunctions(), points);
-  BOOST_REQUIRE_EQUAL(svmfSmallReg.NumFunctions(), points);
-  BOOST_REQUIRE_EQUAL(svmfBigReg.NumFunctions(), points);
+  REQUIRE(svmfNoReg.NumFunctions() == points);
+  REQUIRE(svmfSmallReg.NumFunctions() == points);
+  REQUIRE(svmfBigReg.NumFunctions() == points);
 
 
   for (size_t i = 0; i < trials; ++i)
@@ -326,10 +320,10 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationSeparableEvaluate)
 
     for (size_t j = 0; j < points; ++j)
     {
-      BOOST_REQUIRE_CLOSE(svmfNoReg.Evaluate(parameters, j, 1) + smallRegTerm,
-          svmfSmallReg.Evaluate(parameters, j, 1), 1e-5);
-      BOOST_REQUIRE_CLOSE(svmfNoReg.Evaluate(parameters, j, 1) + bigRegTerm,
-          svmfBigReg.Evaluate(parameters, j, 1), 1e-5);
+      REQUIRE(svmfNoReg.Evaluate(parameters, j, 1) + smallRegTerm ==
+          Approx(svmfSmallReg.Evaluate(parameters, j, 1)).epsilon(1e-7));
+      REQUIRE(svmfNoReg.Evaluate(parameters, j, 1) + bigRegTerm ==
+          Approx(svmfBigReg.Evaluate(parameters, j, 1)).epsilon(1e-7));
     }
   }
 }
@@ -337,7 +331,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionRegularizationSeparableEvaluate)
 /**
  * Test Gradient() of the LinearSVMFunction.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFunctionGradient)
+TEST_CASE("LinearSVMFunctionGradient", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t trials = 10;
@@ -352,7 +346,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionGradient)
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   // Create a LinearSVMFunction, Regularization term ignored.
   LinearSVMFunction<arma::mat> svmf(data, labels, numClasses,
@@ -400,7 +394,8 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionGradient)
     {
       for (size_t k = 0; k < numClasses ; ++k)
       {
-        BOOST_REQUIRE_CLOSE(gradient(j, k), evaluatedGradient(j, k), 1e-5);
+        REQUIRE(gradient(j, k) ==
+            Approx(evaluatedGradient(j, k)).epsilon(1e-7));
       }
     }
   }
@@ -410,7 +405,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionGradient)
  * Test separable Gradient() of the LinearSVMFunction when regularization
  * is used.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableGradient)
+TEST_CASE("LinearSVMFunctionSeparableGradient", "[LinearSVMTest]")
 {
   const size_t points = 100;
   const size_t trials = 3;
@@ -424,7 +419,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableGradient)
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   LinearSVMFunction<> svmfNoReg(data, labels, numClasses, 0.0);
   LinearSVMFunction<> svmfSmallReg(data, labels, numClasses, 0.5);
@@ -448,9 +443,9 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableGradient)
       svmfBigReg.Gradient(parameters, k, bigRegGradient, 1);
 
       // Check sizes of gradients.
-      BOOST_REQUIRE_EQUAL(gradient.n_elem, parameters.n_elem);
-      BOOST_REQUIRE_EQUAL(smallRegGradient.n_elem, parameters.n_elem);
-      BOOST_REQUIRE_EQUAL(bigRegGradient.n_elem, parameters.n_elem);
+      REQUIRE(gradient.n_elem == parameters.n_elem);
+      REQUIRE(smallRegGradient.n_elem == parameters.n_elem);
+      REQUIRE(bigRegGradient.n_elem == parameters.n_elem);
 
       // Check other terms.
       for (size_t j = 0; j < parameters.n_elem; ++j)
@@ -458,9 +453,10 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableGradient)
         const double smallRegTerm = 0.5 * parameters[j];
         const double bigRegTerm = 20.0 * parameters[j];
 
-        BOOST_REQUIRE_CLOSE(gradient[j] + smallRegTerm, smallRegGradient[j],
-                            1e-5);
-        BOOST_REQUIRE_CLOSE(gradient[j] + bigRegTerm, bigRegGradient[j], 1e-5);
+        REQUIRE(gradient[j] + smallRegTerm ==
+            Approx(smallRegGradient[j]).epsilon(1e-7));
+        REQUIRE(gradient[j] + bigRegTerm ==
+            Approx(bigRegGradient[j]).epsilon(1e-7));
       }
     }
   }
@@ -470,7 +466,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMFunctionSeparableGradient)
  * Test training of linear svm on a simple dataset using
  * L-BFGS optimizer
  */
-BOOST_AUTO_TEST_CASE(LinearSVMLBFGSSimpleTest)
+TEST_CASE("LinearSVMLBFGSSimpleTest", "[LinearSVMTest]")
 {
   const size_t numClasses = 2;
   const double lambda = 0.0001;
@@ -490,14 +486,14 @@ BOOST_AUTO_TEST_CASE(LinearSVMLBFGSSimpleTest)
 
   // Compare training accuracy to 1.
   const double acc = lsvm.ComputeAccuracy(dataset, labels);
-  BOOST_REQUIRE_CLOSE(acc, 1.0, 0.5);
+  REQUIRE(acc == Approx(1.0).epsilon(0.005));
 }
 
 /**
  * Test training of linear svm on a simple dataset using
  * Gradient Descent optimizer
  */
-BOOST_AUTO_TEST_CASE(LinearSVMGradientDescentSimpleTest)
+TEST_CASE("LinearSVMGradientDescentSimpleTest", "[LinearSVMTest]")
 {
   const size_t numClasses = 2;
   const size_t maxIterations = 10000;
@@ -523,14 +519,14 @@ BOOST_AUTO_TEST_CASE(LinearSVMGradientDescentSimpleTest)
 
   // Compare training accuracy to 1.
   const double acc = lsvm.ComputeAccuracy(dataset, labels);
-  BOOST_REQUIRE_CLOSE(acc, 1.0, 0.5);
+  REQUIRE(acc == Approx(1.0).epsilon(0.005));
 }
 
 /**
  * Test training of linear svm for two classes on a complex gaussian dataset
  * using L-BFGS optimizer.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMLBFGSTwoClasses)
+TEST_CASE("LinearSVMLBFGSTwoClasses", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t inputSize = 3;
@@ -594,7 +590,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMLBFGSTwoClasses)
     }
   }
 
-  BOOST_REQUIRE_EQUAL(success, true);
+  REQUIRE(success == true);
 }
 
 /**
@@ -602,7 +598,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMLBFGSTwoClasses)
  * using L-BFGS optimizer which can't be separated without adding
  * the intercept term.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMFitIntercept)
+TEST_CASE("LinearSVMFitIntercept", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t inputSize = 3;
@@ -668,14 +664,14 @@ BOOST_AUTO_TEST_CASE(LinearSVMFitIntercept)
     }
   }
 
-  BOOST_REQUIRE_EQUAL(success, true);
+  REQUIRE(success == true);
 }
 
 /**
  * Test training of linear svm on a simple dataset using
  * Gradient Descent optimizer and with another value of delta.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMDeltaLBFGSTwoClasses)
+TEST_CASE("LinearSVMDeltaLBFGSTwoClasses", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t inputSize = 3;
@@ -742,20 +738,20 @@ BOOST_AUTO_TEST_CASE(LinearSVMDeltaLBFGSTwoClasses)
     }
   }
 
-  BOOST_REQUIRE_EQUAL(success, true);
+  REQUIRE(success == true);
 }
 
 /**
  * The test is only compiled if the user has specified OpenMP to be
  * used.
  */
-#ifdef HAS_OPENMP
+#ifdef MLPACK_USE_OPENMP
 
 /**
  * Test training of linear svm on a simple dataset using
  * Parallel SGD optimizer.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMPSGDSimpleTest)
+TEST_CASE("LinearSVMPSGDSimpleTest", "[LinearSVMTest]")
 {
   const size_t numClasses = 2;
   const double lambda = 0.5;
@@ -784,14 +780,14 @@ BOOST_AUTO_TEST_CASE(LinearSVMPSGDSimpleTest)
 
   // Compare training accuracy to 1.
   const double acc = lsvm.ComputeAccuracy(dataset, labels);
-  BOOST_REQUIRE_CLOSE(acc, 1.0, 1.0);
+  REQUIRE(acc == Approx(1.0).epsilon(1e-2));
 }
 
 /**
  * Test training of linear svm for two classes on a complex gaussian dataset
  * using Parallel SGD optimizer.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMParallelSGDTwoClasses)
+TEST_CASE("LinearSVMParallelSGDTwoClasses", "[LinearSVMTest]")
 {
   const size_t points = 500;
   const size_t inputSize = 3;
@@ -818,35 +814,50 @@ BOOST_AUTO_TEST_CASE(LinearSVMParallelSGDTwoClasses)
     labels(i) = 1;
   }
 
-  ens::ConstantStep decayPolicy(alpha);
-
-  // Train linear svm object using Parallel SGD optimizer.
-  // The threadShareSize is chosen such that each function gets optimized.
-  ens::ParallelSGD<ens::ConstantStep> optimizer(0,
-      std::ceil((float) data.n_cols / omp_get_max_threads()),
-      1e-5, true, decayPolicy);
-  LinearSVM<arma::mat> lsvm(data, labels, numClasses, lambda,
-      delta, false, optimizer);
-
-  // Compare training accuracy to 1.
-  const double acc = lsvm.ComputeAccuracy(data, labels);
-  BOOST_REQUIRE_CLOSE(acc, 1.0, 3.5);
-
-  // Create test dataset.
-  for (size_t i = 0; i < points / 2; ++i)
+  // We run the test multiple times, since it sometimes fails, in order to get
+  // the probability of failure down.
+  bool success = false;
+  const size_t trials = 4;
+  for (size_t trial = 0; trial < trials; ++trial)
   {
-    data.col(i) = g1.Random();
-    labels(i) =  0;
-  }
-  for (size_t i = points / 2; i < points; ++i)
-  {
-    data.col(i) = g2.Random();
-    labels(i) = 1;
+    ens::ConstantStep decayPolicy(alpha);
+
+    // Train linear svm object using Parallel SGD optimizer.
+    // The threadShareSize is chosen such that each function gets optimized.
+    ens::ParallelSGD<ens::ConstantStep> optimizer(0,
+        std::ceil((float) data.n_cols / omp_get_max_threads()),
+        1e-5, true, decayPolicy);
+    LinearSVM<arma::mat> lsvm(data, labels, numClasses, lambda,
+        delta, false, optimizer);
+
+    // Compare training accuracy to 1.
+    const double acc = lsvm.ComputeAccuracy(data, labels);
+
+    // Create test dataset.
+    for (size_t i = 0; i < points / 2; ++i)
+    {
+      data.col(i) = g1.Random();
+      labels(i) =  0;
+    }
+    for (size_t i = points / 2; i < points; ++i)
+    {
+      data.col(i) = g2.Random();
+      labels(i) = 1;
+    }
+
+    // Compare test accuracy to 1.
+    const double testAcc = lsvm.ComputeAccuracy(data, labels);
+
+    // Larger tolerance is sometimes needed.
+    if (testAcc == Approx(1.0).epsilon(0.02) &&
+        acc == Approx(1.0).epsilon(0.02))
+    {
+      success = true;
+      break;
+    }
   }
 
-  // Compare test accuracy to 1.
-  const double testAcc = lsvm.ComputeAccuracy(data, labels);
-  BOOST_REQUIRE_CLOSE(testAcc, 1.0, 3.5);
+  REQUIRE(success == true);
 }
 
 #endif
@@ -855,7 +866,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMParallelSGDTwoClasses)
  * Test sparse and dense linear svm and make sure they both work the
  * same using the L-BFGS optimizer.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMSparseLBFGSTest)
+TEST_CASE("LinearSVMSparseLBFGSTest", "[LinearSVMTest]")
 {
   // Create a random dataset.
   arma::sp_mat dataset;
@@ -863,23 +874,26 @@ BOOST_AUTO_TEST_CASE(LinearSVMSparseLBFGSTest)
   arma::mat denseDataset(dataset);
   arma::Row<size_t> labels(800);
   for (size_t i = 0; i < 800; ++i)
-    labels[i] = math::RandInt(0, 2);
+    labels[i] = RandInt(0, 2);
 
   LinearSVM<arma::mat> lr(denseDataset, labels, 2, 0.3, 1,
       false, ens::L_BFGS());
   LinearSVM<arma::sp_mat> lrSparse(dataset, labels, 2, 0.3, 1,
       false, ens::L_BFGS());
 
-  BOOST_REQUIRE_EQUAL(lr.Parameters().n_elem, lrSparse.Parameters().n_elem);
+  REQUIRE(lr.Parameters().n_elem == lrSparse.Parameters().n_elem);
   for (size_t i = 0; i < lr.Parameters().n_elem; ++i)
-    BOOST_REQUIRE_CLOSE(lr.Parameters()[i], lrSparse.Parameters()[i], 5e-4);
+  {
+    REQUIRE(lr.Parameters()[i] == Approx(lrSparse.Parameters()[i]).
+        epsilon(5e-6));
+  }
 }
 
 /**
  * Test training of linear svm for multiple classes on a complex gaussian
  * dataset using L-BFGS optimizer.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMLBFGSMultipleClasses)
+TEST_CASE("LinearSVMLBFGSMultipleClasses", "[LinearSVMTest]")
 {
   const size_t points = 1000;
   const size_t inputSize = 5;
@@ -975,13 +989,13 @@ BOOST_AUTO_TEST_CASE(LinearSVMLBFGSMultipleClasses)
     }
   }
 
-  BOOST_REQUIRE_EQUAL(success, true);
+  REQUIRE(success == true);
 }
 
 /**
  * Testing single point classification (Classify()).
  */
-BOOST_AUTO_TEST_CASE(LinearSVMClassifySinglePointTest)
+TEST_CASE("LinearSVMClassifySinglePointTest", "[LinearSVMTest]")
 {
   const size_t points = 500;
   const size_t inputSize = 5;
@@ -1059,7 +1073,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMClassifySinglePointTest)
 
   for (size_t i = 0; i < data.n_cols; ++i)
   {
-    BOOST_REQUIRE_EQUAL(lsvm.Classify(data.col(i)), labels(i));
+    REQUIRE(lsvm.Classify(data.col(i)) == labels(i));
   }
 }
 
@@ -1067,7 +1081,7 @@ BOOST_AUTO_TEST_CASE(LinearSVMClassifySinglePointTest)
  * Test that single-point classification gives the same results as multi-point
  * classification.
  */
-BOOST_AUTO_TEST_CASE(SinglePointClassifyTest)
+TEST_CASE("SinglePointClassifyTest", "[LinearSVMTest]")
 {
   const size_t points = 500;
   const size_t inputSize = 5;
@@ -1148,14 +1162,14 @@ BOOST_AUTO_TEST_CASE(SinglePointClassifyTest)
   {
     size_t pred = lsvm.Classify(data.col(i));
 
-    BOOST_REQUIRE_EQUAL(pred, predictions[i]);
+    REQUIRE(pred == predictions[i]);
   }
 }
 
 /**
  * Test a Linear SVM model with EndOptimization callback.
  */
-BOOST_AUTO_TEST_CASE(LinearSVMCallbackTest)
+TEST_CASE("LinearSVMCallbackTest", "[LinearSVMTest]")
 {
   const size_t numClasses = 2;
   const double lambda = 0.0001;
@@ -1177,7 +1191,5 @@ BOOST_AUTO_TEST_CASE(LinearSVMCallbackTest)
   LinearSVM<arma::mat> lsvm(dataset, labels, numClasses, lambda,
       delta, false, opt, cb);
 
-  BOOST_REQUIRE(cb.calledEndOptimization == true);
+  REQUIRE(cb.calledEndOptimization == true);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
