@@ -13,17 +13,13 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
-#include <mlpack/core/metrics/lmetric.hpp>
-#include <mlpack/methods/lmnn/lmnn.hpp>
-#include <ensmallen.hpp>
-#include <mlpack/methods/neighbor_search/neighbor_search.hpp>
+#include <mlpack/methods/lmnn.hpp>
+#include <mlpack/methods/neighbor_search.hpp>
 
 #include "catch.hpp"
 #include "test_catch_tools.hpp"
 
 using namespace mlpack;
-using namespace mlpack::metric;
-using namespace mlpack::lmnn;
 using namespace ens;
 
 //
@@ -120,7 +116,7 @@ TEST_CASE("LMNNInitialPointTest", "[LMNNTest]")
     for (int col = 0; col < 5; col++)
     {
       if (row == col)
-        REQUIRE(initialPoint(row, col) == Approx( 1.0).epsilon(1e-7));
+        REQUIRE(initialPoint(row, col) == Approx(1.0).epsilon(1e-7));
       else
         REQUIRE(initialPoint(row, col) == Approx(0.0).margin(1e-5));
     }
@@ -207,8 +203,8 @@ TEST_CASE("LMNNSeparableObjectiveTest", "[LMNNTest]")
 
   // Result calculated by hand.
   arma::mat coordinates = arma::eye<arma::mat>(2, 2);
-  REQUIRE(lmnnfn.Evaluate(coordinates, 0, 1) == Approx( 1.576).epsilon(1e-7));
-  REQUIRE(lmnnfn.Evaluate(coordinates, 1, 1) == Approx( 1.576).epsilon(1e-7));
+  REQUIRE(lmnnfn.Evaluate(coordinates, 0, 1) == Approx(1.576).epsilon(1e-7));
+  REQUIRE(lmnnfn.Evaluate(coordinates, 1, 1) == Approx(1.576).epsilon(1e-7));
   REQUIRE(lmnnfn.Evaluate(coordinates, 2, 1) == Approx(1.576).epsilon(1e-7));
   REQUIRE(lmnnfn.Evaluate(coordinates, 3, 1) == Approx(1.576).epsilon(1e-7));
   REQUIRE(lmnnfn.Evaluate(coordinates, 4, 1) == Approx(1.576).epsilon(1e-7));
@@ -326,21 +322,21 @@ TEST_CASE("LMNNSeparableEvaluateWithGradientTest", "[LMNNTest]")
 
   objective = lmnnfn.EvaluateWithGradient(coordinates, 4, gradient, 1);
 
-  REQUIRE(objective == Approx( 1.576).epsilon(1e-7));
+  REQUIRE(objective == Approx(1.576).epsilon(1e-7));
 
-  REQUIRE(gradient(0, 0) == Approx( -0.048).epsilon(1e-7));
-  REQUIRE(gradient(0, 1) == Approx( 0.0).epsilon(1e-7));
-  REQUIRE(gradient(1, 0) == Approx( 0.0).epsilon(1e-7));
-  REQUIRE(gradient(1, 1) == Approx( 2.0).epsilon(1e-7));
+  REQUIRE(gradient(0, 0) == Approx(-0.048).epsilon(1e-7));
+  REQUIRE(gradient(0, 1) == Approx(0.0).epsilon(1e-7));
+  REQUIRE(gradient(1, 0) == Approx(0.0).epsilon(1e-7));
+  REQUIRE(gradient(1, 1) == Approx(2.0).epsilon(1e-7));
 
   objective = lmnnfn.EvaluateWithGradient(coordinates, 5, gradient, 1);
 
-  REQUIRE(objective == Approx( 1.576).epsilon(1e-7));
+  REQUIRE(objective == Approx(1.576).epsilon(1e-7));
 
-  REQUIRE(gradient(0, 0) == Approx( -0.048).epsilon(1e-7));
-  REQUIRE(gradient(0, 1) == Approx( 0.0).epsilon(1e-7));
-  REQUIRE(gradient(1, 0) == Approx( 0.0).epsilon(1e-7));
-  REQUIRE(gradient(1, 1) == Approx( 2.0).epsilon(1e-7));
+  REQUIRE(gradient(0, 0) == Approx(-0.048).epsilon(1e-7));
+  REQUIRE(gradient(0, 1) == Approx(0.0).epsilon(1e-7));
+  REQUIRE(gradient(1, 0) == Approx(0.0).epsilon(1e-7));
+  REQUIRE(gradient(1, 1) == Approx(2.0).epsilon(1e-7));
 }
 
 // Check that final objective value using SGD optimizer is optimal.
@@ -398,7 +394,7 @@ double KnnAccuracy(const arma::mat& dataset,
   arma::Mat<size_t> neighbors;
   arma::mat distances;
 
-  neighbor::KNN knn;
+  KNN knn;
 
   knn.Train(dataset);
   knn.Search(k, neighbors, distances);
@@ -450,7 +446,7 @@ TEST_CASE("LMNNAccuracyTest", "[LMNNTest]")
   REQUIRE(initAccuracy < finalAccuracy);
 
   // Since this is a very simple dataset final accuracy should be around 100%.
-  REQUIRE(finalAccuracy == Approx( 100.0).epsilon(1e-7));
+  REQUIRE(finalAccuracy == Approx(100.0).epsilon(1e-7));
 }
 
 // Check that accuracy while learning square distance matrix is the same as when
@@ -699,8 +695,10 @@ TEST_CASE("LMNNFunctionGradientTest3", "[LMNNTest]")
 {
   arma::mat dataset;
   arma::Row<size_t> labels;
-  data::Load("iris.csv", dataset);
-  data::Load("iris_labels.txt", labels);
+  if (!data::Load("iris.csv", dataset))
+    FAIL("Cannot load dataset iris.csv");
+  if (!data::Load("iris_labels.txt", labels))
+    FAIL("Cannot load dataset iris_labels.txt");
 
   LMNNFunction<> lmnnfn(dataset, labels, 1, 0.6, 1);
 
@@ -716,8 +714,10 @@ TEST_CASE("LMNNFunctionGradientTest4", "[LMNNTest]")
 {
   arma::mat dataset;
   arma::Row<size_t> labels;
-  data::Load("iris.csv", dataset);
-  data::Load("iris_labels.txt", labels);
+  if (!data::Load("iris.csv", dataset))
+    FAIL("Cannot load dataset iris.csv");
+  if (!data::Load("iris_labels.txt", labels))
+    FAIL("Cannot load dataset iris_labels.txt");
 
   LMNNFunction<> lmnnfn(dataset, labels, 1, 0.6, 1);
 
