@@ -10,20 +10,13 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 
-// Note: We don't use BOOST_REQUIRE_CLOSE in the code below because we need
-// to use FPC_WEAK, and it's not at all intuitive how to do that.
-#include <mlpack/methods/local_coordinate_coding/lcc.hpp>
+#include <mlpack/methods/local_coordinate_coding.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "catch.hpp"
 #include "serialization.hpp"
 
 using namespace arma;
 using namespace mlpack;
-using namespace mlpack::regression;
-using namespace mlpack::lcc;
-
-BOOST_AUTO_TEST_SUITE(LocalCoordinateCodingTest);
 
 void VerifyCorrectness(const vec& beta, const vec& errCorr, double lambda)
 {
@@ -34,23 +27,25 @@ void VerifyCorrectness(const vec& beta, const vec& errCorr, double lambda)
     if (beta(j) == 0)
     {
       // make sure that errCorr(j) <= lambda
-      BOOST_REQUIRE_SMALL(std::max(fabs(errCorr(j)) - lambda, 0.0), tol);
+      REQUIRE(std::max(fabs(errCorr(j)) - lambda, 0.0) ==
+          Approx(0.0).margin(tol));
     }
     else if (beta(j) < 0)
     {
       // make sure that errCorr(j) == lambda
-      BOOST_REQUIRE_SMALL(errCorr(j) - lambda, tol);
+      REQUIRE(errCorr(j) - lambda == Approx(0.0).margin(tol));
     }
     else
     { // beta(j) > 0
       // make sure that errCorr(j) == -lambda
-      BOOST_REQUIRE_SMALL(errCorr(j) + lambda, tol);
+      REQUIRE(errCorr(j) + lambda == Approx(0.0).margin(tol));
     }
   }
 }
 
 
-BOOST_AUTO_TEST_CASE(LocalCoordinateCodingTestCodingStep)
+TEST_CASE("LocalCoordinateCodingTestCodingStep",
+          "[LocalCoordinateCodingTest]")
 {
   double lambda1 = 0.1;
   uword nAtoms = 10;
@@ -86,7 +81,8 @@ BOOST_AUTO_TEST_CASE(LocalCoordinateCodingTestCodingStep)
   }
 }
 
-BOOST_AUTO_TEST_CASE(LocalCoordinateCodingTestDictionaryStep)
+TEST_CASE("LocalCoordinateCodingTestDictionaryStep",
+          "[LocalCoordinateCodingTest]")
 {
   const double tol = 0.1;
 
@@ -119,10 +115,11 @@ BOOST_AUTO_TEST_CASE(LocalCoordinateCodingTestDictionaryStep)
   }
   grad = lambda * grad + (D * Z - X) * trans(Z);
 
-  BOOST_REQUIRE_SMALL(norm(grad, "fro"), tol);
+  REQUIRE(norm(grad, "fro") == Approx(0.0).margin(tol));
 }
 
-BOOST_AUTO_TEST_CASE(SerializationTest)
+TEST_CASE("LocalCoordinateCodingSerializationTest",
+          "[LocalCoordinateCodingTest]")
 {
   mat X = randu<mat>(100, 100);
   size_t nAtoms = 10;
@@ -134,42 +131,44 @@ BOOST_AUTO_TEST_CASE(SerializationTest)
   mat codes;
   lcc.Encode(Y, codes);
 
-  LocalCoordinateCoding lccXml(50, 0.1), lccText(12, 0.0), lccBinary(0, 0.0);
-  SerializeObjectAll(lcc, lccXml, lccText, lccBinary);
+  LocalCoordinateCoding lccXml(50, 0.1), lccJson(12, 0.0), lccBinary(0, 0.0);
+  SerializeObjectAll(lcc, lccXml, lccJson, lccBinary);
 
-  CheckMatrices(lcc.Dictionary(), lccXml.Dictionary(), lccText.Dictionary(),
+  CheckMatrices(lcc.Dictionary(), lccXml.Dictionary(), lccJson.Dictionary(),
       lccBinary.Dictionary());
 
-  mat xmlCodes, textCodes, binaryCodes;
+  mat xmlCodes, jsonCodes, binaryCodes;
   lccXml.Encode(Y, xmlCodes);
-  lccText.Encode(Y, textCodes);
+  lccJson.Encode(Y, jsonCodes);
   lccBinary.Encode(Y, binaryCodes);
 
-  CheckMatrices(codes, xmlCodes, textCodes, binaryCodes);
+  CheckMatrices(codes, xmlCodes, jsonCodes, binaryCodes);
 
   // Check the parameters, too.
-  BOOST_REQUIRE_EQUAL(lcc.Atoms(), lccXml.Atoms());
-  BOOST_REQUIRE_EQUAL(lcc.Atoms(), lccText.Atoms());
-  BOOST_REQUIRE_EQUAL(lcc.Atoms(), lccBinary.Atoms());
 
-  BOOST_REQUIRE_CLOSE(lcc.Tolerance(), lccXml.Tolerance(), 1e-5);
-  BOOST_REQUIRE_CLOSE(lcc.Tolerance(), lccText.Tolerance(), 1e-5);
-  BOOST_REQUIRE_CLOSE(lcc.Tolerance(), lccBinary.Tolerance(), 1e-5);
+  REQUIRE(lcc.Atoms() == lccXml.Atoms());
+  REQUIRE(lcc.Atoms() == lccJson.Atoms());
+  REQUIRE(lcc.Atoms() == lccBinary.Atoms());
 
-  BOOST_REQUIRE_CLOSE(lcc.Lambda(), lccXml.Lambda(), 1e-5);
-  BOOST_REQUIRE_CLOSE(lcc.Lambda(), lccText.Lambda(), 1e-5);
-  BOOST_REQUIRE_CLOSE(lcc.Lambda(), lccBinary.Lambda(), 1e-5);
+  REQUIRE(lcc.Tolerance() == Approx(lccXml.Tolerance()).epsilon(1e-7));
+  REQUIRE(lcc.Tolerance() == Approx(lccJson.Tolerance()).epsilon(1e-7));
+  REQUIRE(lcc.Tolerance() == Approx(lccBinary.Tolerance()).epsilon(1e-7));
 
-  BOOST_REQUIRE_EQUAL(lcc.MaxIterations(), lccXml.MaxIterations());
-  BOOST_REQUIRE_EQUAL(lcc.MaxIterations(), lccText.MaxIterations());
-  BOOST_REQUIRE_EQUAL(lcc.MaxIterations(), lccBinary.MaxIterations());
+  REQUIRE(lcc.Lambda() == Approx(lccXml.Lambda()).epsilon(1e-7));
+  REQUIRE(lcc.Lambda() == Approx(lccJson.Lambda()).epsilon(1e-7));
+  REQUIRE(lcc.Lambda() == Approx(lccBinary.Lambda()).epsilon(1e-7));
+
+  REQUIRE(lcc.MaxIterations() == lccXml.MaxIterations());
+  REQUIRE(lcc.MaxIterations() == lccJson.MaxIterations());
+  REQUIRE(lcc.MaxIterations() == lccBinary.MaxIterations());
 }
 
 /**
  * Test that LocalCoordinateCoding::Train() returns finite final objective
  * value.
  */
-BOOST_AUTO_TEST_CASE(LocalCoordinateCodingTrainReturnObjective)
+TEST_CASE("LocalCoordinateCodingTrainReturnObjective",
+          "[LocalCoordinateCodingTest]")
 {
   double lambda1 = 0.1;
   uword nAtoms = 10;
@@ -187,7 +186,5 @@ BOOST_AUTO_TEST_CASE(LocalCoordinateCodingTrainReturnObjective)
   LocalCoordinateCoding lcc(nAtoms, lambda1, 10);
   double objVal = lcc.Train(X);
 
-  BOOST_REQUIRE_EQUAL(std::isfinite(objVal), true);
+  REQUIRE(std::isfinite(objVal) == true);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
