@@ -2,44 +2,26 @@
  * @file tests/main_tests/dbscan_test.cpp
  * @author Nikhil Goel
  *
- * Test mlpackMain() of dbscan_main.cpp.
+ * Test RUN_BINDING() of dbscan_main.cpp.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
-static const std::string testName = "DBSCAN";
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/util/mlpack_main.hpp>
-#include "test_helper.hpp"
 #include <mlpack/methods/dbscan/dbscan_main.cpp>
+#include <mlpack/core/util/mlpack_main.hpp>
+#include "main_test_fixture.hpp"
 
 #include "../catch.hpp"
 #include "../test_catch_tools.hpp"
 
 using namespace mlpack;
 
-struct DBSCANTestFixture
-{
- public:
-  DBSCANTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~DBSCANTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
+BINDING_TEST_FIXTURE(DBSCANTestFixture);
 
 /**
  * Check that number of output labels and number of input
@@ -56,13 +38,13 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANOutputDimensionTest",
 
   SetInputParam("input", inputData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of predicted labels is equal to the input test points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("assignments").n_cols == inputSize);
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("assignments").n_rows == 1);
-  REQUIRE(IO::GetParam<arma::mat>("centroids").n_rows == 4);
-  REQUIRE(IO::GetParam<arma::mat>("centroids").n_cols >= 1);
+  REQUIRE(params.Get<arma::Row<size_t>>("assignments").n_cols == inputSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("assignments").n_rows == 1);
+  REQUIRE(params.Get<arma::mat>("centroids").n_rows == 4);
+  REQUIRE(params.Get<arma::mat>("centroids").n_cols >= 1);
 }
 
 /**
@@ -78,9 +60,7 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANEpsilonTest",
   SetInputParam("input", inputData);
   SetInputParam("epsilon", (double) -0.5);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -96,9 +76,7 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANMinSizeTest",
   SetInputParam("input", inputData);
   SetInputParam("min_size", (int) -1);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -116,10 +94,10 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANClusterNumberTest",
   SetInputParam("min_size", (int) 1);
   SetInputParam("epsilon", (double) 0.1);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> output;
-  output = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  output = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
   for (size_t i = 0; i < output.n_elem; ++i)
     REQUIRE(output[i] < inputData.n_cols);
@@ -139,23 +117,21 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANDiffEpsilonTest",
   SetInputParam("input", inputData);
   SetInputParam("epsilon", (double) 1.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> output1;
-  output1 = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  output1 = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["epsilon"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input", inputData);
   SetInputParam("epsilon", (double) 0.5);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> output2;
-  output2 = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  output2 = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
   REQUIRE(arma::accu(output1 != output2) > 1);
 }
@@ -175,25 +151,22 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANDiffMinSizeTest",
   SetInputParam("epsilon", (double) 0.4);
   SetInputParam("min_size", (int) 5);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> output1;
-  output1 = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  output1 = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["epsilon"].wasPassed = false;
-  IO::GetSingleton().Parameters()["min_size"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input", inputData);
   SetInputParam("epsilon", (double) 0.5);
   SetInputParam("min_size", (int) 40);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> output2;
-  output2 = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  output2 = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
   REQUIRE(arma::accu(output1 != output2) > 1);
 }
@@ -213,9 +186,7 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANTreeTypeTest",
   SetInputParam("input", std::move(inputData));
   SetInputParam("tree_type", std::string("binary"));
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -234,130 +205,114 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANDiffTreeTypeTest",
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("kd"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> kdOutput;
-  kdOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  kdOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Tree Type = r tree.
 
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("r"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> rOutput;
-  rOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  rOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Tree type = r-star tree.
 
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("r-star"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> rStarOutput;
-  rStarOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  rStarOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Tree Type = x tree.
 
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("x"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> xOutput;
-  xOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  xOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Tree Type = hilbert-r tree.
 
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("hilbert-r"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> hilbertROutput;
-  hilbertROutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  hilbertROutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Tree Type = r-plus tree.
 
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("r-plus"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> rPlusOutput;
-  rPlusOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  rPlusOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Tree Type = r-plus-plus tree.
 
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("r-plus-plus"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> rPlusPlusOutput;
-  rPlusPlusOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  rPlusPlusOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Tree Type = cover tree.
 
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("cover"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> coverOutput;
-  coverOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  coverOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Tree Type = ball tree.
 
   SetInputParam("input", inputData);
   SetInputParam("tree_type", std::string("ball"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> ballOutput;
-  ballOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  ballOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
   CheckMatrices(kdOutput, rOutput);
   CheckMatrices(kdOutput, rStarOutput);
@@ -382,22 +337,21 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANSingleTreeTest",
 
   SetInputParam("input", inputData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> output;
-  output = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  output = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input", inputData);
   SetInputParam("single_mode", true);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> singleModeOutput;
-  singleModeOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  singleModeOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
   CheckMatrices(output, singleModeOutput);
 }
@@ -415,22 +369,21 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANNaiveSearchTest",
 
   SetInputParam("input", inputData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> output;
-  output = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  output = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input", inputData);
   SetInputParam("naive", true);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> naiveOutput;
-  naiveOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  naiveOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
   CheckMatrices(output, naiveOutput);
 }
@@ -451,27 +404,23 @@ TEST_CASE_METHOD(DBSCANTestFixture, "DBSCANRandomSelectionFlagTest",
   SetInputParam("min_size", 1);
   SetInputParam("selection_type", std::string("ordered"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> orderedOutput;
-  orderedOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  orderedOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["input"].wasPassed = false;
-  IO::GetSingleton().Parameters()["epsilon"].wasPassed = false;
-  IO::GetSingleton().Parameters()["min_size"].wasPassed = false;
-  IO::GetSingleton().Parameters()["selection_type"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input", inputData);
   SetInputParam("epsilon", (double) 0.358);
   SetInputParam("min_size", 1);
   SetInputParam("selection_type", std::string("random"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> randomOutput;
-  randomOutput = std::move(IO::GetParam<arma::Row<size_t>>("assignments"));
+  randomOutput = std::move(params.Get<arma::Row<size_t>>("assignments"));
 
   REQUIRE(arma::accu(orderedOutput != randomOutput) > 0);
 }
