@@ -2,24 +2,22 @@
  * @file tests/main_tests/hmm_generate_test.cpp
  * @author Daivik Nema
  *
- * Test mlpackMain() of hmm_generate_main.cpp
+ * Test RUN_BINDING() of hmm_generate_main.cpp
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
-static const std::string testName = "HMMGenerate";
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/util/mlpack_main.hpp>
-#include "test_helper.hpp"
 #include <mlpack/methods/hmm/hmm_model.hpp>
 #include <mlpack/methods/hmm/hmm.hpp>
 #include <mlpack/methods/hmm/hmm_generate_main.cpp>
+#include <mlpack/core/util/mlpack_main.hpp>
+
+#include "main_test_fixture.hpp"
 
 #include "../catch.hpp"
 #include "../test_catch_tools.hpp"
@@ -28,22 +26,7 @@ static const std::string testName = "HMMGenerate";
 
 using namespace mlpack;
 
-struct HMMGenerateTestFixture
-{
- public:
-  HMMGenerateTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~HMMGenerateTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
+BINDING_TEST_FIXTURE(HMMGenerateTestFixture);
 
 TEST_CASE_METHOD(HMMGenerateTestFixture,
                  "HMMGenerateDiscreteHMMCheckDimensionsTest",
@@ -56,8 +39,8 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
 
   // Initialize and train a discrete HMM model.
   HMMModel* h = new HMMModel(DiscreteHMM);
-  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(&trainSeq);
-  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(&trainSeq);
+  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(params, &trainSeq);
+  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(params, &trainSeq);
 
   // Now that we have a trained HMM model, we can use it to generate a sequence
   // of states and observations - using the hmm_generate utility.
@@ -68,21 +51,21 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
   SetInputParam("length", length);
 
   // Call to hmm_generate_main.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the generated observation sequence. Ensure that the generated sequence
   // has the correct length (as provided in the input).
-  arma::mat obsSeq = IO::GetParam<arma::mat>("output");
-  REQUIRE(obsSeq.n_cols == (size_t)length);
-  REQUIRE(obsSeq.n_rows == (size_t)1);
-  REQUIRE(obsSeq.n_elem == (size_t)length);
+  arma::mat obsSeq = params.Get<arma::mat>("output");
+  REQUIRE(obsSeq.n_cols == (size_t) length);
+  REQUIRE(obsSeq.n_rows == (size_t) 1);
+  REQUIRE(obsSeq.n_elem == (size_t) length);
 
   // Get the generated state sequence. Ensure that the generated sequence
   // has the correct length (as provided in the input).
-  arma::Mat<size_t> stateSeq = IO::GetParam<arma::Mat<size_t>>("state");
-  REQUIRE(stateSeq.n_cols == (size_t)length);
-  REQUIRE(stateSeq.n_rows == (size_t)1);
-  REQUIRE(stateSeq.n_elem == (size_t)length);
+  arma::Mat<size_t> stateSeq = params.Get<arma::Mat<size_t>>("state");
+  REQUIRE(stateSeq.n_cols == (size_t) length);
+  REQUIRE(stateSeq.n_rows == (size_t) 1);
+  REQUIRE(stateSeq.n_elem == (size_t) length);
 }
 
 TEST_CASE_METHOD(HMMGenerateTestFixture,
@@ -96,8 +79,8 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
 
   // Initialize and train a gaussian HMM model.
   HMMModel* h = new HMMModel(GaussianHMM);
-  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(&trainSeq);
-  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(&trainSeq);
+  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(params, &trainSeq);
+  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(params, &trainSeq);
 
   // Now that we have a trained HMM model, we can use it to generate a sequence
   // of states and observations - using the hmm_generate utility.
@@ -108,21 +91,21 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
   SetInputParam("length", length);
 
   // Call to hmm_generate_main.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the generated observation sequence. Ensure that the generated sequence
   // has the correct length (as provided in the input).
-  arma::mat obsSeq = IO::GetParam<arma::mat>("output");
-  REQUIRE(obsSeq.n_cols == (size_t)length);
-  REQUIRE(obsSeq.n_rows == (size_t)1);
-  REQUIRE(obsSeq.n_elem == (size_t)length);
+  arma::mat obsSeq = params.Get<arma::mat>("output");
+  REQUIRE(obsSeq.n_cols == (size_t) length);
+  REQUIRE(obsSeq.n_rows == (size_t) 1);
+  REQUIRE(obsSeq.n_elem == (size_t) length);
 
   // Get the generated state sequence. Ensure that the generated sequence
   // has the correct length (as provided in the input).
-  arma::Mat<size_t> stateSeq = IO::GetParam<arma::Mat<size_t>>("state");
-  REQUIRE(stateSeq.n_cols == (size_t)length);
-  REQUIRE(stateSeq.n_rows == (size_t)1);
-  REQUIRE(stateSeq.n_elem == (size_t)length);
+  arma::Mat<size_t> stateSeq = params.Get<arma::Mat<size_t>>("state");
+  REQUIRE(stateSeq.n_cols == (size_t) length);
+  REQUIRE(stateSeq.n_rows == (size_t) 1);
+  REQUIRE(stateSeq.n_elem == (size_t) length);
 }
 
 TEST_CASE_METHOD(HMMGenerateTestFixture,
@@ -158,18 +141,18 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
   SetInputParam("length", length);
 
   // Call to hmm_generate_main
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the generated observation sequence. Ensure that the generated sequence
   // has the correct length (as provided in the input).
-  arma::mat obsSeq = IO::GetParam<arma::mat>("output");
+  arma::mat obsSeq = params.Get<arma::mat>("output");
   REQUIRE(obsSeq.n_cols == (size_t) length);
   REQUIRE(obsSeq.n_rows == (size_t) 2);
   REQUIRE(obsSeq.n_elem == (size_t) length * 2);
 
   // Get the generated state sequence. Ensure that the generated sequence
   // has the correct length (as provided in the input).
-  arma::Mat<size_t> stateSeq = IO::GetParam<arma::Mat<size_t>>("state");
+  arma::Mat<size_t> stateSeq = params.Get<arma::Mat<size_t>>("state");
   REQUIRE(stateSeq.n_cols == (size_t) length);
   REQUIRE(stateSeq.n_rows == (size_t) 1);
   REQUIRE(stateSeq.n_elem == (size_t) length);
@@ -208,18 +191,18 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
   SetInputParam("length", length);
 
   // Call to hmm_generate_main.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the generated observation sequence. Ensure that the generated sequence
   // has the correct length (as provided in the input).
-  arma::mat obsSeq = IO::GetParam<arma::mat>("output");
+  arma::mat obsSeq = params.Get<arma::mat>("output");
   REQUIRE(obsSeq.n_cols == (size_t) length);
   REQUIRE(obsSeq.n_rows == (size_t) 2);
   REQUIRE(obsSeq.n_elem == (size_t) length * 2);
 
   // Get the generated state sequence. Ensure that the generated sequence
   // has the correct length (as provided in the input).
-  arma::Mat<size_t> stateSeq = IO::GetParam<arma::Mat<size_t>>("state");
+  arma::Mat<size_t> stateSeq = params.Get<arma::Mat<size_t>>("state");
   REQUIRE(stateSeq.n_cols == (size_t) length);
   REQUIRE(stateSeq.n_rows == (size_t) 1);
   REQUIRE(stateSeq.n_elem == (size_t) length);
@@ -236,8 +219,8 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
 
   // Initialize and train a HMM model.
   HMMModel* h = new HMMModel(DiscreteHMM);
-  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(&trainSeq);
-  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(&trainSeq);
+  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(params, &trainSeq);
+  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(params, &trainSeq);
 
   // Set the params for the hmm_generate invocation
   // Note that the length is negative - we expect that a runtime error will be
@@ -246,9 +229,7 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
   SetInputParam("model", h);
   SetInputParam("length", length);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 TEST_CASE_METHOD(HMMGenerateTestFixture,
@@ -262,8 +243,8 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
 
   // Initialize and train a HMM model.
   HMMModel* h = new HMMModel(DiscreteHMM);
-  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(&trainSeq);
-  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(&trainSeq);
+  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(params, &trainSeq);
+  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(params, &trainSeq);
 
   // Set the params for the hmm_generate invocation
   // Note that the start state is invalid - we expect that a runtime error will
@@ -274,7 +255,5 @@ TEST_CASE_METHOD(HMMGenerateTestFixture,
   SetInputParam("length", length);
   SetInputParam("start_state", startState);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
