@@ -2,24 +2,22 @@
  * @file tests/main_tests/hmm_viterbi_test.cpp
  * @author Daivik Nema
  *
- * Test mlpackMain() of hmm_viterbi_main.cpp
+ * Test RUN_BINDING() of hmm_viterbi_main.cpp
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
-static const std::string testName = "HMMViterbi";
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/util/mlpack_main.hpp>
-#include "test_helper.hpp"
 #include <mlpack/methods/hmm/hmm_model.hpp>
 #include <mlpack/methods/hmm/hmm.hpp>
 #include <mlpack/methods/hmm/hmm_viterbi_main.cpp>
+#include <mlpack/core/util/mlpack_main.hpp>
+
+#include "main_test_fixture.hpp"
 
 #include "../catch.hpp"
 #include "../test_catch_tools.hpp"
@@ -28,22 +26,7 @@ static const std::string testName = "HMMViterbi";
 
 using namespace mlpack;
 
-struct HMMViterbiTestFixture
-{
- public:
-  HMMViterbiTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~HMMViterbiTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
+BINDING_TEST_FIXTURE(HMMViterbiTestFixture);
 
 TEST_CASE_METHOD(HMMViterbiTestFixture,
                  "HMMViterbiDiscreteHMMCheckDimensionsTest",
@@ -56,8 +39,8 @@ TEST_CASE_METHOD(HMMViterbiTestFixture,
 
   // Initialize and train a discrete HMM model.
   HMMModel* h = new HMMModel(DiscreteHMM);
-  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(&trainSeq);
-  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(&trainSeq);
+  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(params, &trainSeq);
+  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(params, &trainSeq);
 
   // Now that we have a trained HMM model, we can use it to predict the state
   // sequence for a given observation sequence - using the Viterbi algorithm.
@@ -67,10 +50,10 @@ TEST_CASE_METHOD(HMMViterbiTestFixture,
   SetInputParam("input", inp);
 
   // Call to hmm_viterbi_main.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the output of viterbi inference.
-  arma::Mat<size_t> out = IO::GetParam<arma::Mat<size_t> >("output");
+  arma::Mat<size_t> out = params.Get<arma::Mat<size_t> >("output");
 
   // Output sequence length must be the same as input sequence length and
   // there should only be one row (since states are single dimensional values).
@@ -89,8 +72,8 @@ TEST_CASE_METHOD(HMMViterbiTestFixture,
 
   // Initialize and train a gaussian HMM model.
   HMMModel* h = new HMMModel(GaussianHMM);
-  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(&trainSeq);
-  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(&trainSeq);
+  h->PerformAction<InitHMMModel, std::vector<arma::mat>>(params, &trainSeq);
+  h->PerformAction<TrainHMMModel, std::vector<arma::mat>>(params, &trainSeq);
 
   // Now that we have a trained HMM model, we can use it to predict the state
   // sequence for a given observation sequence - using the Viterbi algorithm.
@@ -100,10 +83,10 @@ TEST_CASE_METHOD(HMMViterbiTestFixture,
   SetInputParam("input", inp);
 
   // Call to hmm_viterbi_main.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the output of viterbi inference.
-  arma::Mat<size_t> out = IO::GetParam<arma::Mat<size_t> >("output");
+  arma::Mat<size_t> out = params.Get<arma::Mat<size_t> >("output");
 
   // Output sequence length must be the same as input sequence length and
   // there should only be one row (since states are single dimensional values).
@@ -167,10 +150,10 @@ TEST_CASE_METHOD(HMMViterbiTestFixture,
   SetInputParam("input", observations);
 
   // Call to hmm_viterbi_main.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the output of viterbi inference.
-  arma::Mat<size_t> out = IO::GetParam<arma::Mat<size_t> >("output");
+  arma::Mat<size_t> out = params.Get<arma::Mat<size_t> >("output");
 
   // Output sequence length must be the same as input sequence length and
   // there should only be one row (since states are single dimensional values).
@@ -208,7 +191,7 @@ TEST_CASE_METHOD(HMMViterbiTestFixture,
 
   for (size_t i = 1; i < 50; ++i)
   {
-    double randValue = mlpack::math::Random();
+    double randValue = Random();
 
     if (randValue <= transMat(0, states[i - 1]))
       states[i] = 0;
@@ -234,10 +217,10 @@ TEST_CASE_METHOD(HMMViterbiTestFixture,
   SetInputParam("input", observations);
 
   // Call to hmm_viterbi_main.
-  mlpackMain();
+  RUN_BINDING();
 
   // Get the output of viterbi inference.
-  arma::Mat<size_t> out = IO::GetParam<arma::Mat<size_t> >("output");
+  arma::Mat<size_t> out = params.Get<arma::Mat<size_t> >("output");
 
   // Output sequence length must be the same as input sequence length and
   // there should only be one row (since states are single dimensional values).
