@@ -22,7 +22,7 @@
 
 using namespace mlpack;
 
-#ifdef HAS_STB // Compile this only if stb is present.
+#ifdef MLPACK_HAS_STB // Compile this only if stb is present.
 
 BINDING_TEST_FIXTURE(ImageConverterTestFixture);
 
@@ -165,4 +165,4 @@ TEST_CASE_METHOD(ImageConverterTestFixture, "EmptyInputTest",
   REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
-#endif // HAS_STB.
+#endif // MLPACK_HAS_STB.
