@@ -2,55 +2,31 @@
  * @file tests/main_tests/kde_test.cpp
  * @author Roberto Hueso
  *
- * Test mlpackMain() of kde_main.cpp
+ * Test RUN_BINDING() of kde_main.cpp
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
 
-static const std::string testName = "KDE";
-
 #include <mlpack/core.hpp>
-#include <mlpack/core/util/mlpack_main.hpp>
-#include "test_helper.hpp"
 #include <mlpack/methods/kde/kde_main.cpp>
+#include <mlpack/core/util/mlpack_main.hpp>
+
+#include "main_test_fixture.hpp"
 
 #include "../catch.hpp"
 
 using namespace mlpack;
 
-struct KDETestFixture
-{
- public:
-  KDETestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~KDETestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
-
-void ResetKDESettings()
-{
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
-}
+BINDING_TEST_FIXTURE(KDETestFixture);
 
 /**
-  * Ensure that the estimations we get for KDEMain, are the same as the ones we
-  * get from the KDE class without any wrappers. Requires normalization.
- **/
+ * Ensure that the estimations we get for KDEMain, are the same as the ones we
+ * get from the KDE class without any wrappers. Requires normalization.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEGaussianRTreeResultsMain",
                 "[KDEMainTest][BindingTests]")
 {
@@ -61,13 +37,10 @@ TEST_CASE_METHOD(KDETestFixture, "KDEGaussianRTreeResultsMain",
   double kernelBandwidth = 1.5;
   double relError = 0.05;
 
-  kernel::GaussianKernel kernel(kernelBandwidth);
-  metric::EuclideanDistance metric;
-  KDE<kernel::GaussianKernel,
-      metric::EuclideanDistance,
-      arma::mat,
-      tree::RTree>
-      kde(relError, 0.0, kernel, KDEMode::DUAL_TREE_MODE, metric);
+  GaussianKernel kernel(kernelBandwidth);
+  EuclideanDistance metric;
+  KDE<GaussianKernel, EuclideanDistance, arma::mat, RTree> kde(
+      relError, 0.0, kernel, KDEMode::KDE_DUAL_TREE_MODE, metric);
   kde.Train(reference);
   kde.Evaluate(query, kdeEstimations);
   // Normalize estimations.
@@ -81,19 +54,19 @@ TEST_CASE_METHOD(KDETestFixture, "KDEGaussianRTreeResultsMain",
   SetInputParam("rel_error", relError);
   SetInputParam("bandwidth", kernelBandwidth);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  mainEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
+  mainEstimations = std::move(params.Get<arma::vec>("predictions"));
 
   // Check whether results are equal.
   for (size_t i = 0; i < query.n_cols; ++i)
-    REQUIRE(kdeEstimations[i] == Approx( mainEstimations[i]).epsilon(relError));
+    REQUIRE(kdeEstimations[i] == Approx(mainEstimations[i]).epsilon(relError));
 }
 
 /**
-  * Ensure that the estimations we get for KDEMain, are the same as the ones we
-  * get from the KDE class without any wrappers. Doesn't require normalization.
- **/
+ * Ensure that the estimations we get for KDEMain, are the same as the ones we
+ * get from the KDE class without any wrappers. Doesn't require normalization.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDETriangularBallTreeResultsMain",
                 "[KDEMainTest][BindingTests]")
 {
@@ -104,13 +77,10 @@ TEST_CASE_METHOD(KDETestFixture, "KDETriangularBallTreeResultsMain",
   double kernelBandwidth = 3.0;
   double relError = 0.06;
 
-  kernel::TriangularKernel kernel(kernelBandwidth);
-  metric::EuclideanDistance metric;
-  KDE<kernel::TriangularKernel,
-      metric::EuclideanDistance,
-      arma::mat,
-      tree::BallTree>
-      kde(relError, 0.0, kernel, KDEMode::DUAL_TREE_MODE, metric);
+  TriangularKernel kernel(kernelBandwidth);
+  EuclideanDistance metric;
+  KDE<TriangularKernel, EuclideanDistance, arma::mat, BallTree> kde(
+      relError, 0.0, kernel, KDEMode::KDE_DUAL_TREE_MODE, metric);
   kde.Train(reference);
   kde.Evaluate(query, kdeEstimations);
 
@@ -122,19 +92,19 @@ TEST_CASE_METHOD(KDETestFixture, "KDETriangularBallTreeResultsMain",
   SetInputParam("rel_error", relError);
   SetInputParam("bandwidth", kernelBandwidth);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  mainEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
+  mainEstimations = std::move(params.Get<arma::vec>("predictions"));
 
   // Check whether results are equal.
   for (size_t i = 0; i < query.n_cols; ++i)
-    REQUIRE(kdeEstimations[i] == Approx( mainEstimations[i]).epsilon(relError));
+    REQUIRE(kdeEstimations[i] == Approx(mainEstimations[i]).epsilon(relError));
 }
 
 /**
-  * Ensure that the estimations we get for KDEMain, are the same as the ones we
-  * get from the KDE class without any wrappers in the monochromatic case.
- **/
+ * Ensure that the estimations we get for KDEMain, are the same as the ones we
+ * get from the KDE class without any wrappers in the monochromatic case.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMonoResultsMain",
                 "[KDEMainTest][BindingTests]")
 {
@@ -144,13 +114,10 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMonoResultsMain",
   double kernelBandwidth = 2.3;
   double relError = 0.05;
 
-  kernel::EpanechnikovKernel kernel(kernelBandwidth);
-  metric::EuclideanDistance metric;
-  KDE<kernel::EpanechnikovKernel,
-      metric::EuclideanDistance,
-      arma::mat,
-      tree::StandardCoverTree>
-    kde(relError, 0.0, kernel, KDEMode::DUAL_TREE_MODE, metric);
+  EpanechnikovKernel kernel(kernelBandwidth);
+  EuclideanDistance metric;
+  KDE<EpanechnikovKernel, EuclideanDistance, arma::mat, StandardCoverTree>
+      kde(relError, 0.0, kernel, KDEMode::KDE_DUAL_TREE_MODE, metric);
   kde.Train(reference);
   // Perform monochromatic KDE.
   kde.Evaluate(kdeEstimations);
@@ -164,30 +131,28 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMonoResultsMain",
   SetInputParam("rel_error", relError);
   SetInputParam("bandwidth", kernelBandwidth);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  mainEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
+  mainEstimations = std::move(params.Get<arma::vec>("predictions"));
 
   // Check whether results are equal.
   for (size_t i = 0; i < reference.n_cols; ++i)
-    REQUIRE(kdeEstimations[i] == Approx( mainEstimations[i]).epsilon(relError));
+    REQUIRE(kdeEstimations[i] == Approx(mainEstimations[i]).epsilon(relError));
 }
 
 /**
   * Ensuring that absence of input data is checked.
- **/
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDENoInputData",
                 "[KDEMainTest][BindingTests]")
 {
   // No input data is not provided. Should throw a runtime error.
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
   * Check result has as many densities as query points.
- **/
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEOutputSize",
                 "[KDEMainTest][BindingTests]")
 {
@@ -200,14 +165,14 @@ TEST_CASE_METHOD(KDETestFixture, "KDEOutputSize",
   SetInputParam("reference", reference);
   SetInputParam("query", query);
 
-  mlpackMain();
+  RUN_BINDING();
   // Check number of output elements.
-  REQUIRE(IO::GetParam<arma::vec>("predictions").size() == samples);
+  REQUIRE(params.Get<arma::vec>("predictions").size() == samples);
 }
 
 /**
   * Check that saved model can be reused.
- **/
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEModelReuse",
                 "[KDEMainTest][BindingTests]")
 {
@@ -223,29 +188,34 @@ TEST_CASE_METHOD(KDETestFixture, "KDEModelReuse",
   SetInputParam("bandwidth", 2.4);
   SetInputParam("rel_error", 0.05);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::vec oldEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
+  arma::vec oldEstimations = std::move(params.Get<arma::vec>("predictions"));
+
+  KDEModel* m = params.Get<KDEModel*>("output_model");
+  params.Get<KDEModel*>("output_model") = NULL;
+  CleanMemory();
+  ResetSettings();
 
   // Change parameters and load model.
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
   SetInputParam("query", query);
-  SetInputParam("input_model",
-      std::move(IO::GetParam<KDEModel*>("output_model")));
+  SetInputParam("input_model", m);
+  SetInputParam("bandwidth", 2.4);
+  SetInputParam("rel_error", 0.05);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::vec newEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
+  arma::vec newEstimations = std::move(params.Get<arma::vec>("predictions"));
 
   // Check estimations are the same.
   for (size_t i = 0; i < samples; ++i)
-    REQUIRE(oldEstimations[i] == Approx( newEstimations[i]).epsilon(relError));
+    REQUIRE(oldEstimations[i] == Approx(newEstimations[i]).epsilon(relError));
 }
 
 /**
-  * Ensure that the estimations we get for KDEMain, are the same as the ones we
-  * get from the KDE class without any wrappers using single-tree mode.
- **/
+ * Ensure that the estimations we get for KDEMain, are the same as the ones we
+ * get from the KDE class without any wrappers using single-tree mode.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEGaussianSingleKDTreeResultsMain",
                 "[KDEMainTest][BindingTests]")
 {
@@ -256,13 +226,10 @@ TEST_CASE_METHOD(KDETestFixture, "KDEGaussianSingleKDTreeResultsMain",
   double kernelBandwidth = 3.0;
   double relError = 0.06;
 
-  kernel::GaussianKernel kernel(kernelBandwidth);
-  metric::EuclideanDistance metric;
-  KDE<kernel::GaussianKernel,
-      metric::EuclideanDistance,
-      arma::mat,
-      tree::BallTree>
-      kde(relError, 0.0, kernel, KDEMode::SINGLE_TREE_MODE, metric);
+  GaussianKernel kernel(kernelBandwidth);
+  EuclideanDistance metric;
+  KDE<GaussianKernel, EuclideanDistance, arma::mat, BallTree> kde(
+      relError, 0.0, kernel, KDEMode::KDE_SINGLE_TREE_MODE, metric);
   kde.Train(reference);
   kde.Evaluate(query, kdeEstimations);
   kdeEstimations /= kernel.Normalizer(reference.n_rows);
@@ -276,18 +243,18 @@ TEST_CASE_METHOD(KDETestFixture, "KDEGaussianSingleKDTreeResultsMain",
   SetInputParam("rel_error", relError);
   SetInputParam("bandwidth", kernelBandwidth);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  mainEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
+  mainEstimations = std::move(params.Get<arma::vec>("predictions"));
 
   // Check whether results are equal.
   for (size_t i = 0; i < query.n_cols; ++i)
-    REQUIRE(kdeEstimations[i] == Approx( mainEstimations[i]).epsilon(relError));
+    REQUIRE(kdeEstimations[i] == Approx(mainEstimations[i]).epsilon(relError));
 }
 
 /**
-  * Ensure we get an exception when an invalid kernel is specified.
- **/
+ * Ensure we get an exception when an invalid kernel is specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidKernel",
                 "[KDEMainTest][BindingTests]")
 {
@@ -299,14 +266,12 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidKernel",
   SetInputParam("query", query);
   SetInputParam("kernel", std::string("linux"));
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
-  * Ensure we get an exception when an invalid tree is specified.
- **/
+ * Ensure we get an exception when an invalid tree is specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidTree",
                 "[KDEMainTest][BindingTests]")
 {
@@ -318,14 +283,12 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidTree",
   SetInputParam("query", query);
   SetInputParam("tree", std::string("olive"));
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
-  * Ensure we get an exception when an invalid algorithm is specified.
- **/
+ * Ensure we get an exception when an invalid algorithm is specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidAlgorithm",
                 "[KDEMainTest][BindingTests]")
 {
@@ -337,15 +300,13 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidAlgorithm",
   SetInputParam("query", query);
   SetInputParam("algorithm", std::string("bogosort"));
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
-  * Ensure we get an exception when both reference and input_model are
-  * specified.
- **/
+ * Ensure we get an exception when both reference and input_model are
+ * specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainReferenceAndModel",
                 "[KDEMainTest][BindingTests]")
 {
@@ -358,14 +319,12 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainReferenceAndModel",
   SetInputParam("query", query);
   SetInputParam("input_model", model);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
-  * Ensure we get an exception when an invalid absolute error is specified.
- **/
+ * Ensure we get an exception when an invalid absolute error is specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidAbsoluteError",
                 "[KDEMainTest][BindingTests]")
 {
@@ -376,20 +335,18 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidAbsoluteError",
   SetInputParam("reference", reference);
   SetInputParam("query", query);
 
-  Log::Fatal.ignoreInput = true;
   // Invalid value.
   SetInputParam("abs_error", -0.1);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Valid value.
   SetInputParam("abs_error", 5.8);
-  REQUIRE_NOTHROW(mlpackMain());
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_NOTHROW(RUN_BINDING());
 }
 
 /**
-  * Ensure we get an exception when an invalid relative error is specified.
- **/
+ * Ensure we get an exception when an invalid relative error is specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidRelativeError",
                 "[KDEMainTest][BindingTests]")
 {
@@ -400,25 +357,23 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidRelativeError",
   SetInputParam("reference", reference);
   SetInputParam("query", query);
 
-  Log::Fatal.ignoreInput = true;
   // Invalid under 0.
   SetInputParam("rel_error", -0.1);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Invalid over 1.
   SetInputParam("rel_error", 1.1);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Valid value.
   SetInputParam("rel_error", 0.3);
-  REQUIRE_NOTHROW(mlpackMain());
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_NOTHROW(RUN_BINDING());
 }
 
 /**
-  * Ensure we get an exception when an invalid Monte Carlo probability is
-  * specified.
- **/
+ * Ensure we get an exception when an invalid Monte Carlo probability is
+ * specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCProbability",
                 "[KDEMainTest][BindingTests]")
 {
@@ -431,25 +386,23 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCProbability",
   SetInputParam("kernel", std::string("gaussian"));
   SetInputParam("monte_carlo", true);
 
-  Log::Fatal.ignoreInput = true;
   // Invalid under 0.
   SetInputParam("mc_probability", -0.1);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Invalid over 1.
   SetInputParam("mc_probability", 1.1);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Valid value.
   SetInputParam("mc_probability", 0.3);
-  REQUIRE_NOTHROW(mlpackMain());
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_NOTHROW(RUN_BINDING());
 }
 
 /**
-  * Ensure we get an exception when an invalid Monte Carlo initial sample size
-  * is specified.
- **/
+ * Ensure we get an exception when an invalid Monte Carlo initial sample size
+ * is specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCInitialSampleSize",
                 "[KDEMainTest][BindingTests]")
 {
@@ -462,25 +415,23 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCInitialSampleSize",
   SetInputParam("kernel", std::string("gaussian"));
   SetInputParam("monte_carlo", true);
 
-  Log::Fatal.ignoreInput = true;
   // Invalid under 0.
   SetInputParam("initial_sample_size", -1);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Invalid 0.
   SetInputParam("initial_sample_size", 0);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Valid value.
   SetInputParam("initial_sample_size", 20);
-  REQUIRE_NOTHROW(mlpackMain());
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_NOTHROW(RUN_BINDING());
 }
 
 /**
-  * Ensure we get an exception when an invalid Monte Carlo entry coefficient
-  * is specified.
- **/
+ * Ensure we get an exception when an invalid Monte Carlo entry coefficient
+ * is specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCEntryCoef",
                 "[KDEMainTest][BindingTests]")
 {
@@ -493,21 +444,19 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCEntryCoef",
   SetInputParam("kernel", std::string("gaussian"));
   SetInputParam("monte_carlo", true);
 
-  Log::Fatal.ignoreInput = true;
   // Invalid under 1.
   SetInputParam("mc_entry_coef", 0.5);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Valid greater than 1.
   SetInputParam("mc_entry_coef", 1.1);
-  REQUIRE_NOTHROW(mlpackMain());
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_NOTHROW(RUN_BINDING());
 }
 
 /**
-  * Ensure we get an exception when an invalid Monte Carlo break coefficient
-  * is specified.
- **/
+ * Ensure we get an exception when an invalid Monte Carlo break coefficient
+ * is specified.
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCBreakCoef",
                 "[KDEMainTest][BindingTests]")
 {
@@ -520,26 +469,24 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCBreakCoef",
   SetInputParam("kernel", std::string("gaussian"));
   SetInputParam("monte_carlo", true);
 
-  Log::Fatal.ignoreInput = true;
   // Invalid under 0.
   SetInputParam("mc_break_coef", -0.5);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Valid between 0 and 1.
   SetInputParam("mc_break_coef", 0.3);
-  REQUIRE_NOTHROW(mlpackMain());
+  REQUIRE_NOTHROW(RUN_BINDING());
 
   // Invalid greater than 1.
   SetInputParam("mc_break_coef", 1.1);
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
-  * Ensure when --monte_carlo flag is true, then KDEMain actually uses Monte
-  * Carlo estimations. Since this test has a random component, it might fail
-  * (although it's unlikely).
- **/
+ * Ensure when --monte_carlo flag is true, then KDEMain actually uses Monte
+ * Carlo estimations. Since this test has a random component, it might fail
+ * (although it's unlikely).
+ */
 TEST_CASE_METHOD(KDETestFixture, "KDEMainMonteCarloFlag",
                 "[KDEMainTest][BindingTests]")
 {
@@ -558,16 +505,16 @@ TEST_CASE_METHOD(KDETestFixture, "KDEMainMonteCarloFlag",
   SetInputParam("monte_carlo", true);
 
   // Compute estimations 1.
-  mlpackMain();
-  estimations1 = std::move(IO::GetParam<arma::vec>("predictions"));
+  RUN_BINDING();
+  estimations1 = std::move(params.Get<arma::vec>("predictions"));
 
-  delete IO::GetParam<KDEModel*>("output_model");
+  delete params.Get<KDEModel*>("output_model");
 
   // Compute estimations 2.
   SetInputParam("reference", reference);
   SetInputParam("query", query);
-  mlpackMain();
-  estimations2 = std::move(IO::GetParam<arma::vec>("predictions"));
+  RUN_BINDING();
+  estimations2 = std::move(params.Get<arma::vec>("predictions"));
 
   // Check whether results are equal.
   differences = arma::abs(estimations1 - estimations2);
