@@ -2,47 +2,28 @@
  * @file tests/main_tests/lmnn_test.cpp
  * @author Manish Kumar
  *
- * Test mlpackMain() of lmnn_main.cpp.
+ * Test RUN_BINDING() of lmnn_main.cpp.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
-static const std::string testName = "LMNN";
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/util/mlpack_main.hpp>
 #include <mlpack/core/metrics/lmetric.hpp>
-
-#include "test_helper.hpp"
 #include <mlpack/methods/lmnn/lmnn_main.cpp>
+#include <mlpack/core/util/mlpack_main.hpp>
+
+#include "main_test_fixture.hpp"
 
 #include "../test_catch_tools.hpp"
 #include "../catch.hpp"
 
 using namespace mlpack;
 
-struct LMNNTestFixture
-{
- public:
-  LMNNTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~LMNNTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
+BINDING_TEST_FIXTURE(LMNNTestFixture);
 
 /**
  * Ensure that, when labels are implicitily given with input,
@@ -59,21 +40,20 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNExplicitImplicitLabelsTest",
 
   SetInputParam("input", inputData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that final output has expected number of rows and colums.
-  REQUIRE(IO::GetParam<arma::mat>("output").n_rows ==
+  REQUIRE(params.Get<arma::mat>("output").n_rows ==
       inputData.n_rows - 1);
-  REQUIRE(IO::GetParam<arma::mat>("output").n_cols ==
+  REQUIRE(params.Get<arma::mat>("output").n_cols ==
       inputData.n_rows - 1);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_rows ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_rows ==
       inputData.n_rows - 1);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_cols ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_cols ==
       inputData.n_cols);
 
   // Reset Settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Now check that when labels are explicitely given, the last column
   // of input is not treated as labels.
@@ -87,16 +67,16 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNExplicitImplicitLabelsTest",
   SetInputParam("input", inputData);
   SetInputParam("labels", std::move(labels));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that final output has expected number of rows and colums.
-  REQUIRE(IO::GetParam<arma::mat>("output").n_rows ==
+  REQUIRE(params.Get<arma::mat>("output").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("output").n_cols ==
+  REQUIRE(params.Get<arma::mat>("output").n_cols ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_rows ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_cols ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_cols ==
       inputData.n_cols);
 }
 
@@ -122,58 +102,56 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNOptimizerTest",
   // when that is fixed.
   SetInputParam("optimizer",  std::string("amsgrad"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that final output has expected number of rows and colums.
-  REQUIRE(IO::GetParam<arma::mat>("output").n_rows ==
+  REQUIRE(params.Get<arma::mat>("output").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("output").n_cols ==
+  REQUIRE(params.Get<arma::mat>("output").n_cols ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_rows ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_cols ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_cols ==
       inputData.n_cols);
 
   // Reset rettings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Input random data points.
   SetInputParam("input", inputData);
   SetInputParam("labels", labels);
   SetInputParam("optimizer",  std::string("sgd"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that final output has expected number of rows and colums.
-  REQUIRE(IO::GetParam<arma::mat>("output").n_rows ==
+  REQUIRE(params.Get<arma::mat>("output").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("output").n_cols ==
+  REQUIRE(params.Get<arma::mat>("output").n_cols ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_rows ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_cols ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_cols ==
       inputData.n_cols);
 
-  // Reset rettings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  // Reset settings.
+  ResetSettings();
 
   // Input random data points.
   SetInputParam("input", inputData);
   SetInputParam("labels", std::move(labels));
   SetInputParam("optimizer",  std::string("lbfgs"));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that final output has expected number of rows and colums.
-  REQUIRE(IO::GetParam<arma::mat>("output").n_rows ==
+  REQUIRE(params.Get<arma::mat>("output").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("output").n_cols ==
+  REQUIRE(params.Get<arma::mat>("output").n_cols ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_rows ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_cols ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_cols ==
       inputData.n_cols);
 }
 
@@ -201,16 +179,16 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNValidDistanceTest",
   SetInputParam("labels", std::move(labels));
   SetInputParam("distance", std::move(distance));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that final output has expected number of rows and colums.
-  REQUIRE(IO::GetParam<arma::mat>("output").n_rows ==
+  REQUIRE(params.Get<arma::mat>("output").n_rows ==
       inputData.n_rows - 1);
-  REQUIRE(IO::GetParam<arma::mat>("output").n_cols ==
+  REQUIRE(params.Get<arma::mat>("output").n_cols ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_rows ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_rows ==
       inputData.n_rows - 1);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_cols ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_cols ==
       inputData.n_cols);
 }
 
@@ -238,16 +216,16 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNValidDistanceTest2",
   SetInputParam("labels", std::move(labels));
   SetInputParam("distance", std::move(distance));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that final output has expected number of rows and colums.
-  REQUIRE(IO::GetParam<arma::mat>("output").n_rows ==
+  REQUIRE(params.Get<arma::mat>("output").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("output").n_cols ==
+  REQUIRE(params.Get<arma::mat>("output").n_cols ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_rows ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_cols ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_cols ==
       inputData.n_cols);
 }
 
@@ -275,16 +253,16 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNInvalidDistanceTest",
   SetInputParam("labels", std::move(labels));
   SetInputParam("distance", std::move(distance));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that final output has expected number of rows and colums.
-  REQUIRE(IO::GetParam<arma::mat>("output").n_rows ==
+  REQUIRE(params.Get<arma::mat>("output").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("output").n_cols ==
+  REQUIRE(params.Get<arma::mat>("output").n_cols ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_rows ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_rows ==
       inputData.n_rows);
-  REQUIRE(IO::GetParam<arma::mat>("transformed_data").n_cols ==
+  REQUIRE(params.Get<arma::mat>("transformed_data").n_cols ==
       inputData.n_cols);
 }
 
@@ -305,9 +283,7 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNNumTargetsTest",
   SetInputParam("k", (int) 5);
 
   // Check that an error is thrown.
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -331,14 +307,13 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffNormalizationTest",
   SetInputParam("linear_scan", true);
   SetInputParam("tolerance", 0.01);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
-  // Reset rettings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  // Reset settings.
+  ResetSettings();
 
   // Use the same input but set normalize to false.
   SetInputParam("input", std::move(inputData));
@@ -347,11 +322,11 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffNormalizationTest",
   SetInputParam("linear_scan", true);
   SetInputParam("tolerance", 0.01);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -375,14 +350,13 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffStepSizeTest",
   SetInputParam("step_size", (double) 0.01);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Set parameters using the same input but with a larger step_size.
   SetInputParam("input", std::move(inputData));
@@ -390,12 +364,12 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffStepSizeTest",
   SetInputParam("step_size", (double) 20.5);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  RUN_BINDING();
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -418,25 +392,24 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffToleranceTest",
   SetInputParam("tolerance", (double) 1e-6);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Set parameters using the same input but with a larger tolerance.
   SetInputParam("input", std::move(inputData));
   SetInputParam("tolerance", (double) 0.3);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -460,14 +433,13 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffBatchSizeTest",
   SetInputParam("batch_size", (int) 20);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Set parameters using the same input but with a larger batch_size.
   SetInputParam("input", std::move(inputData));
@@ -475,11 +447,11 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffBatchSizeTest",
   SetInputParam("batch_size", (int) 30);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -504,14 +476,13 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffNumTargetsTest",
   SetInputParam("k", 1);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Set different parameters.
   SetInputParam("input", std::move(inputData));
@@ -519,11 +490,11 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffNumTargetsTest",
   SetInputParam("k", 5);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -548,14 +519,13 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffRegularizationTest",
   SetInputParam("linear_scan",  (bool) true);
   SetInputParam("regularization", 1.0);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Set different parameters.
   SetInputParam("input", std::move(inputData));
@@ -563,11 +533,11 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffRegularizationTest",
   SetInputParam("linear_scan",  (bool) true);
   SetInputParam("regularization", 0.1);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -591,14 +561,13 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffRangeTest",
   SetInputParam("labels", labels);
   SetInputParam("linear_scan",  (bool) true);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Set different parameters.
   SetInputParam("input", std::move(inputData));
@@ -606,11 +575,11 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffRangeTest",
   SetInputParam("linear_scan",  (bool) true);
   SetInputParam("range", 100);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -637,14 +606,13 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffMaxIterationTest",
   SetInputParam("k", 5);
   SetInputParam("max_iterations", (int) 2);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Set parameters using the same input but with a larger max_iterations.
   SetInputParam("input", std::move(inputData));
@@ -654,11 +622,11 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffMaxIterationTest",
   SetInputParam("k", 5);
   SetInputParam("max_iterations", (int) 500);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -683,14 +651,13 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffPassesTest",
   SetInputParam("linear_scan",  (bool) true);
   SetInputParam("passes", (int) 2);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  arma::mat output = IO::GetParam<arma::mat>("output");
-  arma::mat transformedData = IO::GetParam<arma::mat>("transformed_data");
+  arma::mat output = params.Get<arma::mat>("output");
+  arma::mat transformedData = params.Get<arma::mat>("transformed_data");
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Set parameters using the same input but with a larger passes.
   SetInputParam("input", std::move(inputData));
@@ -698,11 +665,11 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffPassesTest",
   SetInputParam("linear_scan",  (bool) true);
   SetInputParam("passes", (int) 6);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that the output matrices are different.
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("output") != output) > 0);
-  REQUIRE(arma::accu(IO::GetParam<arma::mat>("transformed_data") !=
+  REQUIRE(arma::accu(params.Get<arma::mat>("output") != output) > 0);
+  REQUIRE(arma::accu(params.Get<arma::mat>("transformed_data") !=
       transformedData) > 0);
 }
 
@@ -729,13 +696,10 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", labels);
   SetInputParam("k", (int) 0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Test for range value.
 
@@ -744,13 +708,10 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", labels);
   SetInputParam("range", (int) 0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Test for batch size value.
 
@@ -759,13 +720,10 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", labels);
   SetInputParam("batch_size", (int) 0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Test for regularization value.
 
@@ -774,13 +732,10 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", labels);
   SetInputParam("regularization", (double) -1.0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Test for step size value.
 
@@ -789,13 +744,10 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", labels);
   SetInputParam("step_size", (double) -1.0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Test for max iterations value.
 
@@ -804,13 +756,10 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", labels);
   SetInputParam("max_iterations", (int) -1.0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Test for passes value.
 
@@ -819,13 +768,10 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", labels);
   SetInputParam("passes", (int) -1.0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Test for max iterations value.
 
@@ -834,13 +780,10 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", labels);
   SetInputParam("rank", (int) -1.0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
   // Reset settings.
-  IO::ClearSettings();
-  IO::RestoreSettings(testName);
+  ResetSettings();
 
   // Test for tolerance value.
 
@@ -849,7 +792,5 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   SetInputParam("labels", std::move(labels));
   SetInputParam("tolerance", (double) -1.0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
