@@ -2,43 +2,26 @@
  * @file tests/main_tests/radical_test.cpp
  * @author Manish Kumar
  *
- * Test mlpackMain() of radical_main.cpp.
+ * Test RUN_BINDING() of radical_main.cpp.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
-static const std::string testName = "Radical";
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/util/mlpack_main.hpp>
-#include "test_helper.hpp"
 #include <mlpack/methods/radical/radical_main.cpp>
+#include <mlpack/core/util/mlpack_main.hpp>
+
+#include "main_test_fixture.hpp"
 
 #include "../catch.hpp"
 
 using namespace mlpack;
 
-struct RadicalTestFixture
-{
- public:
-  RadicalTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~RadicalTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
+BINDING_TEST_FIXTURE(RadicalTestFixture);
 
 /**
  * Check that output Y and W matrix have valid dimensions.
@@ -50,15 +33,15 @@ TEST_CASE_METHOD(RadicalTestFixture, "RadicalOutputDimensionTest",
 
   SetInputParam("input", std::move(input));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check dimension of Y matrix.
-  REQUIRE(IO::GetParam<arma::mat>("output_ic").n_rows == 5);
-  REQUIRE(IO::GetParam<arma::mat>("output_ic").n_cols == 3);
+  REQUIRE(params.Get<arma::mat>("output_ic").n_rows == 5);
+  REQUIRE(params.Get<arma::mat>("output_ic").n_cols == 3);
 
   // Check dimension of W matrix.
-  REQUIRE(IO::GetParam<arma::mat>("output_unmixing").n_rows == 5);
-  REQUIRE(IO::GetParam<arma::mat>("output_unmixing").n_cols == 5);
+  REQUIRE(params.Get<arma::mat>("output_unmixing").n_rows == 5);
+  REQUIRE(params.Get<arma::mat>("output_unmixing").n_cols == 5);
 }
 
 /**
@@ -75,42 +58,37 @@ TEST_CASE_METHOD(RadicalTestFixture, "RadicalBoundsTest",
   SetInputParam("input", input);
   SetInputParam("replicates", (int) 0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
-  bindings::tests::CleanMemory();
+  CleanMemory();
+  ResetSettings();
 
   // Test for noise_std_dev.
 
   SetInputParam("input", input);
   SetInputParam("noise_std_dev", (double) -1.0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
-  bindings::tests::CleanMemory();
+  CleanMemory();
+  ResetSettings();
 
   // Test for angles.
 
   SetInputParam("input", input);
   SetInputParam("angles", (int) 0);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
-  bindings::tests::CleanMemory();
+  CleanMemory();
+  ResetSettings();
 
   // Test for sweeps.
 
   SetInputParam("input", input);
   SetInputParam("sweeps", (int) -2);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -128,21 +106,22 @@ TEST_CASE_METHOD(RadicalTestFixture, "RadicalDiffNoiseStdDevTest",
 
   SetInputParam("input", input);
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
-  arma::mat Y = IO::GetParam<arma::mat>("output_ic");
+  arma::mat Y = params.Get<arma::mat>("output_ic");
 
-  bindings::tests::CleanMemory();
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input", std::move(input));
   SetInputParam("noise_std_dev", (double) 0.01);
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Check that initial output and final output using two models are different.
-  REQUIRE(arma::accu(Y == IO::GetParam<arma::mat>("output_ic")) < Y.n_elem);
+  REQUIRE(arma::accu(Y == params.Get<arma::mat>("output_ic")) < Y.n_elem);
 }
 
 /**
@@ -159,21 +138,22 @@ TEST_CASE_METHOD(RadicalTestFixture, "RadicalDiffReplicatesTest",
 
   SetInputParam("input", input);
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
-  arma::mat Y = IO::GetParam<arma::mat>("output_ic");
+  arma::mat Y = params.Get<arma::mat>("output_ic");
 
-  bindings::tests::CleanMemory();
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input", std::move(input));
   SetInputParam("replicates", (int) 10);
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Check that initial output and final output using two models are different.
-  REQUIRE(arma::accu(Y == IO::GetParam<arma::mat>("output_ic")) < Y.n_elem);
+  REQUIRE(arma::accu(Y == params.Get<arma::mat>("output_ic")) < Y.n_elem);
 }
 
 /**
@@ -190,21 +170,22 @@ TEST_CASE_METHOD(RadicalTestFixture, "RadicalDiffAnglesTest",
 
   SetInputParam("input", input);
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
-  arma::mat Y = IO::GetParam<arma::mat>("output_ic");
+  arma::mat Y = params.Get<arma::mat>("output_ic");
 
-  bindings::tests::CleanMemory();
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("input", std::move(input));
   SetInputParam("angles", (int) 20);
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Check that initial output and final output using two models are different.
-  REQUIRE(arma::accu(Y == IO::GetParam<arma::mat>("output_ic")) < Y.n_elem);
+  REQUIRE(arma::accu(Y == params.Get<arma::mat>("output_ic")) < Y.n_elem);
 }
 
 /**
@@ -221,19 +202,21 @@ TEST_CASE_METHOD(RadicalTestFixture, "RadicalDiffSweepsTest",
 
   SetInputParam("input", input);
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
-  arma::mat Y = IO::GetParam<arma::mat>("output_ic");
+  arma::mat Y = params.Get<arma::mat>("output_ic");
 
-  bindings::tests::CleanMemory();
+  CleanMemory();
+  ResetSettings();
+  ResetSettings();
 
   SetInputParam("input", std::move(input));
   SetInputParam("sweeps", (int) 2);
 
-  mlpack::math::FixedRandomSeed();
-  mlpackMain();
+  FixedRandomSeed();
+  RUN_BINDING();
 
   // Check that initial output and final output using two models are different.
-  REQUIRE(arma::accu(Y == IO::GetParam<arma::mat>("output_ic")) < Y.n_elem);
+  REQUIRE(arma::accu(Y == params.Get<arma::mat>("output_ic")) < Y.n_elem);
 }
