@@ -9,12 +9,11 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
-#include <mlpack/methods/naive_bayes/naive_bayes_classifier.hpp>
+#include <mlpack/methods/naive_bayes.hpp>
 
 #include "catch.hpp"
 
 using namespace mlpack;
-using namespace naive_bayes;
 
 TEST_CASE("NaiveBayesClassifierTest", "[NBCTest]")
 {
@@ -26,8 +25,10 @@ TEST_CASE("NaiveBayesClassifierTest", "[NBCTest]")
   size_t classes = 2;
 
   arma::mat trainData, trainRes, calcMat;
-  data::Load(trainFilename, trainData, true);
-  data::Load(trainResultFilename, trainRes, true);
+  if (!data::Load(trainFilename, trainData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(trainResultFilename, trainRes))
+    FAIL("Cannot load dataset");
 
   // Get the labels out.
   arma::Row<size_t> labels(trainData.n_cols);
@@ -66,9 +67,12 @@ TEST_CASE("NaiveBayesClassifierTest", "[NBCTest]")
   arma::mat testResProbs;
   arma::Row<size_t> calcVec;
   arma::mat calcProbs;
-  data::Load(testFilename, testData, true);
-  data::Load(testResultFilename, testRes, true);
-  data::Load(testResultProbsFilename, testResProbs, true);
+  if (!data::Load(testFilename, testData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(testResultFilename, testRes))
+    FAIL("Cannot load dataset");
+  if (!data::Load(testResultProbsFilename, testResProbs))
+    FAIL("Cannot load dataset");
 
   testData.shed_row(testData.n_rows - 1); // Remove the labels.
 
@@ -81,7 +85,6 @@ TEST_CASE("NaiveBayesClassifierTest", "[NBCTest]")
   {
     for (size_t j = 0; j < testResProbs.n_rows; ++j)
     {
-      
       REQUIRE(testResProbs(j, i) + 0.0001 ==
           Approx(calcProbs(j, i) + 0.0001).epsilon(0.0001));
     }
@@ -100,8 +103,10 @@ TEST_CASE("NaiveBayesClassifierIncrementalTest", "[NBCTest]")
   size_t classes = 2;
 
   arma::mat trainData, trainRes, calcMat;
-  data::Load(trainFilename, trainData, true);
-  data::Load(trainResultFilename, trainRes, true);
+  if (!data::Load(trainFilename, trainData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(trainResultFilename, trainRes))
+    FAIL("Cannot load dataset");
 
   // Get the labels out.
   arma::Row<size_t> labels(trainData.n_cols);
@@ -140,9 +145,12 @@ TEST_CASE("NaiveBayesClassifierIncrementalTest", "[NBCTest]")
   arma::mat testResProba;
   arma::Row<size_t> calcVec;
   arma::mat calcProbs;
-  data::Load(testFilename, testData, true);
-  data::Load(testResultFilename, testRes, true);
-  data::Load(testResultProbsFilename, testResProba, true);
+  if (!data::Load(testFilename, testData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(testResultFilename, testRes))
+    FAIL("Cannot load dataset");
+  if (!data::Load(testResultProbsFilename, testResProba))
+    FAIL("Cannot load dataset");
 
   testData.shed_row(testData.n_rows - 1); // Remove the labels.
 
@@ -171,8 +179,10 @@ TEST_CASE("SeparateTrainTest", "[NBCTest]")
   size_t classes = 2;
 
   arma::mat trainData, trainRes, calcMat;
-  data::Load(trainFilename, trainData, true);
-  data::Load(trainResultFilename, trainRes, true);
+  if (!data::Load(trainFilename, trainData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(trainResultFilename, trainRes))
+    FAIL("Cannot load dataset");
 
   // Get the labels out.
   arma::Row<size_t> labels(trainData.n_cols);
@@ -229,8 +239,10 @@ TEST_CASE("SeparateTrainIncrementalTest", "[NBCTest]")
   size_t classes = 2;
 
   arma::mat trainData, trainRes, calcMat;
-  data::Load(trainFilename, trainData, true);
-  data::Load(trainResultFilename, trainRes, true);
+  if (!data::Load(trainFilename, trainData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(trainResultFilename, trainRes))
+    FAIL("Cannot load dataset");
 
   // Get the labels out.
   arma::Row<size_t> labels(trainData.n_cols);
@@ -287,8 +299,10 @@ TEST_CASE("SeparateTrainIndividualIncrementalTest", "[NBCTest]")
   size_t classes = 2;
 
   arma::mat trainData, trainRes, calcMat;
-  data::Load(trainFilename, trainData, true);
-  data::Load(trainResultFilename, trainRes, true);
+  if (!data::Load(trainFilename, trainData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(trainResultFilename, trainRes))
+    FAIL("Cannot load dataset");
 
   // Get the labels out.
   arma::Row<size_t> labels(trainData.n_cols);
@@ -357,8 +371,10 @@ TEST_CASE("NaiveBayesClassifierHighDimensionsTest", "[NBCTest]")
   // Create variables for training and assign data to them.
   arma::mat trainData;
   arma::Row<size_t> trainLabels;
-  data::Load(trainFilename, trainData, true);
-  data::Load(trainLabelsFileName, trainLabels, true);
+  if (!data::Load(trainFilename, trainData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(trainLabelsFileName, trainLabels))
+    FAIL("Cannot load dataset");
 
   // Initialize and train a NBC model.
   NaiveBayesClassifier<> nbcTest(trainData, trainLabels, classes);
@@ -367,8 +383,10 @@ TEST_CASE("NaiveBayesClassifierHighDimensionsTest", "[NBCTest]")
   arma::mat testData, calcProbs;
   arma::Row<size_t> testLabels;
   arma::Row<size_t> calcVec;
-  data::Load(testFilename, testData, true);
-  data::Load(testLabelsFilename, testLabels, true);
+  if (!data::Load(testFilename, testData))
+    FAIL("Cannot load dataset");
+  if (!data::Load(testLabelsFilename, testLabels))
+    FAIL("Cannot load dataset");
 
   // Classify observations in the test dataset. To use Classify() method with
   // a parameter for probabilities of predictions, we pass 'calcProbs' to the
