@@ -11,15 +11,11 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
-#include <mlpack/core/metrics/lmetric.hpp>
-#include <mlpack/methods/nca/nca.hpp>
-#include <ensmallen.hpp>
+#include <mlpack/methods/nca.hpp>
 
 #include "catch.hpp"
 
 using namespace mlpack;
-using namespace mlpack::metric;
-using namespace mlpack::nca;
 using namespace ens;
 
 //
