@@ -10,14 +10,11 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
-#include <mlpack/methods/regularized_svd/regularized_svd.hpp>
-
-#include <ensmallen.hpp>
+#include <mlpack/methods/regularized_svd.hpp>
 
 #include "catch.hpp"
 
 using namespace mlpack;
-using namespace mlpack::svd;
 using namespace ens;
 
 TEST_CASE("RegularizedSVDFunctionRandomEvaluate", "[RegularizedSVDTest]")
@@ -251,7 +248,7 @@ TEST_CASE("RegularizedSVDFunctionOptimize", "[RegularizedSVDTest]")
 
 // The test is only compiled if the user has specified OpenMP to be
 // used.
-#ifdef HAS_OPENMP
+#ifdef MLPACK_USE_OPENMP
 
 // Test Regularized SVD with parallel SGD.
 TEST_CASE("RegularizedSVDFunctionOptimizeHOGWILD", "[RegularizedSVDTest]")
