@@ -11,18 +11,10 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
-#include <mlpack/core/boost_backport/boost_backport_string_view.hpp>
-#include <mlpack/core/data/tokenizers/split_by_any_of.hpp>
-#include <mlpack/core/data/tokenizers/char_extract.hpp>
-#include <mlpack/core/data/string_encoding.hpp>
-#include <mlpack/core/data/string_encoding_policies/dictionary_encoding_policy.hpp>
-#include <mlpack/core/data/string_encoding_policies/bag_of_words_encoding_policy.hpp>
-#include <mlpack/core/data/string_encoding_policies/tf_idf_encoding_policy.hpp>
-#include <boost/test/unit_test.hpp>
 #include <memory>
 #include "test_catch_tools.hpp"
 #include "catch.hpp"
-#include "serialization_catch.hpp"
+#include "serialization.hpp"
 
 using namespace mlpack;
 using namespace mlpack::data;
@@ -79,7 +71,7 @@ void CheckVectors(const vector<vector<ValueType>>& a,
  */
 TEST_CASE("DictionaryEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   arma::mat output;
   DictionaryEncoding<SplitByAnyOf::TokenType> encoder;
@@ -116,7 +108,7 @@ TEST_CASE("DictionaryEncodingTest", "[StringEncodingTest]")
  */
 TEST_CASE("UnicodeDictionaryEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   arma::mat output;
   DictionaryEncoding<SplitByAnyOf::TokenType> encoder;
@@ -150,7 +142,7 @@ TEST_CASE("UnicodeDictionaryEncodingTest", "[StringEncodingTest]")
  */
 TEST_CASE("OnePassDictionaryEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   vector<vector<size_t>> output;
   DictionaryEncoding<SplitByAnyOf::TokenType> encoder(
@@ -187,10 +179,10 @@ TEST_CASE("OnePassDictionaryEncodingTest", "[StringEncodingTest]")
  */
 TEST_CASE("SplitByAnyOfTokenizerTest", "[StringEncodingTest]")
 {
-  std::vector<boost::string_view> tokens;
-  boost::string_view line(stringEncodingInput[0]);
+  std::vector<MLPACK_STRING_VIEW> tokens;
+  MLPACK_STRING_VIEW line(stringEncodingInput[0]);
   SplitByAnyOf tokenizer(" ,.");
-  boost::string_view token = tokenizer(line);
+  MLPACK_STRING_VIEW token = tokenizer(line);
 
   while (!token.empty())
   {
@@ -209,6 +201,7 @@ TEST_CASE("SplitByAnyOfTokenizerTest", "[StringEncodingTest]")
     REQUIRE(tokens[i] == expected[i]);
 }
 
+
 /**
  * Test the SplitByAnyOf tokenizer in case of unicode characters.
  */
@@ -224,11 +217,10 @@ TEST_CASE("SplitByAnyOfTokenizerUnicodeTest", "[StringEncodingTest]")
     "\xE2\x93\x82\xE2\x93\x81\xE2\x93\x85\xE2\x92\xB6\xE2\x92\xB8\xE2\x93\x80"
   };
 
-  std::vector<boost::string_view> tokens;
-  boost::string_view line(stringEncodingUtf8Input[2]);
+  std::vector<MLPACK_STRING_VIEW> tokens;
+  MLPACK_STRING_VIEW line(stringEncodingUtf8Input[2]);
   SplitByAnyOf tokenizer(" ,.");
-  boost::string_view token = tokenizer(line);
-
+  MLPACK_STRING_VIEW token = tokenizer(line);
   while (!token.empty())
   {
     tokens.push_back(token);
@@ -269,7 +261,8 @@ TEST_CASE("DictionaryEncodingIndividualCharactersTest", "[StringEncodingTest]")
  * Test the one pass modification of the dictionary encoding algorithm
  * in case of individual character encoding.
  */
-TEST_CASE("OnePassDictionaryEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("OnePassDictionaryEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   std::vector<string> input = {
     "GACCA",
@@ -296,7 +289,7 @@ TEST_CASE("OnePassDictionaryEncodingIndividualCharactersTest", "[StringEncodingT
  */
 TEST_CASE("StringEncodingCopyTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
   arma::sp_mat output;
   DictionaryEncoding<SplitByAnyOf::TokenType> encoderCopy;
   SplitByAnyOf tokenizer(" ,.");
@@ -332,7 +325,7 @@ TEST_CASE("StringEncodingCopyTest", "[StringEncodingTest]")
  */
 TEST_CASE("StringEncodingMoveTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
   arma::sp_mat output;
   DictionaryEncoding<SplitByAnyOf::TokenType> encoderCopy;
   SplitByAnyOf tokenizer(" ,.");
@@ -391,21 +384,21 @@ void CheckDictionaries(const StringEncodingDictionary<TokenType>& expected,
 
 /**
  * This is a specialization of the CheckDictionaries() function for
- * the boost::string_view token type.
+ * the MLPACK_STRING_VIEW token type.
  */
 template<>
 void CheckDictionaries(
-    const StringEncodingDictionary<boost::string_view>& expected,
-    const StringEncodingDictionary<boost::string_view>& obtained)
+    const StringEncodingDictionary<MLPACK_STRING_VIEW>& expected,
+    const StringEncodingDictionary<MLPACK_STRING_VIEW>& obtained)
 {
   /* MapType is equal to
    *
-   * std::unordered_map<boost::string_view,
+   * std::unordered_map<MLPACK_STRING_VIEW,
    *                    size_t,
-   *                    boost::hash<boost::string_view>>.
+   *                    boost::hash<MLPACK_STRING_VIEW>>.
    */
   using MapType =
-      typename StringEncodingDictionary<boost::string_view>::MapType;
+      typename StringEncodingDictionary<MLPACK_STRING_VIEW>::MapType;
 
   const std::deque<std::string>& expectedTokens = expected.Tokens();
   const std::deque<std::string>& tokens = obtained.Tokens();
@@ -458,9 +451,9 @@ TEST_CASE("StringEncodingDictionarySerialization", "[StringEncodingTest]")
 
   for (const string& line : stringEncodingInput)
   {
-    boost::string_view lineView(line);
+    MLPACK_STRING_VIEW lineView(line);
 
-    boost::string_view token = tokenizer(lineView);
+    MLPACK_STRING_VIEW token = tokenizer(lineView);
 
     while (!tokenizer.IsTokenEmpty(token))
     {
@@ -470,13 +463,13 @@ TEST_CASE("StringEncodingDictionarySerialization", "[StringEncodingTest]")
     }
   }
 
-  DictionaryType xmlDictionary, textDictionary, binaryDictionary;
+  DictionaryType xmlDictionary, jsonDictionary, binaryDictionary;
 
-  SerializeObjectAll(dictionary, xmlDictionary, textDictionary,
+  SerializeObjectAll(dictionary, xmlDictionary, jsonDictionary,
       binaryDictionary);
 
   CheckDictionaries(dictionary, xmlDictionary);
-  CheckDictionaries(dictionary, textDictionary);
+  CheckDictionaries(dictionary, jsonDictionary);
   CheckDictionaries(dictionary, binaryDictionary);
 }
 
@@ -494,20 +487,20 @@ TEST_CASE("SplitByAnyOfDictionaryEncodingSerialization", "[StringEncodingTest]")
 
   encoder.Encode(stringEncodingInput, output, tokenizer);
 
-  EncoderType xmlEncoder, textEncoder, binaryEncoder;
-  arma::mat xmlOutput, textOutput, binaryOutput;
+  EncoderType xmlEncoder, jsonEncoder, binaryEncoder;
+  arma::mat xmlOutput, jsonOutput, binaryOutput;
 
-  SerializeObjectAll(encoder, xmlEncoder, textEncoder, binaryEncoder);
+  SerializeObjectAll(encoder, xmlEncoder, jsonEncoder, binaryEncoder);
 
   CheckDictionaries(encoder.Dictionary(), xmlEncoder.Dictionary());
-  CheckDictionaries(encoder.Dictionary(), textEncoder.Dictionary());
+  CheckDictionaries(encoder.Dictionary(), jsonEncoder.Dictionary());
   CheckDictionaries(encoder.Dictionary(), binaryEncoder.Dictionary());
 
   xmlEncoder.Encode(stringEncodingInput, xmlOutput, tokenizer);
-  textEncoder.Encode(stringEncodingInput, textOutput, tokenizer);
+  jsonEncoder.Encode(stringEncodingInput, jsonOutput, tokenizer);
   binaryEncoder.Encode(stringEncodingInput, binaryOutput, tokenizer);
 
-  CheckMatrices(output, xmlOutput, textOutput, binaryOutput);
+  CheckMatrices(output, xmlOutput, jsonOutput, binaryOutput);
 }
 
 /**
@@ -524,28 +517,28 @@ TEST_CASE("CharExtractDictionaryEncodingSerialization", "[StringEncodingTest]")
 
   encoder.Encode(stringEncodingInput, output, tokenizer);
 
-  EncoderType xmlEncoder, textEncoder, binaryEncoder;
-  arma::mat xmlOutput, textOutput, binaryOutput;
+  EncoderType xmlEncoder, jsonEncoder, binaryEncoder;
+  arma::mat xmlOutput, jsonOutput, binaryOutput;
 
-  SerializeObjectAll(encoder, xmlEncoder, textEncoder, binaryEncoder);
+  SerializeObjectAll(encoder, xmlEncoder, jsonEncoder, binaryEncoder);
 
   CheckDictionaries(encoder.Dictionary(), xmlEncoder.Dictionary());
-  CheckDictionaries(encoder.Dictionary(), textEncoder.Dictionary());
+  CheckDictionaries(encoder.Dictionary(), jsonEncoder.Dictionary());
   CheckDictionaries(encoder.Dictionary(), binaryEncoder.Dictionary());
 
   xmlEncoder.Encode(stringEncodingInput, xmlOutput, tokenizer);
-  textEncoder.Encode(stringEncodingInput, textOutput, tokenizer);
+  jsonEncoder.Encode(stringEncodingInput, jsonOutput, tokenizer);
   binaryEncoder.Encode(stringEncodingInput, binaryOutput, tokenizer);
 
-  CheckMatrices(output, xmlOutput, textOutput, binaryOutput);
+  CheckMatrices(output, xmlOutput, jsonOutput, binaryOutput);
 }
 
 /**
  * Test the Bag of Words encoding algorithm.
- */ 
+ */
 TEST_CASE("BagOfWordsEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   arma::mat output;
   BagOfWordsEncoding<SplitByAnyOf::TokenType> encoder;
@@ -617,10 +610,10 @@ TEST_CASE("BagOfWordsEncodingTest", "[StringEncodingTest]")
 
 /**
  * Test the Bag of Words encoding algorithm. The output is saved into a vector.
- */ 
+ */
 TEST_CASE("VectorBagOfWordsEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   vector<vector<size_t>> output;
   BagOfWordsEncoding<SplitByAnyOf::TokenType> encoder(
@@ -684,7 +677,8 @@ TEST_CASE("BagOfWordsEncodingIndividualCharactersTest", "[StringEncodingTest]")
  * Test the Bag of Words encoding algorithm in case of individual
  * characters encoding. The output type is vector<vector<size_t>>.
  */
-TEST_CASE("VectorBagOfWordsEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("VectorBagOfWordsEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   std::vector<string> input = {
     "GACCA",
@@ -713,7 +707,7 @@ TEST_CASE("VectorBagOfWordsEncodingIndividualCharactersTest", "[StringEncodingTe
  */
 TEST_CASE("RawCountSmoothIdfEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   arma::mat output;
   TfIdfEncoding<SplitByAnyOf::TokenType> encoder;
@@ -815,7 +809,7 @@ TEST_CASE("RawCountSmoothIdfEncodingTest", "[StringEncodingTest]")
  */
 TEST_CASE("VectorRawCountSmoothIdfEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   vector<vector<double>> output;
   TfIdfEncoding<SplitByAnyOf::TokenType> encoder(
@@ -861,7 +855,8 @@ TEST_CASE("VectorRawCountSmoothIdfEncodingTest", "[StringEncodingTest]")
  * raw count term frequency type and the smooth inverse document frequency type.
  * These parameters are the default ones.
  */
-TEST_CASE("RawCountSmoothIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("RawCountSmoothIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   vector<string> input = {
     "GACCA",
@@ -942,7 +937,8 @@ TEST_CASE("RawCountSmoothIdfEncodingIndividualCharactersTest", "[StringEncodingT
  * These parameters are the default ones. The output type is
  * vector<vector<double>>.
  */
-TEST_CASE("VectorRawCountSmoothIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("VectorRawCountSmoothIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   std::vector<string> input = {
     "GACCA",
@@ -972,7 +968,7 @@ TEST_CASE("VectorRawCountSmoothIdfEncodingIndividualCharactersTest", "[StringEnc
  */
 TEST_CASE("TfIdfRawCountEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   arma::mat output;
   TfIdfEncoding<SplitByAnyOf::TokenType> encoder(
@@ -1022,7 +1018,7 @@ TEST_CASE("TfIdfRawCountEncodingTest", "[StringEncodingTest]")
  */
 TEST_CASE("VectorTfIdfRawCountEncodingTest", "[StringEncodingTest]")
 {
-  using DictionaryType = StringEncodingDictionary<boost::string_view>;
+  using DictionaryType = StringEncodingDictionary<MLPACK_STRING_VIEW>;
 
   vector<vector<double>> output;
   TfIdfEncoding<SplitByAnyOf::TokenType>
@@ -1068,7 +1064,8 @@ TEST_CASE("VectorTfIdfRawCountEncodingTest", "[StringEncodingTest]")
  * raw count term frequency type and the non-smooth inverse document frequency
  * type.
  */
-TEST_CASE("RawCountTfIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("RawCountTfIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   vector<string> input = {
     "GACCA",
@@ -1099,7 +1096,8 @@ TEST_CASE("RawCountTfIdfEncodingIndividualCharactersTest", "[StringEncodingTest]
  * raw count term frequency type and the non-smooth inverse document frequency
  * type. The output type is vector<vector<double>>.
  */
-TEST_CASE("VectorRawCountTfIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("VectorRawCountTfIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   std::vector<string> input = {
     "GACCA",
@@ -1129,7 +1127,8 @@ TEST_CASE("VectorRawCountTfIdfEncodingIndividualCharactersTest", "[StringEncodin
  * Test the Tf-Idf encoding algorithm for individual characters with the
  * binary term frequency type and the smooth inverse document frequency type.
  */
-TEST_CASE("BinarySmoothIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("BinarySmoothIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   vector<string> input = {
     "GACCA",
@@ -1160,7 +1159,8 @@ TEST_CASE("BinarySmoothIdfEncodingIndividualCharactersTest", "[StringEncodingTes
  * binary term frequency type and the smooth inverse document frequency type.
  * The output type is vector<vector<double>>.
  */
-TEST_CASE("VectorBinarySmoothIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("VectorBinarySmoothIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   std::vector<string> input = {
     "GACCA",
@@ -1222,7 +1222,8 @@ TEST_CASE("BinaryTfIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
  * sublinear term frequency type and the smooth inverse document frequency
  * type.
  */
-TEST_CASE("SublinearSmoothIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("SublinearSmoothIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   vector<string> input = {
     "GACCA",
@@ -1254,7 +1255,8 @@ TEST_CASE("SublinearSmoothIdfEncodingIndividualCharactersTest", "[StringEncoding
  * sublinear term frequency type and the non-smooth inverse document frequency
  * type.
  */
-TEST_CASE("SublinearTfIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("SublinearTfIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   vector<string> input = {
     "GACCA",
@@ -1286,7 +1288,8 @@ TEST_CASE("SublinearTfIdfEncodingIndividualCharactersTest", "[StringEncodingTest
  * standard term frequency type and the smooth inverse document frequency
  * type.
  */
-TEST_CASE("TermFrequencySmoothIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("TermFrequencySmoothIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   vector<string> input = {
     "GACCA",
@@ -1367,7 +1370,8 @@ TEST_CASE("TermFrequencySmoothIdfEncodingIndividualCharactersTest", "[StringEnco
  * standard term frequency type and the non-smooth inverse document frequency
  * type.
  */
-TEST_CASE("TermFrequencyTfIdfEncodingIndividualCharactersTest", "[StringEncodingTest]")
+TEST_CASE("TermFrequencyTfIdfEncodingIndividualCharactersTest",
+          "[StringEncodingTest]")
 {
   vector<string> input = {
     "GACCA",
@@ -1408,18 +1412,18 @@ TEST_CASE("SplitByAnyOfTfIdfEncodingSerialization", "[StringEncodingTest]")
 
   encoder.Encode(stringEncodingInput, output, tokenizer);
 
-  EncoderType xmlEncoder, textEncoder, binaryEncoder;
-  arma::mat xmlOutput, textOutput, binaryOutput;
+  EncoderType xmlEncoder, jsonEncoder, binaryEncoder;
+  arma::mat xmlOutput, jsonOutput, binaryOutput;
 
-  SerializeObjectAll(encoder, xmlEncoder, textEncoder, binaryEncoder);
+  SerializeObjectAll(encoder, xmlEncoder, jsonEncoder, binaryEncoder);
 
   CheckDictionaries(encoder.Dictionary(), xmlEncoder.Dictionary());
-  CheckDictionaries(encoder.Dictionary(), textEncoder.Dictionary());
+  CheckDictionaries(encoder.Dictionary(), jsonEncoder.Dictionary());
   CheckDictionaries(encoder.Dictionary(), binaryEncoder.Dictionary());
 
   xmlEncoder.Encode(stringEncodingInput, xmlOutput, tokenizer);
-  textEncoder.Encode(stringEncodingInput, textOutput, tokenizer);
+  jsonEncoder.Encode(stringEncodingInput, jsonOutput, tokenizer);
   binaryEncoder.Encode(stringEncodingInput, binaryOutput, tokenizer);
 
-  CheckMatrices(output, xmlOutput, textOutput, binaryOutput);
+  CheckMatrices(output, xmlOutput, jsonOutput, binaryOutput);
 }
